@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -214,7 +214,7 @@ SeriesObject.prototype = {
 		}
 		switch (this.recurrence_type) {
 			case 0:
-				returnstring = _("No series");
+				returnstring = _("No recurrence");
 				break;
 			case 1:	
 				returnstring = format(_("Each %s Day"),interval);
@@ -224,14 +224,14 @@ SeriesObject.prototype = {
 				break;
 	  		case 3:
 	  			if(this.days==null) {
-	  				returnstring = format(_("On %s. day every %s. month"),[day_in_month,interval]);
+	  				returnstring = format(_("On day %s every %s month(s)"),[day_in_month,interval]);
 	  			} else {
-	  				returnstring = format(_("On %s %s each %s. months"),[getCountString(day_in_month),getDayString(days),interval]);
+	  				returnstring = format(_("On %s %s each %s months"),[getCountString(day_in_month),getDayString(days),interval]);
 	  			}
 	  			break;
 	  		case 4:
 	  			if(this.days==null) {
-	  				returnstring = format(_("Each %s. %s"),[day_in_month,getMonthString(month)]);
+	  				returnstring = format(_("Each %s %s"),[day_in_month,getMonthString(month)]);
 	  			} else {
 	  				returnstring = format(_("On %s %s in %s"),[getCountString(day_in_month), getDayString(days),getMonthString(month)]);
 	  			}
@@ -256,6 +256,9 @@ SeriesView.prototype = {
 	toggleMiniSequenceStart : function() {
 		var tmp = $("series_duration_calendar_start");
 		if(tmp.style.display!="block") {
+			centerPopupWindow(tmp);
+			tmp.style.height = 210 + "px";
+			tmp.style.width = 228 + "px";
 			tmp.style.display = "block";
 		} else {
 			tmp.style.display = "none";
@@ -264,7 +267,13 @@ SeriesView.prototype = {
 	toggleMiniSequenceEnd : function() {
 		var tmp = $("series_duration_calendar_end");
 		if(tmp.style.display!="block") {
+			centerPopupWindow(tmp);
+			tmp.style.height = 210 + "px";
+			tmp.style.width = 228 + "px";
 			tmp.style.display = "block";
+			if ($("series_ending_date_2")) {
+			    $("series_ending_date_2").checked = "checked";
+		    }
 		} else {
 			tmp.style.display = "none";
 		}
@@ -322,9 +331,9 @@ SeriesView.prototype = {
 		function createCalendar() {
 			Self.sequenceStart = new cMiniCalendar(	$("begin_header_sequence"),$("begin_sequence"), 
 									series_setSequenceStartDate,false,'seq_begin',$("seq_begin_header_month"),$("seq_begin_header_year"));
-										
+
 			Self.sequenceEnd = new cMiniCalendar(	$("end_header_sequence"), $("end_sequence"), 
-										series_setSequenceEndDate,false,'seq_end',$("seq_end_header_month"),$("seq_end_header_year"));								
+										series_setSequenceEndDate,false,'seq_end',$("seq_end_header_month"),$("seq_end_header_year"));
 		}
 		function createCombos() {
 			Self.series_content_month_day_in_month1 = new ComboBox3(window, "series_content_month_day_in_month:1", "7em", 0, true, null, 4);
@@ -375,8 +384,8 @@ SeriesView.prototype = {
 			Self.series_content_year_month1.addElement(_("December"),11);
 			Self.series_content_year_month1.getDomNode();
 			Self.series_content_year_days1 = new ComboBox3(window, "series_content_year_days:1", "9em", 0, true, null, 4);
-			Self.series_content_year_days1.addElement("Monday",2);
-			Self.series_content_year_days1.addElement("Tuesday",4);
+			Self.series_content_year_days1.addElement(_("Monday"),2);
+			Self.series_content_year_days1.addElement(_("Tuesday"),4);
 			Self.series_content_year_days1.addElement(_("Wednesday"),8);
 			Self.series_content_year_days1.addElement(_("Thursday"),16);
 			Self.series_content_year_days1.addElement(_("Friday"),32);
@@ -404,10 +413,11 @@ SeriesView.prototype = {
 //			showNode("modal-dialog");
 //			$("modal-dialog").style.display="block";
 			showNode("series_window");
+			centerPopupWindow($("series_window"));
 			$("series_window").style.display="block";
 			this.openView(module,startdate,enddate);
 		} else {
-			triggerEvent("OX_New_Error",4,_("You can't create a new series in a modified appointment."));
+			triggerEvent("OX_New_Error",4,_("You can't create a new recurrence in a modified appointment."));
 		}
 		
 		
