@@ -6,13 +6,18 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
  * 
  */
-function cAnimMiniCalendar(actionFunction, oDOMHeader) {
+
+var oMiniCalendar;
+var b3xViewLoaded;
+var calendarMiniJson = new JSONX();
+
+function cAnimMiniCalendar(actionFunction, oDOMHeader, nodes) {
 		this.initDate = new Date();
 		this.actionFunction = actionFunction;
 		this.MiniRefer = null;
@@ -25,35 +30,40 @@ function cAnimMiniCalendar(actionFunction, oDOMHeader) {
 		this.selectedId;
 		this.header = oDOMHeader;
 		this.header0;
+		this.nodes = nodes;
 		this.enable_action = configGetKey("modules.calendar.module");
 		var bDisplayApps = configGetKey("modules.calendar.module");		
 		if (!this.enable_action) {
 			actionFunction = function () { 
-				triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); 
+				triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender", window); 
 			};
 		}
+		
+		if (this.nodes == undefined) {
+			this.nodes = [ $("container_mini"), $("header_mini_month"), $("header_mini_year") ];
+		}
+		
 		this.MiniRefer = new cMiniCalendar(oDOMHeader,
-							$("container_mini"), actionFunction,bDisplayApps,
-					 		'mini_subcontainer_0', $("header_mini_month"),
-					 		$("header_mini_year"), this.initDate);
+				nodes[0], actionFunction,bDisplayApps,
+				'mini_subcontainer_0', nodes[1], nodes[2], this.initDate);
 		this.MiniRefer.dnd_enabled = true;
 		this.MiniRefer.enable_action = this.enable_action;
 		var Self = this;
 		
-		function fn_KWAction(arg) {		
-			var DOMTarget = (arg.target)?arg.target:arg.srcElement;
-			var sId = DOMTarget.id;
+		function fn_KWAction(arg) {
+			var DOMTarget = (arg.target) ? arg.target : arg.srcElement;
+			var sId = DOMTarget.id, aInf;
 			for (var indx in Self.MiniRefer.miniCalendarAssoc) {
-				var aInf = Self.MiniRefer.miniCalendarAssoc[indx];
-				if(aInf[3] == sId.split('_')[1]) {
+				aInf = Self.MiniRefer.miniCalendarAssoc[indx];
+				if (aInf[3] == sId.split('_')[1]) {
 					break;
 				}
 			}	
 			var nDate = aInf[0];
 			var oDate = new Date();
 			oDate.setDate(1);
-			oDate.setMonth(Self.MiniRefer.currentMonth);						
-			oDate.setFullYear(Self.MiniRefer.currentYear);						
+			oDate.setMonth(Self.MiniRefer.currentMonth);
+			oDate.setFullYear(Self.MiniRefer.currentYear);
 			if (aInf[1] == 1) {
 				oDate.setMonth(oDate.getMonth());
 			} else if (aInf[1] == 0) {
@@ -62,40 +72,38 @@ function cAnimMiniCalendar(actionFunction, oDOMHeader) {
 				oDate.setMonth(oDate.getMonth()-1);
 			}			
 			oDate.setDate(nDate);
-			function fn() {			    
-			    if (currentpath2[1] != "team") {
-			    	if (currentpath2[2] != "week") {
-			    		triggerEvent('OX_Switch_View','calendar/calendar/week');
-			    	}
-			    	objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
-					objWeekCalendarTool.setKW();
-					// notify via event
-				    triggerEvent("OX_Mini_Calendar_Date_Picked", oDate.getUTCFullYear(), 
-				    		oDate.getUTCMonth(), oDate.getUTCDate());
-			    }
-			    Self.MiniRefer.setSelectedByDate(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
-			}
-			// checking if activefolder is type of 'calendar', otherwise jump to standard folder 
-            var folder = oMainFolderTree.cache.fast_access[activefolder];
-            if (folder && folder.oxfolder.data.module == "calendar") {
-            	folder = activefolder;
-            } else {
-            	folder = configGetKey("folder.calendar");
-            }
-            setActiveFolder(folder,fn);            
+				    
+		    if (currentpath2[1] !== "team") {
+		        activeDay = oDate.getDate();
+		        activeMonth = oDate.getMonth();
+		        activeYear = oDate.getFullYear();
+		        Self.MiniRefer.setSelectedByDate(activeYear, activeMonth, activeDay);
+                ox.UIController.setModule({
+                    module: "calendar", 
+                    folder: "auto", 
+                    view: "calendar/calendar/week",
+                    force: "module",
+                    succes: function() {
+                      // notify via event
+                      triggerEvent("OX_Mini_Calendar_Date_Picked", oDate.getUTCFullYear(),
+                              oDate.getUTCMonth(), oDate.getUTCDate());
+                    }
+                });
+                oDate = nDate = DOMTarget = sId = null;
+		    }
 		}
 		function fn_DBLAction(arg) {
-			triggerEvent('OX_Before_Create_Calendar');
-			Self.MiniRefer.setSelectedByDate(Self.selectedYear, Self.selectedMonth, Self.selectedDate);
+		    Self.MiniRefer.setSelectedByDate(Self.selectedYear, Self.selectedMonth, Self.selectedDate);
+			triggerEvent("OX_Before_Create_Calendar");
 		}
 		// don't implement functions for CW clicks and double clicks; simple clicks are disabled in the constructor
 		if (this.enable_action) {
 			this.MiniRefer.setfnKWAction(fn_KWAction);
-			this.MiniRefer.setfnDBLAction(fn_DBLAction);	
+			this.MiniRefer.setfnDBLAction(fn_DBLAction);
 		} else {
-			this.MiniRefer.setfnKWAction(function() { 
-				    triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); 
-			});		
+			this.MiniRefer.setfnKWAction(function() {
+			    triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender", window);
+			});
 		}
 }
 cAnimMiniCalendar.prototype = {
@@ -134,14 +142,14 @@ cAnimMiniCalendar.prototype = {
 		return this.MiniRefer.loaded;		
 	},
 	
-	scroll: function(nDirection,cb_fn){
+	scroll: function(nDirection,cb_fn) {		
 		var Self = this;
-		var nStart = $("minical_slider").scrollLeft;
+		var nStart = jQuery(Self.nodes[0]).parent()[0].scrollLeft;
 		function do_scroll(nStep) {
 			if (nDirection > 0)
-				$("minical_slider").scrollLeft = Math.log(Math.pow(nStep,0.66))*66;
+				jQuery(Self.nodes[0]).parent()[0].scrollLeft = Math.log(Math.pow(nStep,0.66))*66;
 			else
-				$("minical_slider").scrollLeft = nStart - Math.log(Math.pow(nStep,0.66))*66;
+				jQuery(Self.nodes[0]).parent()[0].scrollLeft = nStart - Math.log(Math.pow(nStep,0.66))*66;
 		}
 		animate((configGetKey("gui.effects.fading") ? 750 : 0), 245, do_scroll,cb_fn);
 	},
@@ -162,17 +170,17 @@ cAnimMiniCalendar.prototype = {
 		var oNextTable = this.MiniRefer.getTable(Self.MiniRefer.oCalendar);
 		var switchsubContainer = newnode('div',{ left:"239px", position:"absolute" });
 		switchsubContainer.appendChild(oNextTable);
-		$("container_mini").appendChild(switchsubContainer);
+		this.nodes[0].appendChild(switchsubContainer);
 		this.animationInProgress = true;
-		$("minical_slider").scrollLeft = 0;
+		jQuery(this.nodes[0]).parent()[0].scrollLeft = 0;
 		this.MiniRefer.subcontainer.style.left = "0px";		
 		this.scroll(1, function(){
-								$("container_mini").removeChild(Self.MiniRefer.subcontainer);
-								Self.MiniRefer.subcontainer = switchsubContainer;
-								Self.animationInProgress = false;
-								if(Self.MiniRefer.displayAppointments)
-									Self.MiniRefer.update();						
-							});
+			Self.nodes[0].removeChild(Self.MiniRefer.subcontainer);
+			Self.MiniRefer.subcontainer = switchsubContainer;
+			Self.animationInProgress = false;
+			if(Self.MiniRefer.displayAppointments)
+				Self.MiniRefer.update();						
+		});
 	},
 	
 	back: function(num) {
@@ -191,29 +199,32 @@ cAnimMiniCalendar.prototype = {
 		var oNextTable = this.MiniRefer.getTable(Self.MiniRefer.oCalendar);
 		var switchsubContainer = newnode('div',{ left:"0px", position:"absolute" });
 		switchsubContainer.appendChild(oNextTable);
-		$("container_mini").insertBefore(switchsubContainer, this.MiniRefer.subcontainer);
+		this.nodes[0].insertBefore(switchsubContainer, this.MiniRefer.subcontainer);
 		this.animationInProgress = true;
 		this.MiniRefer.subcontainer.style.left = "239px";
-		$("minical_slider").scrollLeft = 245;
+		jQuery(this.nodes[0]).parent()[0].scrollLeft = 245;
 		this.scroll(-1,function (){
-								$("container_mini").removeChild(Self.MiniRefer.subcontainer);
-								Self.MiniRefer.subcontainer = switchsubContainer;
-								Self.animationInProgress = false;
-								if(Self.MiniRefer.displayAppointments)
-									Self.MiniRefer.update();
-							});
+			Self.nodes[0].removeChild(Self.MiniRefer.subcontainer);
+				Self.MiniRefer.subcontainer = switchsubContainer;
+				Self.animationInProgress = false;
+				if(Self.MiniRefer.displayAppointments)
+					Self.MiniRefer.update();
+			});
 	},
 	go_to: function(oDate){
 		this.MiniRefer.go_to(oDate);
 	},
 	
 	today: function() {
-		if (!this.checkloaded() || this.animationInProgress) return;
+	    
+	    if (!this.checkloaded() || this.animationInProgress) return;
         
-	    var today = new Date();
-	    activeDay=today.getUTCDate();
-        activeMonth=today.getUTCMonth();
-        activeYear=today.getUTCFullYear();
+		// get current date
+	    var today = new Date(now());
+	    // see Bug 17397 - [L3] 'Today' button in calendar only works for GMT
+	    activeDay = today.getUTCDate();
+        activeMonth = today.getUTCMonth();
+        activeYear = today.getUTCFullYear();
         
         // notify via event
         triggerEvent("OX_Mini_Calendar_Date_Picked", activeYear, activeMonth, activeDay);
@@ -228,12 +239,14 @@ cAnimMiniCalendar.prototype = {
                     loadMonthView();
                     break;
         	}
-            triggerEvent("OX_Switch_View",currentpath.join("/"));
+            triggerEvent("OX_Switch_View", currentpath.join("/"));
+            
         } else if (configContainsKey("folder.calendar")) {
-	        setActiveFolder(configGetKey("folder.calendar"), function () {
+	        ox.api.ui.setFolder(configGetKey("folder.calendar"), function () {
 	            triggerEvent("OX_Switch_View","calendar/calendar/day"); 
 	        });
         }
+        this.setSelectedByDate(activeYear, activeMonth, activeDay);
 		this.MiniRefer.go_to(new Date());		
 	},
 	
@@ -250,8 +263,8 @@ cAnimMiniCalendar.prototype = {
 		}
 		var oHeader = newnode('div',0,{id:'DOMHeaderMini' + this.MiniCalWidgets.length});			
 		var oMiniCalendarNext = new cMiniCalendar(oHeader,
-	 			$("container_mini"), this.actionFunction,true,'mini_subcontainer_'+this.MiniCalWidgets.length,
-	 													$("header_mini_month"),$("header_mini_year"),this.initDate);
+	 			this.nodes[0], this.actionFunction,true,'mini_subcontainer_'+this.MiniCalWidgets.length,
+	 			this.nodes[1],this.nodes[2],this.initDate);
 		if (oMiniCalendarNext.table)	 
 			oMiniCalendarNext.subcontainer.insertBefore(oHeader
 															,oMiniCalendarNext.table);
@@ -276,95 +289,7 @@ cAnimMiniCalendar.prototype = {
 	}	
 }
 
-function cMini3XCalendar(actionFunction, oDOMHeader) {
-		this.initDate = new Date();
-		this.actionFunction = actionFunction;
-		this.MiniCalWidgets = new Array();
-		
-		this.selectedDate = this.initDate.getDate();
-		this.selectedMonth = this.initDate.getMonth();
-		this.selectedYear = this.initDate.getFullYear();
-		
-		this.todayYear = this.selectedYear;
-		
-		this.selectedTime = this.initDate.getTime();
-		this.selectedId;
-		
-		this.header = oDOMHeader;
-		this.header0;
-		this.enable_action = configGetKey("modules.calendar.module");
-		var bDisplayApps = configGetKey("modules.calendar.module");
-		if(!this.enable_action) {
-			actionFunction = function () { triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); };
-		}
-		var oMiniCalendar1 = new cMiniCalendar(oDOMHeader,
-							$("container_mini"),actionFunction,bDisplayApps,
-						 		'mini_subcontainer_0',$("header_mini_month"),$("header_mini_year"),this.initDate);
-		oMiniCalendar1.enable_action = this.enable_action;
-		function fn_KWAction(arg)
-		{		
-			var DOMTarget = (arg.target)?arg.target:arg.srcElement;
-			var sId = DOMTarget.id;
-			for (var indx in oMiniCalendar1.miniCalendarAssoc)
-			{
-				var aInf = oMiniCalendar1.miniCalendarAssoc[indx];
-				if(aInf[3] == sId.split('_')[1])			
-				{
-					break;
-				}
-			}	
-			var nDate = aInf[0];
-			var oDate = new Date();
-			oDate.setDate(1);
-			oDate.setMonth(oMiniCalendar1.currentMonth);						
-			oDate.setFullYear(oMiniCalendar1.currentYear);						
-			if(aInf[1] == 1)
-			{
-				oDate.setMonth(oDate.getMonth());
-			}
-			else if(aInf[1] == 0)
-			{
-				oDate.setMonth(oDate.getMonth()-1);
-			}
-			else if(aInf[1] == 2)			
-			{
-				oDate.setMonth(oDate.getMonth()-1);
-			}
-			oDate.setDate(nDate);		
-			function fn()
-			{				
-				if((currentpath2[0] == "calendar") && 
-							(currentpath2[1] == "calendar") &&
-									(currentpath2[2] == "week"))
-				{
-					objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
-					objWeekCalendarTool.setKW();			
-				}
-				else
-				{
-					triggerEvent('OX_Switch_View','calendar/calendar/week');		
-					objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
-					objWeekCalendarTool.setKW();
-				}
-			}
-			setActiveFolder(configGetKey("folder.calendar"),fn);
-		}						 		
-		function fn_DBLAction(arg) {
-			triggerEvent('OX_Before_Create_Calendar');
-		}
-		
-		//don't implement functions for CW clicks and double clicks; simple clicks are disabled in the constructor
-		if(this.enable_action) {
-			oMiniCalendar1.setfnKWAction(fn_KWAction);
-			oMiniCalendar1.setfnDBLAction(fn_DBLAction);	
-		} else {
-			// if feature is not available
-			this.MiniRefer.setfnKWAction(function() { triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); });
-		}
-			
-		oMiniCalendar1.setSelectedByDate(this.selectedYear,this.selectedMonth,this.selectedDate);
-		this.MiniCalWidgets.push(oMiniCalendar1);
-}
+
 function comboMonthChanged(param,minical)
 {
 	var NextDate = new Date();
@@ -381,162 +306,40 @@ function comboYearChanged(param,minical)
 	NextDate.setUTCMonth(minical.currentMonth);			
 	minical.go_to(NextDate);
 }
-cMini3XCalendar.prototype = {
-	destroy: function ()
-	{
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			this.MiniCalWidgets[nIndx].destroy();
-		}
-	},
-	load: function ()
-	{
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			this.MiniCalWidgets[nIndx].load(this.MiniCalWidgets[nIndx]);
-		}
-	},
-	setSelectedByDate: function (year, month, day)
-	{
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			this.MiniCalWidgets[nIndx].setSelectedByDate(year, month, day);
-		}
-	},
-	update: function ()
-	{
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			this.MiniCalWidgets[nIndx].update();
-			this.MiniCalWidgets[nIndx].setToday();
-		}
-	},	
-	setSelected: function (sId)
-	{
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			//find calendar where id is defined
-			this.MiniCalWidgets[nIndx].setUnselected();	
-		}		
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			//find calendar where id is defined
-			if(this.MiniCalWidgets[nIndx].miniCalendarAssoc[sId])
-			{
-				this.MiniCalWidgets[nIndx].setSelected(sId);
-				this.selectedDate = this.MiniCalWidgets[nIndx].selectedDate;
-				this.selectedMonth = this.MiniCalWidgets[nIndx].selectedMonth;
-				this.selectedYear  = this.MiniCalWidgets[nIndx].selectedYear;
-				this.selectedTime = Date.UTC(this.MiniCalWidgets[nIndx].selectedYear,
-													this.MiniCalWidgets[nIndx].selectedMonth,
-															this.MiniCalWidgets[nIndx].selectedDate);
-				for(var nIndx2=0;nIndx2<this.MiniCalWidgets.length;nIndx2++)
-				{
-					this.MiniCalWidgets[nIndx2].selectedDate	= this.selectedDate;
-					this.MiniCalWidgets[nIndx2].selectedMonth	= this.selectedMonth;	
-					this.MiniCalWidgets[nIndx2].selectedYear	= this.selectedYear;
-					this.MiniCalWidgets[nIndx2].selectedTime	= this.selectedTime;
-			
-				}					
-			}
-		}
-	},	
-	checkloaded: function ()
-	{
-		//check all views were loaded
-		var bAllLoaded = 1;
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			bAllLoaded &= this.MiniCalWidgets[nIndx].loaded;
-		}
-		return bAllLoaded;		
-	},
-	next: function (num)
-	{	
-		if(!this.checkloaded())
-			return;
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-				this.MiniCalWidgets[nIndx].next(num);
-		}
-		
-		this.initDate.setMonth(this.initDate.getMonth()+num);
-		/*
-		if(this.header0)
-		{
-			this.header.innerHTML = this.MiniCalWidgets[0].currentYear;
-		}*/
-	},
-	back: function (num)
-	{
-		if(!this.checkloaded())
-			return;
-		for(var nIndx=0;nIndx<this.MiniCalWidgets.length;nIndx++)
-		{
-			this.MiniCalWidgets[nIndx].back();
-		}
-		this.initDate.setMonth(this.initDate.getMonth()-num);	
-		/*
-		if(this.header0)
-		{
-			this.header.innerHTML = this.MiniCalWidgets[0].currentYear;
-		}		
-		*/
-	},
-	addView: function ()
-	{
-		this.initDate.setMonth(this.initDate.getMonth()+1);		
-		if(!this.header0)	
-		{
-			var oHeader0 = newnode('div',0,{id:'DOMHeaderMini0'});	
-			this.header0  = oHeader0;
-			this.MiniCalWidgets[0].header = oHeader0;			
-			this.MiniCalWidgets[0].subcontainer.insertBefore(oHeader0,this.MiniCalWidgets[0].table);
-			this.MiniCalWidgets[0].updateHeaderMini();	
-			//this.header.innerHTML = this.MiniCalWidgets[0].currentYear;
-		}
-		var oHeader = newnode('div',0,{id:'DOMHeaderMini' + this.MiniCalWidgets.length});			
-		var oMiniCalendarNext = new cMiniCalendar(oHeader,
-	 			$("container_mini"),this.actionFunction,true,'mini_subcontainer_'+this.MiniCalWidgets.length,
-	 													$("header_mini_month"),$("header_mini_year"),this.initDate);
-		if(oMiniCalendarNext.table)	 
-			oMiniCalendarNext.subcontainer.insertBefore(oHeader
-															,oMiniCalendarNext.table);
-		else
-			oMiniCalendarNext.subcontainer.appendChild(oHeader);
-		this.MiniCalWidgets.push(oMiniCalendarNext);
-	},
-	removeView: function ()
-	{
-		if(this.header0)
-		{
-			this.MiniCalWidgets[0].subcontainer.removeChild(this.header0);			
-			this.MiniCalWidgets[0].header = this.header;
-			this.header0 = null;
-			this.MiniCalWidgets[0].updateHeaderMini();				
-		}
-		this.initDate.setMonth(this.initDate.getMonth()-1);
-		var oMonthView = this.MiniCalWidgets.pop();
-		if(oMonthView)
-		{
-			oMonthView.subcontainer.removeChild(oMonthView.header);
-			oMonthView.destroy();
-		}
-	}	
-}
 
+/**
+ * Our current mini-calendar
+ * @param {DOMNode} displayPanelContainer Used by cAnimMiniCalendar.removeView,
+ * which in turn is not used (anymore). 
+ * @param {DOMNode} container The container for the calendar contents.
+ * @param {Function} actionFunction A callback function which is called when
+ * the user clicks on a day. It should call setSelected(this.id) to process
+ * the selection.
+ * @param {Boolean} bDisplayAppointments Specifies whether days with
+ * appointments should be marked.
+ * @param {String} subcontainerid Not used.
+ * @param {DOMNode} displayPanelContainerM container of the month selection
+ * ComboBox.
+ * @param {DOMNode} displayPanelContainerY container of the year selection
+ * ComboBox.
+ * @param {Date} initDate Specifies a date to display initially.
+ * Defaults to the current month.
+ * @param {Date} selectedDate The selected date. Defaults to today.
+ */
 function cMiniCalendar(displayPanelContainer, container, actionFunction,
 			bDisplayAppointments, subcontainerid, displayPanelContainerM,
 				displayPanelContainerY, initDate, selectedDate) {
 	this.enable_action = true;
-	this.aMonthNames = new Array('January','February','March','April','May',
-								'June','July','August','September','October','November','December');
+	this.aMonthNames = [_("January"), _("February"), _("March"), _("April"),
+        _("May"), _("June"), _("July"), _("August"), _("September"),
+        _("October"), _("November"), _("December")];
 	this.container = container;
 	this.table;
 	this.loaded = false;
 	this.dnd_enabled = false;
 	this.subcontainerid = subcontainerid || "min_subcontainer_default";
-	this.subcontainer = newnode('div');	
+	this.subcontainer = newnode('div', { left:"0px", right:"0px",position:"absolute" });
+	jQuery(this.container).parent()[0].scrollLeft = 0;
 	this.container.appendChild(this.subcontainer);
 	addTMPId(this.subcontainer);
 	this.header = displayPanelContainer;
@@ -544,10 +347,11 @@ function cMiniCalendar(displayPanelContainer, container, actionFunction,
 	this.header_year = displayPanelContainerY;	
 	this.actionFN = actionFunction;
 	this.displayAppointments = bDisplayAppointments;
-	var odat = new Date();
-	this.todayDate = odat.getDate();
-	this.todayMonth = odat.getMonth();	
-	this.todayYear = odat.getFullYear();
+	// get today (see bug #17397)
+	var odat = new Date(now());
+	this.todayYear = odat.getUTCFullYear();
+	this.todayMonth = odat.getUTCMonth();
+	this.todayDate = odat.getUTCDate();
 	if (initDate) {
 		this.currentMonth = initDate.getUTCMonth();
 		this.currentYear = initDate.getUTCFullYear();
@@ -581,10 +385,16 @@ function cMiniCalendar(displayPanelContainer, container, actionFunction,
 }	
 
 cMiniCalendar.prototype = {
-	setfnDBLAction: function (fn) {
+	/**
+	 * Specifies a callback for the double-click on a day.
+	 */
+    setfnDBLAction: function (fn) {
 		this.actionDBLFN = fn;
 	},
 	
+	/**
+	 * Specifies a callback for the click on a week number.
+	 */
 	setfnKWAction: function(fn) {
 		this.fnKWAction = fn;
 	},
@@ -609,6 +419,10 @@ cMiniCalendar.prototype = {
 		this.loaded = false;
 	},
 	
+	/**
+	 * Jumps to the next month.
+     * Does not change the selection.
+	 */
 	next: function(num) {
 		if(num == undefined) num = 1;
 		if(!this.loaded) return;
@@ -626,6 +440,10 @@ cMiniCalendar.prototype = {
 		this.load(this);
 	},
 	
+    /**
+     * Jumps to the previous month.
+     * Does not change the selection.
+     */
 	back: function(num) {
 		if(num == undefined) num = 1;
 		if(!this.loaded) return;
@@ -643,6 +461,10 @@ cMiniCalendar.prototype = {
 		this.load(this);
 	},
 	
+    /**
+     * Jumps to the specified month.
+     * Does not change the selection.
+     */
 	go_to: function(oDateLoc) {
 		if (!this.loaded) return;
 		this.destroy();
@@ -664,14 +486,19 @@ cMiniCalendar.prototype = {
 	load: function(obj) {
 		this.oCalendar = new cCalendar(this.currentMonth,this.currentYear);
 		if (this.header_month && !this.oComboMonth && !this.oComboYear) {
-			this.oComboMonth = new ComboBoxSpecial(window, this.header_month.id, '7em', this.todayMonth, 
-																	false, 'OX_Select_MiniMonth', 6,this) ;
-			this.oComboYear = new ComboBoxSpecial(window, this.header_year.id, '3em', 5, 
-																	false, 'OX_Select_MiniYear', 10,this) ;
+			this.oComboMonth = new ComboBoxSpecial(
+			    window, this.header_month, '7em', this.todayMonth, 
+			    false, 'OX_Select_MiniMonth', 6, this
+			);
+			this.oComboYear = new ComboBoxSpecial(
+			    window, this.header_year, '3em', 3, 
+				false, 'OX_Select_MiniYear', 6, this
+			);
 			this.oComboYear.optWidth = "4em";
 			this.oComboYear.show_buttons = true;
-			for (var nKeyIndx=-5; nKeyIndx < 5; nKeyIndx++){
-				this.oComboYear.addElement((this.todayYear+nKeyIndx),(this.todayYear+nKeyIndx));
+			for (var nKeyIndx=-3; nKeyIndx < 3; nKeyIndx++){
+				this.oComboYear.addElement(noI18n(this.todayYear+nKeyIndx),
+				                           this.todayYear+nKeyIndx);
 			}
 			for (var nKeyIndx=0;nKeyIndx<this.aMonthNames.length;nKeyIndx++) {
 				this.oComboMonth.addElement(this.aMonthNames[nKeyIndx], nKeyIndx);
@@ -722,8 +549,7 @@ cMiniCalendar.prototype = {
 					obj.appointmentList = cbobjCalendar.data;					
 				} else if(cbobjCalendar && cbobjCalendar.error) {
 					newServerError(cbobjCalendar,4);
-				} else
-					triggerEvent('OX_New_Error', 2 ,'Internal Error: No callback parameter in MINICALENDER');
+				}
 				obj.create();
 			}
 			this.getCalObjMC(oFirstDayDate,oLastDayDate,cb_fkt_mc);					
@@ -737,6 +563,10 @@ cMiniCalendar.prototype = {
 		calendarMiniJson.get(sAjaxRequest, null, callback);
 	},	
 	
+    /**
+     * Updates the markings of days with appointments, if
+     * the bDisplayAppointments parameter to the constructor was true.
+     */
 	update: function() {
 		//TODO
 		var oFirstDayDate = new Date();
@@ -774,10 +604,8 @@ cMiniCalendar.prototype = {
 				Self.appointmentList = cbobjCalendar.data;					
 			} else if(cbobjCalendar && cbobjCalendar.error) {
 				newServerError(cbobjCalendar);
-			} else {
-				triggerEvent('OX_New_Error', 2 ,'Internal Error: No callback parameter in MINICALENDER');
 			}
-			Self.refreshView();			
+			Self.refreshView();
 		}
 		if (this.displayAppointments) {
 			this.getCalObjMC(oFirstDayDate,oLastDayDate,fn_refreshCurrentMiniCal);
@@ -816,19 +644,15 @@ cMiniCalendar.prototype = {
 		var Self = this;
 		var nAllDaysCount = 0;
 		var oTable = newnode("table", {}, { 
-			className: "CalMiniMainTable1 background-color-content border-color-content-default", 
+			className: "CalMiniMainTable1", 
 				cellPadding: 0, cellSpacing: 0, border: 0 });
 		this.table = oTable;
 		var oTableBody = newnode('tbody');	// IE specific
 		var oTRHead = newnode('tr');
-		var weekDays = [
-            { c: "monday"   /*i18n context*/, t: "M"/*i18n*/ },
-            { c: "tuesday"  /*i18n context*/, t: "T"/*i18n*/ },
-            { c: "wednesday"/*i18n context*/, t: "W"/*i18n*/ },
-            { c: "thursday" /*i18n context*/, t: "T"/*i18n*/ },
-            { c: "friday"   /*i18n context*/, t: "F"/*i18n*/ },
-            { c: "saturday" /*i18n context*/, t: "S"/*i18n*/ },
-            { c: "sunday"   /*i18n context*/, t: "S"/*i18n*/ }];
+		var weekDays = [pgettext("monday", "M"), pgettext("tuesday", "T"),
+                        pgettext("wednesday", "W"), pgettext("thursday", "T"),
+                        pgettext("friday", "F"), pgettext("saturday", "S"),
+                        pgettext("sunday", "S")];
         
         var _nTd = newnode('td', { height:"2em", padding:"0px" }, { className: "cursorPointer" });
         if (this.fnKWAction != null) {
@@ -837,22 +661,14 @@ cMiniCalendar.prototype = {
 	            activeDay=1;
 	            activeMonth=Self.currentMonth;
 	            activeYear=Self.currentYear;
-	            
 	            Self.setSelectedByDate(activeYear, activeMonth, activeDay);
-	            if (currentpath2[0] == "calendar") {
-                    loadMonthView();
-                    triggerEvent("OX_Switch_View","calendar/calendar/month");
-	            } else if (configContainsKey("folder.calendar")) {
-	                setActiveFolder(configGetKey("folder.calendar"), function () {
-	                    triggerEvent("OX_Switch_View","calendar/calendar/month"); 
-	                });
-	            }
-	        };       	
+                ox.UIController.setModule({module: "calendar", folder:"auto", view:"calendar/calendar/week",force: "module"});
+	        };
         }
         oTRHead.appendChild(_nTd);
         for (var i=0; i<weekDays.length; i++) {
             var HeadTD = newnode('td', { height:"2em", padding:"0px" }, 0,
-                [addTranslated(weekDays[i].t, weekDays[i].c)]);
+                [addTranslated(weekDays[i])]);
 			oTRHead.appendChild(HeadTD);
 		}
 		oTRHead.className = "miniCalendarTRHead dateCalendarFontSize background-color-additional-content font-style-headline";
@@ -870,8 +686,10 @@ cMiniCalendar.prototype = {
 				if (!this.enable_action || !this.fnKWAction) {
  					oKWTD.className += " cursorReset";		 			
  				}
+				
 				if (this.fnKWAction != null) {	
 					addDOMEvent(oKWTD, "click", this.fnKWAction);
+					
 				}
 				oTR.appendChild(oKWTD);
 				addTMPId(oKWTD);
@@ -943,7 +761,9 @@ cMiniCalendar.prototype = {
 						oTD.style.MozUserSelect = "none";
 						oTD.ondblclick = this.actionDBLFN;
 					}
-					oTD.onclick = this.actionFN;		
+
+					oTD.onclick = this.actionFN;
+								
 					oTR.appendChild(oTD);
 					addTMPId(oTD);
 					function fnOver(node) {
@@ -1025,6 +845,13 @@ cMiniCalendar.prototype = {
 		return oTable;
 	},
 	
+	/**
+	 * Selects the specified day, switching to the appropriate month view if
+	 * necessary.
+	 * @param {Number} year The year of the day to select.
+	 * @param {Number} month The month of the day to select.
+	 * @param {Number} day The date of the day to select.
+	 */
 	setSelectedByDate: function(year, month, day) {
 		this.selectedDate = day;
 		this.selectedMonth = month;		
@@ -1071,6 +898,11 @@ cMiniCalendar.prototype = {
 			this.go_to(oDateLoc);
 		}
 	},
+	
+	/**
+	 * Updates the today marking.
+	 * Just in case the user was logged in past midnight...
+	 */
 	setToday: function() {
 		var todayDate = new Date();
 		this.todayDate = todayDate.getDate();
@@ -1110,43 +942,54 @@ cMiniCalendar.prototype = {
  			} 				 			
 		}
 	},	
-	setSelected: function (sId)
-	{
+	/**
+	 * Selects a day by its internal DOM node ID.
+	 * Used by the actionFunction constructor parameter to actually process
+	 * the selection.
+	 */
+	setSelected: function (sId) {
 		//deselect
-		if(this.selectedID)
-			this.setUnselected();
+		if (this.selectedID) {
+		    this.setUnselected();
+		}
 		
 		//select
 		this.selectedID = sId;
 		var oDateOthMonth = new Date();
 		oDateOthMonth.setFullYear(this.currentYear);
 		oDateOthMonth.setDate(1);	
-		oDateOthMonth.setMonth(this.currentMonth);	 	
+		oDateOthMonth.setMonth(this.currentMonth);
 		var back=1;
-		if(this.miniCalendarAssoc[sId][1] == 0)	
-		{
-			oDateOthMonth.setMonth(oDateOthMonth.getMonth()-1);
-			var back=0;
+		if(this.miniCalendarAssoc[sId][1] == 0) {
+		    oDateOthMonth.setMonth(oDateOthMonth.getMonth() - 1);
+		    var back = 0;
+		} else if(this.miniCalendarAssoc[sId][1] == 2) {
+		    oDateOthMonth.setMonth(oDateOthMonth.getMonth() + 1);
+		    var back = 2;
 		}
-		else if(this.miniCalendarAssoc[sId][1] == 2)	
-		{
-			oDateOthMonth.setMonth(oDateOthMonth.getMonth()+1);			
-			var back=2;			
-		}
-		oDateOthMonth.setDate(this.miniCalendarAssoc[sId][0]);				
+		oDateOthMonth.setDate(this.miniCalendarAssoc[sId][0]);
 		this.selectedMonth = oDateOthMonth.getMonth();
 		this.selectedYear = oDateOthMonth.getFullYear();
 		this.selectedDate = oDateOthMonth.getDate();
-		
 		this.selectedTime = oDateOthMonth.getTime();
-
-		oTD = $2(sId);
-		oTD.className += ' background-color-PMG-selection-elements';
-		if(back==0)
-			this.back();
-		if(back==2)
-			this.next();			
+		
+		jQuery("#" + this.selectedID, this.subcontainer).addClass("background-color-PMG-selection-elements");
+		
+		if (back==0) {
+		    this.back();
+		} else if (back==2) {
+		    this.next();
+		}
 	},
+	
+	/**
+	 * Returns the date of the day with the specified internal DOM node ID.
+	 * @protected
+	 * @param {String} sId The internal DOM node ID of the day.
+	 * @type Date
+	 * @return A Date object with the date of the specified day and
+	 * with the current time of day.
+	 */
 	getDateByID : function (sId)
 	{
 		var oDateOthMonth = new Date(null);
@@ -1165,6 +1008,10 @@ cMiniCalendar.prototype = {
 		oDateOthMonth.setUTCDate(this.miniCalendarAssoc[sId][0]);			
 		return oDateOthMonth;		
 	},
+	/**
+	 * Hides the selection temporarily.
+	 */
+    // Bug: Navigation calls like next/back show the selection again.
 	setUnselected: function ()
 	{
 		var oTD = $2(this.selectedID);
