@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -14,13 +14,10 @@
  */
 // TEST DATA
 var nNumCharAppointmentView = 10;
-var calendarJson = new JSON();
+var calendarJson = new JSONX();
 //Global Vars
 var monthViewCreated = false;
 var calendarObjects;
-var nMonthGlob; 
-var nYearGlob;
-var tmptimeOutDouble = false;
 var tmptimeOutSingle = null;
 var aAppointmentAssoc = new Object();
 var sAssocMonthArray = new Object();
@@ -41,14 +38,8 @@ function showAllAppointmentsMonth(){
 }
 
 function refreshMonthView(changeFolder) {
-	if (changeFolder!=undefined && changeFolder) {
+	if (changeFolder === true) {
 		oMonthViewObj.refreshMonthView(calendar_getAllFoldersAttribute());
-	} else {
-		function fn() {
-			if(!configContainsKey("gui.calendar.allfolders"))	
-				oMonthViewObj.refreshMonthView(calendar_getAllFoldersAttribute());
-		}
-		//oMonthViewObj.getStorage();
 	}
 }
 
@@ -109,7 +100,6 @@ function loadMonthView() {
 			function fn() {
 				oMonthViewObj.refreshMonthView(calendar_getAllFoldersAttribute());
 			}
-			//storageCache.update(fn);
 			oMonthViewObj.getStorage(fn);
 		} else {
 			goToActiveMonth();
@@ -126,7 +116,6 @@ function goToActiveMonth() {
 		oDateLoc.setMonth(activeMonth); 		
 		oMonthViewObj.oCalendarTool = new calendarTool(activeMonth, activeYear);	
 		oMonthViewObj.updateMonthView();
-		refreshMonthView();
 	}
 }
 
@@ -137,12 +126,12 @@ function goToNextMonth(nDirection) {
 		oDateLoc.setUTCDate(1);   
         oDateLoc.setUTCMonth(oDateLoc.getUTCMonth()+(nDirection));
         activeMonth = oDateLoc.getUTCMonth();
-        activeYear = oDateLoc.getUTCFullYear();     
-        activeDay = oDateLoc.getUTCDate();					
+        activeYear = oDateLoc.getUTCFullYear();
+        activeDay = oDateLoc.getUTCDate();
+        triggerEvent("Date_Changed", activeYear, activeMonth, activeDay);
 		if (oMiniCalendar) oMiniCalendar.setSelectedByDate(activeYear, activeMonth, activeDay);
 		oMonthViewObj.oCalendarTool = new calendarTool(activeMonth, activeYear);	
 		oMonthViewObj.updateMonthView();
-		refreshMonthView();
 	}
 }
 
@@ -307,6 +296,13 @@ function monthView() {
 	this.redraw = function (){};
 	this.show_we = 1;
 	this.show_ww = 2;
+	// month headline
+	this.headline = new I18nNode(function() {
+        return formatDateTime("MMMM yyyy", new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0)));
+    });
+	if (!$("monthviewheader").firstChild) {
+	    $("monthviewheader").appendChild(this.headline.node);
+	}
 }
 
 function moveAppToNewStart(objc, startTimeParam, endTimeParam, fn_opt) {
@@ -318,8 +314,7 @@ function moveAppToNewStart(objc, startTimeParam, endTimeParam, fn_opt) {
 
 monthView.prototype = {
 	updateHeader: function() {
-		$("monthviewheader").firstChild.data = 
-		       formatDateTime("MM/yyyy", new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0)));
+	    this.headline.update();
 	},
 	
 	loadMonthView: function(bAll) {
@@ -336,7 +331,7 @@ monthView.prototype = {
 	    //Old, use refresh function
 		calendarObjects = new Array();
 		this.dateIdAssoc = new Object();
-		this.aAppointmentAssoc = new Object();
+		this.aAppointmentAssoc = aAppointmentAssoc= new Object();
 		sAssocMonthArray = new Object();
 		var calendar = $("calmain");
 		while (calendar.childNodes.length>0) {
@@ -373,6 +368,7 @@ monthView.prototype = {
 				height = (((calendar.offsetHeight - pxPerEm) / numWeeks));		
 				
 			function drawpreviewDragandDrop(evt,type,object) {	
+                stopEvent(evt);
 				var subObject = object;
 				if(object && object.currentObjects && object.currentObjects.length>0) {
 						subObject = object.currentObjects[0]; 
@@ -399,7 +395,6 @@ monthView.prototype = {
 								 && sId.split('_')[3] != 'headcontainer')			
 					DOMTarget.className += " dndSelectionCalendarBG";
 				DOMTarget.style.cursor = "move";
-				stopEvent(evt);
 				return false;							
 			}
 			function removeDDPreviewDivs(evt,type,object) {
@@ -414,42 +409,48 @@ monthView.prototype = {
 				DOMTarget.className = removeClass(DOMTarget.className,"dndSelectionCalendarBG");
 			}					
 	
-			function dropCallBack(evt,dragType,object,mousepos,targetNode) {
+			function dropCallBack(evt, dragType, object, mousepos, targetNode) {
 				var subObject = object;
-				if(object && object.currentObjects && object.currentObjects.length>0) {
-						subObject = object.currentObjects[0]; 
+				if (object && object.currentObjects && object.currentObjects.length>0) {
+				    subObject = object.currentObjects[0]; 
 				}
-				var DOMTarget = targetNode;//(evt.currentTarget)?evt.currentTarget:evt.srcElement;			
-				var DOMTarget2 = (evt.target)?evt.target:evt.srcElement;
+				var DOMTarget = targetNode;
+				var DOMTarget2 = (evt.target) ? evt.target : evt.srcElement;
 				DOMTarget2.style.cursor = "default";			
 				var sId = DOMTarget.id;	
-				if(!sId || !sAssocMonthArray[sId+'_num'])
-					return;					
-				var oDate = new Date();
 				
-				//var oDate=new Date(Date.UTC(sAssocMonthArray[sId+'_num'].year,sAssocMonthArray[sId+'_num'].month,sAssocMonthArray[sId+'_num'].day.nDate,0,0,0));
-				oDate.setUTCHours(0);		
-				oDate.setUTCMinutes(0);					
-				oDate.setUTCSeconds(0);								
-				oDate.setUTCDate(1);		
-				oDate.setUTCFullYear(sAssocMonthArray[sId+'_num'].year);				
-				oDate.setUTCMonth(sAssocMonthArray[sId+'_num'].month);				
-				if(sAssocMonthArray[sId+'_num'].day.nCurrMonth == 0)
-					oDate.setUTCMonth(oDate.getUTCMonth()-1);
-				else if(sAssocMonthArray[sId+'_num'].day.nCurrMonth == 2)			
-					oDate.setUTCMonth(oDate.getUTCMonth()+1);			
-				oDate.setUTCDate(sAssocMonthArray[sId+'_num'].day.nDate);					
-				var start_date = new Date(subObject.start_date);
-				var end_date = new Date(subObject.end_date);	
-				oDate.setUTCHours(start_date.getUTCHours());
-				oDate.setUTCMinutes(start_date.getUTCMinutes());
-				var changes=oDate.getTime()-start_date.getTime();
-				var oDateEnd=new Date(end_date.getTime()+changes);	
-				moveAppToNewStart(subObject,oDate,oDateEnd);
-				DOMTarget.className = removeClass(DOMTarget.className,"dndSelectionCalendarBG");			
-				if($2("dnd_div_") != undefined)
+				if (!sId || !sAssocMonthArray[sId+'_num']) {
+					return;
+				}
+				var assoc = sAssocMonthArray[sId + '_num'];
+				var month = assoc.month;
+				
+				if (assoc.day.nCurrMonth == 0) {
+					month--;
+				} else if(assoc.day.nCurrMonth == 2) {
+					month++;
+				}
+				
+				var oDate = new Date(Date.UTC(assoc.year, month, assoc.day.nDate, 0, 0, 0));
+				
+				// getting super object holding the real app data
+				var oDateEnd = new Date(oDate.getTime());
+				for (var i in oMonthViewObj.aMonthBtAppointments) {
+				    var obj = oMonthViewObj.aMonthBtAppointments[i];
+				    if (obj.id === subObject.id) {
+				        oDate.setUTCHours(new Date(obj.start_date).getUTCHours());
+		                oDate.setUTCMinutes(new Date(obj.start_date).getUTCMinutes());
+		                oDateEnd=new Date(oDate.getTime() + (obj.end_date - obj.start_date));
+				        break;
+				    }
+				}
+				
+				moveAppToNewStart(subObject, oDate, oDateEnd);
+				DOMTarget.className = removeClass(DOMTarget.className, "dndSelectionCalendarBG");
+				if ($2("dnd_div_") != undefined) {
 					body.removeChild($2("dnd_div_"));
 					removeTMPId($2("dnd_div_"));
+				}
 			}
 			for (ind=0; ind<numWeeks; ind++) {
 				//clone
@@ -460,7 +461,7 @@ monthView.prototype = {
 				obj.id = sIdPrefix[0]+'_'+nextWeekNumber;
 				addTMPId(obj);	
 				//change Ids here		
-				for (numNode=0; numNode<obj.childNodes.length; numNode++) {					
+				for (numNode=0; numNode<obj.childNodes.length; numNode++) {
 					if (obj.childNodes[numNode].id == "kwnumber_0") {
 						newId = 'kwnumber_'+ nextWeekNumber;
 						obj.childNodes[numNode].id = newId;
@@ -561,7 +562,7 @@ monthView.prototype = {
 		MULTstartDate.setUTCHours(0);
 		
 		var MULTendDate = new Date(end_date);		
-		MULTendDate.setUTCHours(0)
+		MULTendDate.setUTCHours(0);
 	
 		//Create multiday appointments here
 		var nDaysMultiDay = Math.round((((MULTendDate.getTime() - MULTstartDate.getTime()))  / 1000 / 60 / 60 / 24));
@@ -574,7 +575,7 @@ monthView.prototype = {
 			var oCurrDayIter = new Date(startDate);				
 			for (var nNumDay=0; nNumDay<=nDaysMultiDay; nNumDay++) {
 				//do nothing at start day - that's default case
-				if (nNumDay != 0) {		
+				if (nNumDay != 0) {
 					this.doDrawAppointment(oCurrDayIter, calendarObjects, index, nNumDay<nDaysMultiDay);				
 				}
 				oCurrDayIter.setUTCDate(oCurrDayIter.getUTCDate()+1);
@@ -590,8 +591,8 @@ monthView.prototype = {
 		var constBottom = 7;
 		var constBottomBorder = 1;
 		var constAppointmentPlusBorderPlusMargin = pxPerEm*1.1 + 4 + 1;	
-	    var calc_ww = (workWeekHeight - constHeader - constBottom - constBottomBorder) / constAppointmentPlusBorderPlusMargin
-	    var calc_we = (weekEndHeight - constHeader - constBottom - constBottomBorder) / constAppointmentPlusBorderPlusMargin
+	    var calc_ww = (workWeekHeight - constHeader - constBottom - constBottomBorder) / constAppointmentPlusBorderPlusMargin;
+	    var calc_we = (weekEndHeight - constHeader - constBottom - constBottomBorder) / constAppointmentPlusBorderPlusMargin;
 		this.show_ww = IE6 ? Math.floor(calc_ww) : Math.ceil(calc_ww);
 		this.show_we = IE6 ? Math.floor(calc_we) : Math.ceil(calc_we);
 		this.redraw();
@@ -636,17 +637,17 @@ monthView.prototype = {
 			this.aAppointmentAssoc[sAppId] = calendarObjects;
 		}
 		oViewObj.app++;
-					
+		
 		if (oViewObj.app == (this.show_ww + 1) && !oViewObj.day.bWeekend || 
 		    oViewObj.app == (this.show_we + 1) && oViewObj.day.bWeekend ) {
 			
 			var oButtonDiv = getContentAsDiv('','expandButton','but_'+sCurrId);
 			addDOMEvent(oButtonDiv,'click',monthAction);
 			$2(sCurrId).appendChild(oButtonDiv);
-			addTMPId(oButtonDiv)		
-			oViewObj.app++;					
-		}	
-						
+			addTMPId(oButtonDiv);
+			oViewObj.app++;
+		}
+		
 		if (oViewObj.day.bWeekend && oViewObj.app > 0 && $2(sCurrId+'_0_app')) {
 			$2(sCurrId+'_0_app').style.height = "1.0em";
 			$2(sCurrId+'_0_app').style.lineHeight = "1.0em";
@@ -654,9 +655,9 @@ monthView.prototype = {
 	
 		var aSelected = calendarSelection.getSelected();
 		for (var nindx=0; nindx < aSelected.length; nindx++) {
-			if(id == aSelected[nindx].id && folder_id == aSelected[nindx].folder && $2(sAppId)) {			
+			if(id == aSelected[nindx].id && folder_id == aSelected[nindx].folder && $2(sAppId)) {
 				$2(sAppId).className = removeClass($2(sAppId).className,
-				'border-color-image');			
+				'border-color-image');
 				$2(sAppId).className += ' selectedAppMonth border-color-selection-elements';
 				aSelectedAppArray.push(sAppId);
 				break;
@@ -691,7 +692,7 @@ monthView.prototype = {
 	},
 	
 	//Initialize month view with calendar data, add Appointments
-	initMonthView: function() {	
+	initMonthView: function() {
 		    var Self = this;	
 			var aAppointments = new Array();
 			this.oCalendar = new cCalendar(this.oCalendarTool.nMonth,this.oCalendarTool.nYear);
@@ -723,35 +724,24 @@ monthView.prototype = {
 																className:"fullTimeAppointmentMonthTitle"});														
 					
 					
-					if(isToday(currDateObj))
-						var bgCurrentDay = " background-color-PMG-selection-elements";
-					else 
-						var bgCurrentDay = "";
-					if(currentDay.bWeekend)
-						dDiv =  getContentAsDiv(currentDay.nDate,"dateCalendarFontSize dateAlignMonthView"+bgCurrentDay,sCurrId+'_num');
-					else					
-						dDiv =  getContentAsDiv(currentDay.nDate,"dateCalendarFontSize dateAlignMonthView"+bgCurrentDay,sCurrId+'_num');
-					if(!currentDay.bWeekend)
-						var oHeadDiv = newnode('div',0,{className:"headerContStyle",id:sCurrId+"_headcontainer"});
-					else					
-						var oHeadDiv = newnode('div',0,{className:"headerContStyle",id:sCurrId+"_headcontainer"});					
+					var dDiv = getContentAsDiv(currentDay.nDate,"dateCalendarFontSize dateAlignMonthView", sCurrId+'_num');
+					var oHeadDiv = newnode('div',0,{className:"headerContStyle",id:sCurrId+"_headcontainer"});
 		
 					oHeadDiv.appendChild(ShowFullTimeDiv);
 					addTMPId(ShowFullTimeDiv);
-					oHeadDiv.appendChild(dDiv);				
+					oHeadDiv.appendChild(dDiv);
 					addTMPId(dDiv);
 					addDOMEvent(dDiv,"selectstart",function (e) {
 						stopEvent(e);
 						return false;
-					});					
-					addDOMEvent(dDiv,"click",monthAction);						
-					addDOMEvent(dDiv,"dblclick",monthAction);														
-					if(this.today.getUTCFullYear() == currDateObj.getUTCFullYear() &&
-									this.today.getUTCMonth() == currDateObj.getUTCMonth() &&
-												this.today.getUTCDate() == currDateObj.getUTCDate())
-					{
-						$2(sCurrId).className += " background-color-content";
+					});
+					addDOMEvent(dDiv,"click",monthAction);
+					addDOMEvent(dDiv,"dblclick",monthAction);
+					
+					if (isLocalToday(currDateObj)) {
+						$2(sCurrId).className += " todayBackground";
 					}
+					
 					$2(sCurrId).appendChild(oHeadDiv);
 					addTMPId(oHeadDiv);
 					
@@ -772,7 +762,7 @@ monthView.prototype = {
 					{	
 						//set date date of month
 						this.calendar_end = new Date(currDateObj);
-						this.calendar_end.setDate(this.calendar_end.getDate()+1)
+						this.calendar_end.setDate(this.calendar_end.getDate()+1);
 						try{
 							$2(sCurrId).parentNode.style.borderBottom = "1px solid";
 							$2(sCurrId).parentNode.className += " border-color-image";
@@ -803,17 +793,17 @@ monthView.prototype = {
                         }
                         $2('kwnumber_'+indexWeek).className = removeClass($2('kwnumber_'+indexWeek).className, "background-color-PMG-selection-elements");
 						triggerEvent('OX_Switch_View','calendar/calendar/week');
-					}
+					};
                 })(this.oCalendar, indexWeek));
                 addDOMEvent($2('kwnumber_'+indexWeek), "mouseover", (function(indexWeek) {
                 	return function(e) {
                         $2('kwnumber_'+indexWeek).className += " background-color-PMG-selection-elements";
-                	}
+                	};
                 })(indexWeek));
                 addDOMEvent($2('kwnumber_'+indexWeek), "mouseout", (function(indexWeek) {
                 	return function(e) {
                         $2('kwnumber_'+indexWeek).className = removeClass($2('kwnumber_'+indexWeek).className, "background-color-PMG-selection-elements");
-                	}
+                	};
                 })(indexWeek));
                 
 											
@@ -823,146 +813,105 @@ monthView.prototype = {
 	},
 	
 	buildAppointments: function(index, object) {
-		    var newObject = {
-		    	id: object[0], // 1
-		    	folder: object[1], // 20
-		    	recurrence_position: object[2] || 0, // 207
-		    	recurrence_id: object[3], // 206
-		    	created_by: object[4], // 2
-		    	title: object[5], // 200
-		    	start_date: object[6], // 201
-		    	end_date: object[7], // 202
-		    	note: object[8], // 203
-		        recurrence_type: object[9], // 209
-		        participants: object[10], // 221
-		        full_time: object[11], // 401
-		        shown_as: object[12], // 402
-		        color_label: object[13], // 102
-		        location: object[14], // 400
-		        categories: object[15], // 100
-		        private_flag: object[16] // 101
-		    }
-		    newObject["indxxx"] = index;
-		    object["indxxx"] = index;
-			this.aMonthBtAppointments[index] = newObject;
+        var newObject = convertAppointmentArray(object);
+        newObject["indxxx"] = index;
+        object["indxxx"] = index;
+        this.aMonthBtAppointments[index] = newObject;
 	},
 	
-	sortAppointments: function() {	
-		this.aMonthBtAppointments.sort(
-			function(a, b){
-				return (a.full_time || a.start_date < b.start_date ? -1 : 1); 
-			}
-		);
-		for(var i=0; i<this.aMonthBtAppointments.length;i++) {
-			this.attachAppointments(this.aMonthBtAppointments[i]["indxxx"],this.aMonthBtAppointments[i]);
+	sortAppointments: function () {
+	    // vars
+	    var apps = this.aMonthBtAppointments, i = 0, $i = apps.length, app;
+	    // sort appointments (for whatever reason; would be nice to know)
+	    function monthSorter(a, b) {
+	        if (a.full_time) {
+                return -1;
+            } else if (b.full_time) {
+                return 1;
+            } else {
+                return a.start_date < b.start_date ? -1 : 1;
+            }
+	    }
+		apps.sort(monthSorter);
+		// loop over appointments
+		for (; i < $i; i++) {
+		    app = apps[i];
+			this.attachAppointments(app.indxxx, app);
 		}
 	},
-	
+
 	getStorage: function(fnParamComplete) {
-		var Self = this;
-		function cb_fkt(storage) {
-			monthViewCreated = true;		
-			if (storage) {			
-				Self.storage = storage;
-			}		
-			monthViewCreated = true;		
-			Self.redraw = function() {
-				Self.clearMonthView();					
-				Self.storage.newIterate(Self.storage.ids, emptyFunction, function(x,y) {
-					Self.buildAppointments(x,y);
-				},
-				function() {
-					Self.sortAppointments();
-				});
-				monthViewCreated = true;				
-				Self.timestamp = storage.timestamp;
-				lastUpdateOfCalendarTimestamp  = Self.storage.timestamp;
-				calendar_HeaderUpdate(Self.storage.ids.length);
-			};
-				
-			Self.storage.events.register("Changed", Self.redraw);			
+	    var Self = this;
+        if (this.storage) {
+            this.storage.events.unregister("Changed", function() {
+                Self.updateView();
+            });
+        }
+        this.clearMonthView();
+        var oChDate = this.getDateFromDay(this.oCalendar.aWeeks[0].aDays[0]);
+        var starttime = oChDate.getTime();
+        oChDate = this.getDateFromDay(this.oCalendar.aWeeks[this.oCalendar.aWeeks.length-1].aDays[6]);
+        oChDate.setUTCDate(oChDate.getUTCDate()+1);
+        var endtime = oChDate.getTime();
+        if (Self.show_all) {
+            var oParameters = { action:"all", start:starttime, end:endtime, columns:"1,20,207,206,2" };
+        } else {        
+            var oParameters = { action:"all", start:starttime, end:endtime, folder:activefolder, columns:"1,20,207,206,2" };
+        }   
+        oParameters.showPrivate = true;
+        storageCache.get(AjaxRoot + "/calendar", 
+                oParameters, 
+                function(storage) {
+                    storageCache.current = storage;
+                    calendarSelection.setStorage(storage);
+                    calendarSelection.reset();
+                    storageCache.update();
+                    Self.iterateStorage(storage);
+                    lastUpdateOfCalendarTimestamp  = storage.timestamp;
+                    if (fnParamComplete !== undefined) {
+                        fnParamComplete();
+                    }
+                },
+                 this.calendarwfields.toString(),
+                 true,
+                 calendar_serializeid,
+                 calendar_makeID);
+    },
+    
+    updateView: function() {
+        this.clearMonthView();
+        this.iterateStorage();
+        lastUpdateOfCalendarTimestamp = storageCache.current.timestamp;
+        calendar_HeaderUpdate(this.storage.ids.length);
+    },
+    
+    iterateStorage: function(storage) {
+        var Self = this;
+        if (storage) {
+            Self.storage = storage;
+            Self.storage.events.register("Changed", function() {
+                Self.updateView();
+            });
+        }
+        Self.storage.newIterate(Self.storage.ids, emptyFunction, function(x,y) {
+            Self.buildAppointments(x,y);
+        },function(){
+            Self.sortAppointments();
+        });
+        monthViewCreated = true;
+    }, 
 
-			storage.newIterate(storage.ids, emptyFunction, function(x,y) {
-				Self.buildAppointments(x,y);	
-			}, function () {
-				//duplicated entries
-				Self.sortAppointments();
-			 	storageCache.update();		
-			});	
-			if (fnParamComplete != undefined) {		
-				fnParamComplete();	
-			}
-		}			
-		sFolderId = activefolder;		
-		var oChDate = this.getDateFromDay(this.oCalendar.aWeeks[0].aDays[0]);
-		var starttime = oChDate.getTime();
-		oChDate = this.getDateFromDay(this.oCalendar.aWeeks[this.oCalendar.aWeeks.length-1].aDays[6]);
-		oChDate.setUTCDate(oChDate.getUTCDate()+1);
-		var endtime = oChDate.getTime();
-		if (Self.show_all) {
-			var oParameters = { action:"all", start:starttime, end:endtime, columns:"1,20,207,206,2" };
-		} else {		
-			var oParameters = { action:"all", start:starttime, end:endtime, folder:sFolderId, columns:"1,20,207,206,2" };
-		}	
-		oParameters.showPrivate = true;
-		storageCache.get(AjaxRoot + "/calendar", oParameters, 
-		                function(storage) {
-						 	cb_fkt(storage);
-							calendarSelection.setStorage(storage);
-							calendarSelection.reset();
-							Self.timestamp = storage.timestamp;
-							lastUpdateOfCalendarTimestamp  = storage.timestamp; 
-						},
-						 this.calendarwfields.toString(),
-						 true,
-						 calendar_serializeid,
-				         calendar_makeID);	
-	},
-
-	clearMonthView: function() {	
+	clearMonthView: function() {
 		//loop day divs
-		for(var nItem in sAssocMonthArray) {
-			var aTMP = nItem.split('_');
-			var sDayDivId = '';
-			//remove postfix of current id
-			for (var nIndx=0; nIndx<aTMP.length-1; nIndx++) {
-				sDayDivId += aTMP[nIndx];
-				if (nIndx < aTMP.length-2) sDayDivId += '_';
-			}
-			var currentDayDiv = $2(sDayDivId);
-	
-			//find and remove appointments and expand buttons
-			var aNodesToRemove = new Array();
-			for (var nNodeX=0; nNodeX < currentDayDiv.childNodes.length; nNodeX++) {
-				var currentChild;
-				if (currentChild = currentDayDiv.childNodes[nNodeX]) {
-					var sPostfix = '';
-					var sPrefix = '';
-					if (currentChild.id) {
-						var aTMP2 = currentChild.id.split('_');
-						sPostfix = aTMP2[aTMP2.length-1];	
-						sPrefix = aTMP2[0];			
-					}
-					if (sPostfix == 'app' || sPrefix == 'but') {					
-						aNodesToRemove.push(currentChild);
-					}
-					if (sPostfix == 'headcontainer') {	
-						for(var nDivIndx=0; nDivIndx<currentChild.childNodes.length; nDivIndx++) {
-							if (currentChild.childNodes[nDivIndx].id.split('_')[3] == 'title') {
-								removeChildNodes(currentChild.childNodes[nDivIndx]);					
-								currentChild.childNodes[nDivIndx].className = 'fullTimeAppointmentMonthTitle';
-							}
-						}
-					}
-				}
-			}
-			for(var nNodeTR=0; nNodeTR<aNodesToRemove.length; nNodeTR++) {
-				currentDayDiv.removeChild(aNodesToRemove[nNodeTR]);
-			}
+		for (var id in sAssocMonthArray) {
+		    var nodes = jQuery($2(id.slice(0, -4))).children();
+		    nodes.filter('[id$="_app"],[id^="but_"]').remove();
+		    nodes.filter('[id$="_headcontainer"]>[id$="_title"]')
+		        .empty().attr('class', 'fullTimeAppointmentMonthTitle');
 		}
-		aAppointmentAssoc = new Object();
-		this.aMonthBtAppointments  = new Array();
-		aSelectedAppArray = new Array();
+		this.aAppointmentAssoc = new Object();
+		this.aMonthBtAppointments = new Array();
+		this.aSelectedAppArray = aSelectedAppArray = new Array();
 		monthViewCreated = false;	
 		for(var i in this.dateIdAssoc) {
 			this.dateIdAssoc[i].app = 0;
@@ -972,12 +921,11 @@ monthView.prototype = {
 	
 	refreshMonthView: function(bAll) {
 		this.show_all = bAll;
-		if(calendar_getAllFoldersAttribute()){
+		if (calendar_getAllFoldersAttribute()){
 			$("allAppointmentMonthView").checked = true;
+		} else {
+			$("allAppointmentMonthView").checked = false;
 		}
-		else
-			$("allAppointmentMonthView").checked = false;	
-		oMonthViewObj.clearMonthView();
 		oMonthViewObj.getStorage();
 	},
 	
@@ -1007,7 +955,7 @@ monthView.prototype = {
 	},
 	
 	getAppointmentDiv: function(calendarObjects,sId,fullday,isMultiday) {
-		var owner = getFolderOwner(activefolder);
+		var owner = activeFolderOwner;
 		var isPrivateShared = (owner !== configGetKey('identifier') && calendarObjects.private_flag === true);
 		
 		var appointmentDate = new Date(calendarObjects.start_date);
@@ -1021,7 +969,7 @@ monthView.prototype = {
 						"appInMonthView border-color-image")} );
 		
 		// setting background color depending on categories, if set
-		var backColor = " background-color-content";
+		var backColor = "";
 		if (calendarObjects.categories) {
 			// getting the first color out of the categories list
 			var cat = ox.categories.getFirstMatch(calendarObjects.categories);
@@ -1040,7 +988,7 @@ monthView.prototype = {
 			timeDisplayString += " - " + calendarObjects.location;
 		}
 		
-		var owner = getFolderOwner(activefolder);
+		var owner = activeFolderOwner;
 		
 		// setting confirmation styles
 		if (calendarObjects.participants.length) {
@@ -1173,7 +1121,8 @@ function getSelectMonthView(evt){
 	}
 	selectedAppointment = { 
         id:oObj.id, folder:oObj.folder, recurrence_position:oObj.recurrence_position, 
-        recurrence_id:oObj.recurrence_id, created_by:oObj.created_by
+        recurrence_id:oObj.recurrence_id, created_by:oObj.created_by, 
+        participants: oObj.participants
     };
 	calendarSelection.click(oMonthViewObj.aAppointmentAssoc[sDOMId].index);
 	triggerEvent("Selected", [ selectedAppointment ]);
