@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Suphi Basdemir <suphi.basdemir@open-xchange.com>
@@ -70,11 +70,11 @@ WeekCalendarTool.prototype = {
                     }
                 } catch (e) { /*see default implementation*/ }
             };
-			hover.onShow = function (node) {
+			hover.onShow = function (node, manual) {
 				OXAppointmentHover.actualHover=this;
 				var splitid=node.oxcalobj.split("-");
 				OXAppointmentHover.refillContent(splitid[1],splitid[0],splitid[2]);	
-			}
+			};
 		}
 		
 		if (configGetKey("gui.effects.hover.calendar") && calendarhovers["week"]) {
@@ -148,6 +148,7 @@ WeekCalendarTool.prototype = {
 		var Self = this;
 		
 		function drawpreviewDragandDrop(evt,type,object) {
+		    stopEvent(evt);
 			var subObject = object;
 			if(object && object.currentObjects && object.currentObjects.length>0) {
 					subObject = object.currentObjects[0]; 
@@ -287,9 +288,15 @@ WeekCalendarTool.prototype = {
 				addDOMEvent(nCurrContent, 'dblclick', openNewAppointmentInWeek);	
 				addDOMEvent(nCurrHeader, 'dblclick', openNewWholeAppointmentInWeek);
 				
-				Self.yearUTC=Self.oMonday.getUTCFullYear();	
-				nCurrHeader.className = isToday(Self.oMonday) 
-				        ? "background-color-PMG-selection-elements" : "";
+				Self.yearUTC=Self.oMonday.getUTCFullYear();
+				
+				// today?
+				var node = jQuery(nCurrHeader.parentNode);
+				if (isLocalToday(Self.oMonday)) {
+				    node.addClass("todayBackground");
+				} else {
+				    node.removeClass("todayBackground");
+				}
 
 				nCurrHeader.firstChild.nodeValue = formatDate(Self.oMonday,"dateday");
 				Self.oMonday.setUTCDate(Self.oMonday.getUTCDate()+1);
@@ -327,6 +334,7 @@ WeekCalendarTool.prototype = {
 			Self.timer = 700;
 		}
 		
+		triggerEvent("Date_Changed", activeYear, activeMonth, activeDay);
 		if (oMiniCalendar) oMiniCalendar.setSelectedByDate(activeYear, activeMonth, activeDay);
 	},
 	clearTimer: function() {
@@ -376,14 +384,14 @@ WeekCalendarTool.prototype = {
 		Self.params.start=Self.starttime;
 		Self.params.end=endtime;		
 		Self.params.columns="1,20,207";
-		if(!Self.showallappointments) {
-			Self.params.folder= activefolder;
+		if (!Self.showallappointments) {
+			Self.params.folder= ox.UIController.getFolder();
 		}
 		Self.params.showPrivate = true;
 		storageCache.get(AjaxRoot + "/calendar",
 		 Self.params,
 		 function(storage) {
-		 	Self.weekAppointments = new Array()
+		 	Self.weekAppointments = new Array();
 		 	for (var t = 0; t< Self.displayedWeekLinks.length; t++)
 		 		Self.displayedWeekLinks[t].style.display = "none";
 		 		
@@ -442,7 +450,8 @@ WeekCalendarTool.prototype = {
 		var shownDiv = getShownDiv(object.shown_as);
 		
 		var divIconParticipant = newnode("div", {},{ className: "showAppointmentSeqWeek"});
-		if(object.participants && object.participants.length > 1) {
+		
+		if (isGroupAppointment(object.participants)) {
 			var imageGroupFlag=document.createElement("img");
 			imageGroupFlag.setAttribute("src",getFullImgSrc("img/calendar/group.gif"));
 			divIconParticipant.appendChild(imageGroupFlag);
@@ -468,7 +477,7 @@ WeekCalendarTool.prototype = {
 		if (object.full_time) {
 			datDIV.className = 'textFullTimeWeek wholeDayBackground border-color-design borderDefault';
 		} else {
-			datDIV.className = 'appInWeekView borderDefault background-color-content border-color-design';
+			datDIV.className = 'appInWeekView borderDefault border-color-design';
 		}
 		textDiv = newnode('div');
 		textDiv.className = "showAppointmentTextWeek mozSelected";
@@ -497,6 +506,18 @@ WeekCalendarTool.prototype = {
 		this.object = object;
 		this.object.index = index;
 		
+		// consolidate users and participants (field 220 and 221)
+        for (var i in object[16]) {
+            var a1 = object[16][i];
+            for (var ia in object[8]) {
+                if (object[8][ia].id == a1.id) {
+                    a1.confirmation = object[8][ia].confirmation;
+                    if (object[8][ia].confirmmessage) a1.confirmmessage = object[8][ia].confirmmessage;
+                    break;
+                }
+            }
+        }
+		
 		var id = this.object[0];
 		var folder = this.object[1];
 		var recurrencePos = this.object[2] || 0;	
@@ -514,7 +535,7 @@ WeekCalendarTool.prototype = {
 		var createdBy = this.object[15];
 		var participants = this.object[16];
 		var categories = this.object[17];
-		var owner = getFolderOwner(activefolder);
+		var owner = activeFolderOwner;
 		var oneday=1000*60*60*24;
 		
 		var isPrivateShared = (owner !== configGetKey('identifier') && privateFlag === true);
@@ -523,7 +544,8 @@ WeekCalendarTool.prototype = {
 		
 		var selectedAppointmentWeek = { 
 			id: id, folder: folder, recurrence_position: recurrencePos, 
-			recurrence_id: recurrenceID, created_by: createdBy 
+			recurrence_id: recurrenceID, created_by: createdBy, 
+			participants: participants
 		};
 		
 		var	appObject = {
@@ -535,7 +557,6 @@ WeekCalendarTool.prototype = {
 			    recurrence_type: this.object[7]
 		};
 		
-		
 		// app start date before week start?
 		if (start_date < this.starttime) {
 			start_date = this.starttime;
@@ -549,7 +570,7 @@ WeekCalendarTool.prototype = {
 		/******* INIT NODE TEMPLATE *******/
 		
 		var divIconParticipant = newnode("div", {},{ className: "showAppointmentSeqWeek"});
-		if (participants && participants.length > 1) {
+		if (isGroupAppointment(participants)) {
 			var imageGroupFlag=document.createElement("img");
 			imageGroupFlag.setAttribute("src",getFullImgSrc("img/calendar/group.gif"));
 			divIconParticipant.appendChild(imageGroupFlag);
@@ -591,7 +612,7 @@ WeekCalendarTool.prototype = {
 
 		appNode.appendChild(document.createTextNode(" "));
 		var cName = "appInWeekView border-color-design borderDefault";
-		var backColor = "background-color-content";
+		var backColor = "";
 		if (isFullTime) {
 			cName = "textFullTimeWeek border-color-design borderDefault";
 			backColor = "wholeDayBackground";
@@ -615,7 +636,7 @@ WeekCalendarTool.prototype = {
 
 		var textDiv = newnode("div");
 		textDiv.className = "showAppointmentTextWeek";
-		var textToView = title;
+		var textToView = title || "";
 		if (location) {
 			textToView += " - " + location;
 		}
@@ -626,16 +647,16 @@ WeekCalendarTool.prototype = {
 				if (participants[i].id == owner) {
 					switch(participants[i].confirmation) {
 						case 0:
-							datDIV.style.opacity = ".6";
+							contentDiv.style.opacity = ".6";
 							textDiv.style.fontStyle = "italic";
-							textToView = "(" + _("waiting") + ")";
+							textToView += " (" + _("waiting") + ")";
 							break;
 						case 2:
 							textDiv.style.textDecoration = "line-through";
 							break;
 						case 3:											
 							textDiv.style.fontStyle = "italic";
-							textToView = "(" + _("tentative") + ")";
+							textToView += " (" + _("tentative") + ")";
 							break;
 					}
 				}
