@@ -6,7 +6,7 @@
  * ,
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -14,13 +14,9 @@
  */
 /* IE FIX */
 register("Loaded", function () {
-	if((document.all) && (window.offscreenBuffering)) {
-		changeClassAttributes(".wwline","height","19px");		
-	}
 	addDOMEvent($("calendarWorkweek"), "click" ,function(e) {
-		if (calendarSelection.count != 0) {
+		if (calendarSelection.count !== 0) {
 			cwwchangeSelected();
-			cwwchangeSelectedFull();
 			calendarSelection.reset();
 			selectedAppointment = null;
 			triggerEvent("Selected",[]);
@@ -29,10 +25,13 @@ register("Loaded", function () {
 });
 
 register("OX_Configuration_Changed", function () {
-	if (calendarinittemplates) {
+    var path = currentpath[2];
+	if (calendarinittemplates && path !== "day" 
+	    && path !== "workweek" && path !== "custom") {
         calendarinittemplates=false;
         createTemplatesWW(getWWInterval(), getWWStartTime(), getWWEndTime());
     }
+	path = null;
 });
 
 var maxappointmentsperday=3;
@@ -62,20 +61,15 @@ function cwwdisable() {
 var allcalendarobjects=new Object();
 var wwhovers=new Object();
 function default_calendar_workweek_create_object(module,folder) {
-	
-	if(module=="calendar")
-	{
-		if(!calendar_activedate) {
-//			var myinterval=configGetKey("gui.calendar.interval");
+	if (module=="calendar") {
+		if (!calendar_activedate) {
 			var myinterval=15;
-			var d=new Date();			
-			d.setUTCDate(1);
-			d.setUTCMonth(activeMonth);
-			d.setUTCFullYear(activeYear);
-			d.setUTCDate(activeDay);
-			d.setUTCHours(d.getHours());
+			var d = new Date(now());
+			if (activeYear && activeMonth && activeDay) {
+			    d.setUTCFullYear(activeYear, activeMonth, activeDay);
+			}
 			var mymin=d.getUTCMinutes();
-			if(mymin % myinterval) {
+			if (mymin % myinterval) {
 				mymin=mymin - (mymin % myinterval)+ myinterval;
 			}
 			d.setUTCMinutes(mymin);
@@ -87,7 +81,7 @@ function default_calendar_workweek_create_object(module,folder) {
 	calendar_activedate=null;
 	calendar_wholeday=null;
 }
-function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,created_by,title,start_date,end_date,note,recurrence_type,participants,full_time,shown_as,color_label,location,private_flag,interval,categories)
+function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,created_by,title,start_date,end_date,note,recurrence_type,participants,full_time,shown_as,color_label,location,private_flag,interval,categories,users)
 {
 	this.index;
 	this.selected=false;
@@ -110,6 +104,9 @@ function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,cr
 	this.interval=interval;
 	this.categories=categories;
 	this.divs=new Object();
+	// this must really be subject to a total rebuild
+	// adding just another property
+	this.users = users;
 }
 CalendarWorkWeekObject.prototype = {
 	addDiv : function (id,node) {
@@ -144,85 +141,74 @@ function cww_onShowAllAppointmentsChanged(mybool) {
 	updateWWView(oDateLoc);
 }
 
-function showCalendarWorkweek() {	
-	if(!firstenter) {
-		var callbacks=new Object();
-		callbacks["CALENDAR_BOTTOM"]=function(event,dragType,data,mouseposition,targetNode) { cww_saveAppointment(data,event,"CALENDAR_BOTTOM");  }
-		callbacks["calendar"]=function(event,dragType,data,mouseposition,targetNode) { cww_saveAppointment(data.currentObjects[0],event,"calendar",false);  }
-		callbacks["CALENDAR_TOP"]=function(event,dragType,data,mouseposition,targetNode) { cww_saveAppointment(data,event,"CALENDAR_TOP");  }
-		callbacks["CALENDAR_NEW"]=function(event,dragType,data,mouseposition,targetNode) { cww_createAppointment(data,event,"CALENDAR_NEW",mouseposition,createPreviewNewAppointmentWW) } 
-		registerTarget($("cwwtimecontentall"),callbacks,null,null,
-		function(event,type,object,mouseposition) { 
-			if(type=="CALENDAR_NEW") {
-				drawpreviewnewAppointment(event,type,object,mouseposition)
-			} else if (type == "calendar") {
-				if(object && object.currentObjects && object.currentObjects.length>0) {
-					drawpreviewDragandDrop(event,type,object.currentObjects[0]); 
-				}
-			}
-			else {
-				drawpreviewDragandDrop(event,type,object); 
-			}
-		},
-		function(event,type,object,mouseposition) { 
-			if(type=="CALENDAR_NEW") {
-				drawpreviewnewAppointment(event,type,object,mouseposition)
-			} else if (type == "calendar") {
-				if(object && object.currentObjects && object.currentObjects.length>0) {
-					drawpreviewDragandDrop(event,type,object.currentObjects[0]); 
-				}
-			} else {
-				drawpreviewDragandDrop(event,type,object); 
-			}
-		},
-		function(event,type,object) { removeDDPreviewDivs(); } );
-				
-		function disabled(e) {
-			var iconNode = $2("dragdrop_default_node");
-			if(iconNode == undefined) {
-				iconNode = newnode("div", {left: (e.clientX + iconOffset) + "px",top: (e.clientY + iconOffset) + "px"},
- 			    { className : "dragdropdefaultnode background-color-default border-color-design", id: "dragdrop_default_node"},[
- 			    	newnode("table",{ width:"100%" , height: "100%" },{ cellPadding:"0" , cellSpacing :"0" , border : "0" },[
- 			    		newnode("tbody",null,null,[
- 			    			newnode("tr",null,null,[
- 			    				newnode("td",null,null,[
- 			    					newnode("img",{},{ src : getFullImgSrc("img/dnd_disabled.gif") },[])
- 			    				]),
- 			    				newnode("td",{ fontSize : "8pt", whiteSpace : "nowrap" },null,[
- 			    					newnode("div",{ overflow: "hidden"},null,[addTranslated("No subject")])
- 			    				])
- 			    			])
- 			    		])
- 			    	])
- 			    ]);
-				body.appendChild(iconNode);
-				addTMPId(iconNode);
-			}
-			iconNode.style.left = (e.clientX + iconOffset) + "px";
-			iconNode.style.top = (e.clientY + iconOffset)+ "px";
-			stopEvent(e);
-			return false;
-		}
-		function disabledremove(e) {
-			if($2("dragdrop_default_node")) {
-				$2("dragdrop_default_node").parentNode.removeChild($2("dragdrop_default_node"));
-				removeTMPId($2("dragdrop_default_node"));	
-			}
-			
-		}
-		registerSource($("cwwcontentresize"),"CALENDAR_NEW",function () { return null; },null,null,disabled,disabledremove);
-		firstenter=true;
-	}
+function showCalendarWorkweek() {
+    if (!firstenter) {
+        var callbacks = new Object();
+        callbacks["CALENDAR_BOTTOM"] = function(event, dragType, data, mouseposition, targetNode) {
+            cww_saveAppointment(data, event, "CALENDAR_BOTTOM"); 
+        };
+        callbacks["calendar"] = function(event, dragType, data, mouseposition, targetNode) {
+            cww_saveAppointment(data.currentObjects[0], event, "calendar", false); 
+        };
+        
+        callbacks["CALENDAR_TOP"] = function(event, dragType, data, mouseposition, targetNode) {
+            cww_saveAppointment(data, event, "CALENDAR_TOP");
+        };
+        
+        callbacks["CALENDAR_NEW"] = function(event, dragType, data, mouseposition, targetNode) {
+            cww_createAppointment(data , event, "CALENDAR_NEW", mouseposition, createPreviewNewAppointmentWW);
+        };
+        
+        registerTarget($("cwwtimecontentall"), callbacks, null, null,
+            function (event,type,object,mouseposition) {
+                if (type == "CALENDAR_NEW") {
+                    drawpreviewnewAppointment(event, type, object, mouseposition);
+                } else if (type == "calendar") {
+                    if (object && object.currentObjects && object.currentObjects.length > 0) {
+                        drawpreviewDragandDrop(event, type, object.currentObjects[0]); 
+                    }
+                } else {
+                    drawpreviewDragandDrop(event, type, object);
+                }
+            },
+            function (event,type,object,mouseposition) {
+                if (type == "CALENDAR_NEW") {
+                    drawpreviewnewAppointment(event, type, object, mouseposition);
+                } else if (type == "calendar") {
+                    if (object && object.currentObjects && object.currentObjects.length > 0) {
+                        drawpreviewDragandDrop(event, type, object.currentObjects[0]);
+                    }
+                } else {
+                    drawpreviewDragandDrop(event, type, object);
+                }
+            },
+            function(event,type,object) {
+                removeDDPreviewDivs();
+            }
+        );
+        
+        registerSource($("cwwcontentresize"), 
+            "CALENDAR_NEW",
+            function () {
+                return null;
+            },
+            null, null,
+            jQuery.noop, jQuery.noop
+        );
+        
+        firstenter = true;
+    }
+
 	function checkChanges() {
         if (cwwdaysinweek != cww_oldvalues.cwwdaysinweek) { 
-            return true; 
+            return true;
         }
         return false;
     }
 
     var tmpinterval=getWWInterval();
     var tmpstarttime=getWWStartTime();
-    var tmpendtime=getWWEndTime();        
+    var tmpendtime=getWWEndTime();
     
     if (!calendarinittemplates || checkChanges()) {
         createTemplatesWW(tmpinterval,tmpstarttime,tmpendtime);
@@ -232,7 +218,7 @@ function showCalendarWorkweek() {
     
     var scrollpoint=tmpstarttime/tmpinterval;
     setTimeout(function() {
-        $("cwwtimecontentall").scrollTop=(scrollpoint*20); 
+        $("cwwtimecontentall").scrollTop=((scrollpoint*20)+1); 
     },0);    
 	
 	showallappointments=calendar_getAllFoldersAttribute();
@@ -242,7 +228,7 @@ function showCalendarWorkweek() {
 }
 
 function getWWInterval() {
-	var tmpinterval=15*60000;
+	var tmpinterval=30*60000;
 	if (configContainsKey("gui.calendar.interval")) {
         tmpinterval=configGetKey("gui.calendar.interval")*60000;
     }
@@ -258,7 +244,7 @@ function getWWStartTime() {
 }
 
 function getWWEndTime() {
-    var tmpendtime=17*60*60000;
+    var tmpendtime=18*60*60000;
     if (configContainsKey("gui.calendar.endtime")) {
         tmpendtime=configGetKey("gui.calendar.endtime")*60*60000;
     }
@@ -309,8 +295,10 @@ function cwwchangeView(days,view){
 function goToNextWeek(nDirection)
 {
 	var step=1;
-	if(currentpath2.join("/") == "calendar/calendar/workweek"  || currentpath2.join("/") == "calendar/list/workweek")  { step = 7 }
-	if(currentpath2.join("/") == "calendar/calendar/custom"  || currentpath2.join("/") == "calendar/list/custom")  { step = configGetKey("gui.calendar.custom.countdays") }
+	if (currentpath2.join("/") == "calendar/calendar/workweek"  || currentpath2.join("/") == "calendar/list/workweek")  { step = 7 }
+	if (currentpath2.join("/") == "calendar/calendar/custom"  || currentpath2.join("/") == "calendar/list/custom") {
+	    step = ox.api.config.get("gui.calendar.custom.countdays", 3); 
+	}
 	var oDateLoc = new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0));	
 	oDateLoc.setUTCDate(oDateLoc.getUTCDate()+(nDirection*step));	
 	activeMonth = oDateLoc.getUTCMonth();
@@ -321,6 +309,7 @@ function goToNextWeek(nDirection)
 	} else {
 		startofweek=oDateLoc.getUTCDay(); 
 	}
+	triggerEvent("Date_Changed", activeYear, activeMonth, activeDay);
 	oMiniCalendar.setSelectedByDate(activeYear, activeMonth, activeDay);
 	updateWWView(oDateLoc);
 }
@@ -359,24 +348,27 @@ function updateHeaderWW(oDateLoc) {
 		if (currentpath2.join("/") == "calendar/calendar/workweek" || currentpath2.join("/") == "calendar/calendar/custom") {
 			var sId = 'singleDay' + (indDay) + 'stWw';			
 			var nCurrHeader = $2(sId);
-			//if (!nCurrHeader) continue;
-			if (isToday(oMonday))
-				nCurrHeader.className = "font-color-default background-color-PMG-selection-elements";
-			else 
-				nCurrHeader.className = "font-color-default";
-				
+			// set class name
+			nCurrHeader.className = "font-color-default";
+            // change proper parent's class name
+			var node = jQuery(nCurrHeader).parents(".appointmentViewHeadBG");
+			// today?
+			if (isLocalToday(oMonday)) {
+			    node.addClass("todayBackground");
+			} else {
+			    node.removeClass("todayBackground");
+			}
 			nCurrHeader.innerHTML = formatDate(oMonday,"dateday"); 
 			if( nCurrHeader.style.display!="") { nCurrHeader.style.display=""; }
-			oMonday.setDate(oMonday.getDate()+1);
+			oMonday.setUTCDate(oMonday.getUTCDate()+1);
 
 		} else {
 			var sId = 'singleDay' + (indDay) + 'stWw';
 			var nCurrHeader  = $2(sId);
 			//if (!nCurrHeader) continue;
 			removeChildNodes(nCurrHeader);
-			var document1=document.createTextNode(".");
 			nCurrHeader.className += " font-color-selected";
-			nCurrHeader.appendChild(document1); 
+			nCurrHeader.appendChild(document.createTextNode(".")); 
 		}
 	}
 }
@@ -458,16 +450,21 @@ function showCalendarObject(index,object) {
     var calendarobject = new CalendarWorkWeekObject(object[0], object[1],
         object[2] || 0, object[3], object[4], object[5], object[6], object[7],
         object[8], object[9], object[16], object[11], object[12], object[13],
-        object[14], object[15], object[17], object[18]);
+        object[14], object[15], object[17], object[18], object[10]);
 	calendarobject.index=index;
-	allcalendarobjects[""+calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position]=calendarobject;		
+	var hash = new String(calendarobject.folder_id) + "-" + calendarobject.id + "-" + calendarobject.recurrence_position;
+	// object already exists, ignore
+	if (!allcalendarobjects[hash]) {
+	    allcalendarobjects[hash] = calendarobject;
+	}
 	cwwdrawAppointment(calendarobject);
 }
 function cwwchangeSelected(elementid) {
-	if(calendarSelection.count != 0) {
-		calendarSelection.reset();		
+    // reset previous selection
+	if (calendarSelection.count != 0) {
+		calendarSelection.reset();
 	}
-	for(var myzaehler in allcalendarobjects) {
+	for (var myzaehler in allcalendarobjects) {
 		for(var myzaehler2 in allcalendarobjects[myzaehler].divs) {
 			var tds = allcalendarobjects[myzaehler].divs[myzaehler2].getElementsByTagName("td");
 			var divs = allcalendarobjects[myzaehler].divs[myzaehler2].getElementsByTagName("div");			
@@ -522,43 +519,33 @@ function cwwchangeSelected(elementid) {
 	}
 	
 	if (elementid) {
+	    // toggle
 		calendarSelection.toggle(allcalendarobjects[elementid].index);
-		selectedAppointment = { 
-			id: allcalendarobjects[elementid].id, folder: allcalendarobjects[elementid].folder_id, 
-			recurrence_position: allcalendarobjects[elementid].recurrence_position, 
-			recurrence_id: allcalendarobjects[elementid].recurrence_id, 
-			created_by: allcalendarobjects[elementid].created_by 
-		};
+		// set global var
+		var obj = allcalendarobjects[elementid];
+		var names = [
+             "id", "folder_id", "recurrence_position", "recurrence_id", 
+             "created_by", "title", "start_date", "end_date", "note", 
+             "recurrence_type", "participants", "full_time", "shown_as",
+             "color_label", "location", "private_flag", "interval", "categories",
+             "users"
+		];
+		// copy properties
+		selectedAppointment = {};
+		var i = 0, $l = names.length, name;
+		for (; i < $l; i++) {
+		    name = names[i];
+		    selectedAppointment[name] = obj[name];
+		}
+		// copy folder (duplicate)
+        selectedAppointment.folder = obj.folder_id;
+		// trigger event
 		triggerEvent("Selected", calendarSelection.getSelected());
 	}	
 }
-function cwwchangeSelectedFull(elementid) {
-	if (calendarSelection.count != 0){
-		calendarSelection.reset();
-	}
-	for (var myzaehler in allcalendarobjects) {
-		for (var myzaehler2 in allcalendarobjects[myzaehler].divs) {
-			if (elementid == myzaehler) {
-				allcalendarobjects[myzaehler].divs[myzaehler2].className += " selectedAppointmentWW background-color-selection-elements border-color-selection-elements";
-			}
-		}
-	}
-	
-	if (elementid) {
-		if(calendarSelection.count != 0) {
-			calendarSelection.toggle(allcalendarobjects[elementid].index);		
-		}
-		selectedAppointment = { 
-			id: allcalendarobjects[elementid].id, folder: allcalendarobjects[elementid].folder_id,
-			recurrence_position: allcalendarobjects[elementid].recurrence_position, 
-	        recurrence_id: allcalendarobjects[elementid].recurrence_id, 
-	        created_by: allcalendarobjects[elementid].created_by
-		};
-		triggerEvent("Selected",calendarSelection.getSelected());
-	}
-}
 
 function cwwdrawAppointment(calendarobject) {
+    
 	function cww_doDblClick (event) {
 		if(!event) {
 			event=window.event;
@@ -584,7 +571,7 @@ function cwwdrawAppointment(calendarobject) {
 		edt=new Date(cwwactualday.getTime()+(cwwdaysinweek*oneday)).getTime();
 	}
 	
-	var owner = getFolderOwner(activefolder);
+	var owner = activeFolderOwner;
 	var isPrivateShared = (owner !== configGetKey('identifier') && calendarobject.private_flag === true);
 	
 	var sdttmp=sdt;
@@ -617,19 +604,7 @@ function cwwdrawAppointment(calendarobject) {
 				//fixed bug with auto selection													
 				calendarSelection.reset();	
 				var myfunc1 = function(oInplEdit) {
-					return function(e) {
-						var SelObj = calendarSelection.getID();
-						if(SelObj && SelObj.id == paramObj.id &&
-							SelObj.folder == paramObj.folder_id &&
-							SelObj.recurrence_position == paramObj.recurrence_position)
-							{
-								if(window.event) {
-									e = window.event;
-								}
-								oInplEdit.on();
-								stopEvent(e);
-						}
-					};
+					
 				};
                 var tds = myappointment.getElementsByTagName("td");
                 var title = tds[1].getElementsByTagName("span")[0];
@@ -651,21 +626,54 @@ function cwwdrawAppointment(calendarobject) {
 				if (isPrivateShared == false) {
 					myappointment.oxcalobj = calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
 					
-					addDOMEvent(myappointment,"mousedown",function (e) {
-						cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position);
-						cancelBubbling(e);
+					var timer = null;
+					
+					addDOMEvent(tds[1], "click", function(e) {
+					    function go() {
+					        oInplEdit.on();
+					        timer = null;
+					    }
+					    var SelObj = calendarSelection.getID();
+                        if (SelObj && SelObj.id == paramObj.id &&
+                                SelObj.folder == paramObj.folder_id &&
+                                SelObj.recurrence_position == paramObj.recurrence_position) {
+                            if (timer === null) {
+                                timer = setTimeout(go, 300);
+                            }
+                        }
 					});
-					addDOMEvent(tds[1], "mousedown", myfunc1(oInplEdit));		
+					
 					addDOMEvent(myappointment, "click", function(e) {
-						var SelObj = calendarSelection.getID();
-						if (SelObj && SelObj.id == paramObj.id &&
-							SelObj.folder == paramObj.folder_id &&
-							SelObj.recurrence_position == paramObj.recurrence_position) {
-						} else {
-							cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
-						}
-						cancelBubbling(e);
-					});
+                        var SelObj = calendarSelection.getID();
+                        if (SelObj && SelObj.id == paramObj.id &&
+                            SelObj.folder == paramObj.folder_id &&
+                            SelObj.recurrence_position == paramObj.recurrence_position) {
+                        } else {
+                            if (timer !== null) {
+                                clearTimeout(timer);
+                                timer = null;
+                            }
+                            cwwchangeSelected(calendarobject.folder_id + "-" 
+                                    + calendarobject.id + "-" + calendarobject.recurrence_position);
+                        }
+                        cancelBubbling(e);
+                    });
+					
+					addDOMEvent(myappointment, "dblclick", function(e) {
+                        if (timer !== null) {
+                            clearTimeout(timer);
+                            timer = null;
+                        }
+                        cww_doDblClick(e);
+                    });
+					
+                    addDOMEvent(myappointment, "contextmenu", function(e) {
+                        // select item first
+                        cwwchangeSelected(calendarobject.folder_id + "-" 
+                                + calendarobject.id + "-" + calendarobject.recurrence_position);
+                        stopEvent(e);
+                        globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
+                    });
 					
 					/* Drag & Drop Source */
 					registerSource(myappointment,"calendar",function () { 
@@ -673,12 +681,6 @@ function cwwdrawAppointment(calendarobject) {
 						mymove.begin("calendar",[calendarobject]); 
 						return mymove; 
 					},null,null,calendardefaultdisabled,defaultdisabledremove);
-					
-					addDOMEvent(myappointment, "dblclick", cww_doDblClick);
-	                addDOMEvent(myappointment, "contextmenu", function(e) {
-	                    stopEvent(e);
-	                    globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
-	                });
 				} else {
 					// private apps in shared folder, set cursor to default
 					tds[1].style.cursor = "default";
@@ -701,10 +703,10 @@ function cwwdrawAppointment(calendarobject) {
 				}
 				
 				// title & location
-				var appTitle = [];
-				if (calendarobject.title) appTitle.push(calendarobject.title);
-				if (calendarobject.location) appTitle.push(calendarobject.location);
-				title.firstChild.data = appTitle.join(" - ") || "";
+				var textToView = calendarobject.title || "";
+				if (calendarobject.location) {
+		            textToView += " - " + calendarobject.location;
+		        }
 									
 				// setting confirmation styles
 				if (calendarobject.participants.length) {
@@ -714,21 +716,22 @@ function cwwdrawAppointment(calendarobject) {
 								case 0:
 									myappointment.style.opacity = ".6";
 									title.style.fontStyle = "italic";
-									calendarobject.title += " (" + _("waiting") + ")";
+									textToView += " (" + _("waiting") + ")";
 									break;
 								case 2:
 									title.style.textDecoration = "line-through";
 									break;
 								case 3:											
 									title.style.fontStyle = "italic";
-									calendarobject.title += " (" + _("tentative") + ")";
+									textToView += " (" + _("tentative") + ")";
 									break;
 							}
 							break;
 						}
 					}
 				}
-				
+                title.firstChild.data = textToView;
+                
 				appointmentcontainer.appendChild(myappointment);
 			}
 			sdttmp = sdttmp+oneday;
@@ -796,19 +799,8 @@ function cwwdrawAppointment(calendarobject) {
 					oInplEdit.style.color = "white";
 					oInplEdit.style.fontSize = "8pt";
 					oInplEdit.style.height = "1.2em";
-					//fixed bug with auto selection													
+					//fixed bug with auto selection
 					calendarSelection.reset();
-					var myfunc1 = function(oInplEdit) {
-						return function(e) {
-							var SelObj = calendarSelection.getID();
-							if (SelObj && SelObj.id == paramObj.id &&
-									SelObj.folder == paramObj.folder_id &&
-									SelObj.recurrence_position == paramObj.recurrence_position) {
-								oInplEdit.on();
-								stopEvent(e);
-							}
-						};
-					};
                     var tds = myappointment.getElementsByTagName("td");
                     var title = tds[2].getElementsByTagName("span")[0];
                     
@@ -846,22 +838,46 @@ function cwwdrawAppointment(calendarobject) {
 					if (isPrivateShared == false) {
 						myappointment.oxcalobj = calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
 						
-                    	addDOMEvent(myappointment,"mousedown",function (e) {						
-							cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position);
-							cancelBubbling(e);
-						});
-						addDOMEvent(tds[2], "mousedown", myfunc1(oInplEdit));
-						addDOMEvent(myappointment, "click", function(e) {
-							var SelObj = calendarSelection.getID();
-							if(SelObj && SelObj.id == paramObj.id &&
-								SelObj.folder == paramObj.folder_id &&
-								SelObj.recurrence_position == paramObj.recurrence_position) {							
-							} else {
-								cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
-							}
-							cancelBubbling(e);
-						});	
-						addDOMEvent(myappointment,"dblclick",cww_doDblClick);
+						var timer = null;
+						
+	                    addDOMEvent(tds[2], "click", function(e) {
+	                        function go() {
+	                            oInplEdit.on();
+	                            timer = null;
+	                        }
+	                        var SelObj = calendarSelection.getID();
+	                        if (SelObj && SelObj.id == paramObj.id &&
+	                                SelObj.folder == paramObj.folder_id &&
+	                                SelObj.recurrence_position == paramObj.recurrence_position) {
+	                            if (timer === null) {
+	                                timer = setTimeout(go, 300);
+	                            }
+	                        }
+	                    });
+	                    
+	                    addDOMEvent(myappointment, "click", function(e) {
+	                        var SelObj = calendarSelection.getID();
+	                        if (SelObj && SelObj.id == paramObj.id &&
+	                            SelObj.folder == paramObj.folder_id &&
+	                            SelObj.recurrence_position == paramObj.recurrence_position) {
+	                        } else {
+	                            if (timer !== null) {
+	                                clearTimeout(timer);
+	                                timer = null;
+	                            }
+	                            cwwchangeSelected(calendarobject.folder_id + "-" 
+	                                    + calendarobject.id + "-" + calendarobject.recurrence_position);
+	                        }
+	                        cancelBubbling(e);
+	                    });
+	                    
+	                    addDOMEvent(myappointment, "dblclick", function(e) {
+	                        if (timer !== null) {
+	                            clearTimeout(timer);
+	                            timer = null;
+	                        }
+	                        cww_doDblClick(e);
+	                    });
 						
 						/* Cursor fuer Drag&Drop */
 						addDOMEvent(domdivs[1], "mouseover",
@@ -877,6 +893,9 @@ function cwwdrawAppointment(calendarobject) {
 							(function(obj){ return function(){ obj.style.cursor = "s-resize"; }; })(domdivs[4]));
 						
 	                    addDOMEvent(myappointment, "contextmenu", function(e) {
+	                        // select item first
+	                        cwwchangeSelected(calendarobject.folder_id + "-" 
+	                                + calendarobject.id + "-" + calendarobject.recurrence_position);
 	                        stopEvent(e);
 	                        globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
 	                    });
@@ -912,10 +931,10 @@ function cwwdrawAppointment(calendarobject) {
 						}
 						
 						// Title & location
-						var appTitle = [];
-						if (calendarobject.title) appTitle.push(calendarobject.title);
-						if (calendarobject.location) appTitle.push(calendarobject.location);
-						title.firstChild.data = appTitle.join(" - ") || "";
+						var textToView = calendarobject.title || "";
+		                if (calendarobject.location) {
+		                    textToView += " - " + calendarobject.location;
+		                }
 						
 						// setting confirmation styles
 						if (calendarobject.participants.length) {
@@ -925,20 +944,22 @@ function cwwdrawAppointment(calendarobject) {
 										case 0:
 											myappointment.style.opacity = ".6";
 											title.style.fontStyle = "italic";
-											calendarobject.title += " (" + _("waiting") + ")";
+											textToView += " (" + _("waiting") + ")";
 											break;
 										case 2:
 											title.style.textDecoration = "line-through";
 											break;
 										case 3:											
 											title.style.fontStyle = "italic";
-											calendarobject.title += " (" + _("tentative") + ")";
+											textToView += " (" + _("tentative") + ")";
 											break;
 									}
 									break;
 								}
 							}
 						}
+						
+						title.firstChild.data = textToView;
 												
 						/** Recurrence Type **/
 						if (calendarobject.recurrence_type && calendarobject.recurrence_type!=0) {
@@ -948,7 +969,7 @@ function cwwdrawAppointment(calendarobject) {
 						}
 												
 						/** Private or Group **/
-						if (calendarobject.participants && calendarobject.participants.length>1) {
+						if (isGroupAppointment(calendarobject.participants)) {
 							tds[3].getElementsByTagName("img")[1].style.display = "inline";
 							tds[3].getElementsByTagName("img")[1].src=getFullImgSrc("img/calendar/group.gif");							
 						} else {
@@ -1177,8 +1198,10 @@ function createCalendarContentFullTime() {
 		//addDOMEvent(secondtd.getElementsByTagName("table")[0],"dblclick",getfunction2(secondtd.getElementsByTagName("table")[0]));	
 		secondtr.appendChild(secondtd);
 	}
+	/*
 	if (IE < 8) $("cwwheaderscroll").style.display="none";
 	else $("cwwheaderscroll").style.display="";
+	*/
 	
 	delete calendarhovers["daywwcustom"];
 	calendarhovers["daywwcustom"]=new Hover(secondtr,OXAppointmentHover.getContent().node);
@@ -1191,7 +1214,7 @@ function createCalendarContentFullTime() {
             }
         } catch (e) { }
     };
-	calendarhovers["daywwcustom"].onShow = function (node) {
+	calendarhovers["daywwcustom"].onShow = function (node, manual) {
 		OXAppointmentHover.actualHover=this;
 		var splitid=node.oxcalobj.split("-");
 		OXAppointmentHover.refillContent(splitid[1],splitid[0],splitid[2]);
@@ -1334,7 +1357,7 @@ function createCalendarContentWW(interval,startworktime,endworktime){
             }
         } catch (e) { /*see default implementation*/ }
 	}
-	calendarhovers["daywwcustom2"].onShow = function (node) {
+	calendarhovers["daywwcustom2"].onShow = function (node, manual) {
 		OXAppointmentHover.actualHover=this;
 		var splitid=node.oxcalobj.split("-");
 		OXAppointmentHover.refillContent(splitid[1],splitid[0],splitid[2]);	
@@ -1513,7 +1536,7 @@ function getDragandDropPoint(e) {
 	} 
 	var daylength=coreelement.offsetWidth/cwwdaysinweek;
 	var day=Math.floor(fieldposx/daylength);
-	var intervalcount=Math.floor(fieldposy/wwline)*configGetKey("gui.calendar.interval")*60000;
+	var intervalcount=Math.floor(fieldposy/wwline)*ox.api.config.get("gui.calendar.interval", 30)*60000;
 	var mydate=new Date(intervalcount);
 	return new Date(Date.UTC(cwwactualday.getUTCFullYear(),cwwactualday.getUTCMonth(),cwwactualday.getUTCDate()+day,mydate.getUTCHours(),mydate.getUTCMinutes(),0));
 	 
@@ -1542,7 +1565,8 @@ function drawpreviewnewAppointment(event,target,object,mouseposition) {
 }
 var cww_lastdateddwholeday;
 function drawpreviewDragandDropWholeDay(event,target,object) {
-	var newdate=getDragandDropPointWholeDay(event);
+	stopEvent(event);
+    var newdate=getDragandDropPointWholeDay(event);
 	if((cww_lastdateddwholeday && !newdate) || (!cww_lastdateddwholeday && newdate) || (cww_lastdateddwholeday && newdate && (cww_lastdateddwholeday.getTime() != newdate.getTime()))) {
 		cww_lastdateddwholeday = newdate;
 		var starttime=object.start_date;
@@ -1560,12 +1584,13 @@ function drawpreviewDragandDropWholeDay(event,target,object) {
 	}
 }
 function drawpreviewDragandDrop(event,target,object) {
+    stopEvent(event);
 	var newdate = getDragandDropPoint(event);
 	if((cww_lastdatedd && !newdate) || (!cww_lastdatedd && newdate) || (cww_lastdatedd && newdate && (cww_lastdatedd.getTime() !=newdate.getTime()))) {
 		cww_lastdatedd = newdate;
 		var starttime=object.start_date;
 		var endtime=object.end_date;
-		var oneintervaltime=configGetKey("gui.calendar.interval")*60000;
+		var oneintervaltime=ox.api.config.get("gui.calendar.interval", 30)*60000;
 		switch (target) {
 			case "CALENDAR_BOTTOM":
 				if(newdate) {
@@ -1702,7 +1727,7 @@ function cww_saveAppointment(object,event,target,wholeday,i) {
 	}
 	var starttime=object.start_date;
 	var endtime=object.end_date;
-	var oneintervaltime=configGetKey("gui.calendar.interval")*60000;
+	var oneintervaltime=ox.api.config.get("gui.calendar.interval", 30)*60000;
 	switch (target) {
 		case "CALENDAR_BOTTOM":
 			if(newdate) {
@@ -1874,6 +1899,19 @@ function editAppointment(obj, changes, callback) {
 		app.recurrence_position = 0;
 		app.recurrence_type = 0;
 	}
+	function normalizeFullTimeDate(date) {
+	    var odate = new Date(date);
+	    return Date.UTC(odate.getUTCFullYear(),
+	            odate.getUTCMonth(), odate.getUTCDate(), "0",
+                "0", "0");
+	}
+	
+	// adjust full time appointments #14435
+	if (obj.full_time === true) {
+	    changes.start_date = normalizeFullTimeDate(changes.start_date);
+	    changes.end_date = normalizeFullTimeDate(changes.end_date);
+	}
+	
 	// update via UI
 	ox.calendar.ui.update(app, changes, callback);
 }
@@ -1882,24 +1920,7 @@ function createAppointment(object) {
 	if (!object.alarm && configContainsKey("gui.calendar.default_reminder")) {
 		object.alarm = configGetKey("gui.calendar.default_reminder");
 	}
-	json.put(AjaxRoot + "/calendar?action=new&session=" + session, object, null, 
-	function(response){
-		function cbignore() {
-			object.ignore_conflicts=true;
-			json.put(AjaxRoot + "/calendar?action=new&session=" + session, object, null,
-			function(responseinternal) {
-				if(responseinternal && responseinternal.data && responseinternal.data.id) {	
-					storageCache.update();	
-				} 		
-			});
-		}
-		if(response && response.data && response.data.id) {	
-			storageCache.update();	
-		} 
-		else if(response && response.data && response.data.conflicts) {
-			ConflictsPopup.open(object,response.data.conflicts,null,null,cbignore);
-		}
-	});
+	ox.calendar.ui.create(object);
 }
 function openNewAppointmentWindow(object) {
 	function createAppyes() {
@@ -1915,7 +1936,6 @@ function openNewAppointmentWindow(object) {
 					end_date: object.end_date
 				}
 			});
-			//newWindow("newAppointment.html#modul=new&folder_id="+object.folder_id+"&start_date="+object.start_date+"&end_date="+object.end_date+"", getWindowOptions(null, 680));
 		}
 		removeDDPreviewDivs();
 		newAppointmentObject(object,myok,function() {},myadvanced,null);
