@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -43,6 +43,7 @@ register("OX_Configuration_Loaded", function() {
     }
     if (!configContainsKey("modules.tasks.notifyAcceptedDeclinedAsParticipant")) {
     	configSetKey("modules.tasks.notifyAcceptedDeclinedAsParticipant",true);
+    	configuration_changed_fields["module"]=true;
     }
 	if(!configContainsKey("mail.deletemail")) {
 		configSetKey("mail.deletemail",false);	
@@ -70,11 +71,16 @@ register("OX_Configuration_Loaded", function() {
 		configSetKey("mail.inlineattachments",true);
 		configSetKey("mail.emoticons",true);
 		configSetKey("mail.colorquoted",true);
+		configuration_changed_fields["mail"]=true;
+		configuration_changed_fields["gui"]=true;
+	}
+	if (!configContainsKey("gui.mail.showname")) {
+	    configSetKey("gui.mail.showname", false);
 	}
 	if(!configContainsKey("gui.mail.formatmessage")) {
-		configSetKey("gui.mail.formatmessage","ALTERNATIVE")
+		configSetKey("gui.mail.formatmessage","ALTERNATIVE");
 	} else if(configGetKey("gui.mail.formatmessage") == "text") {
-		configSetKey("gui.mail.formatmessage","ALTERNATIVE")
+		configSetKey("gui.mail.formatmessage","ALTERNATIVE");
 	}
 	if(!configContainsKey("gui.mail.autocomplete")) {
 		configSetKey("gui.mail.autocomplete",true)
@@ -97,6 +103,9 @@ register("OX_Configuration_Loaded", function() {
 	if(!configContainsKey("gui.calendar.default_reminder")) {
 		configSetKey("gui.calendar.default_reminder",15);
 	}
+	if(!configContainsKey("gui.calendar.teamview.workingTimeOnly")) {
+        configSetKey("gui.calendar.teamview.workingTimeOnly", true);
+    }
 	
     if (!configContainsKey("gui.calendar.views")) {
         if (configContainsKey("gui.calendar.view")) {
@@ -114,7 +123,7 @@ register("OX_Configuration_Loaded", function() {
             }
         } else {
             var view = { view: "calendar", calendar: "workweek", team: "workweek",
-                         list: "weorkweek", shared: true };
+                         list: "workweek", shared: true };
         }
         configSetKey("gui.calendar.views", view);
         configSetKey("gui.calendar.view", getDefaultCalendarView());
@@ -123,6 +132,7 @@ register("OX_Configuration_Loaded", function() {
 		configSetKey("gui.calendar.allfolders",true);
 		configSetKey("modules.calendar.notifyAcceptedDeclinedAsCreator",true);
     	configSetKey("modules.tasks.notifyAcceptedDeclinedAsCreator",true);
+    	configuration_changed_fields["modules"]=true;
 	}
 	if(!configContainsKey("gui.calendar.day.numberofappointments")) {
 		configSetKey("gui.calendar.day.numberofappointments",4);
@@ -147,6 +157,7 @@ register("OX_Configuration_Loaded", function() {
     } 
     if (!configContainsKey("modules.calendar.notifyAcceptedDeclinedAsParticipant")) {
         configSetKey("modules.calendar.notifyAcceptedDeclinedAsParticipant",true);
+        configuration_changed_fields["modules"]=true;
     }
 	if(!configContainsKey("gui.contacts.view")) {
 		configSetKey("gui.contacts.view","contacts/cards");
@@ -178,12 +189,6 @@ register("OX_Configuration_Loaded", function() {
 			configSetKey("gui.global.autorefresh",0);
 		}
 	}
-	if(!configContainsKey("gui.portal.tooltip")) {
-		configSetKey("gui.portal.tooltip",false);
-	}
-	if(!configContainsKey("gui.portal.minicalendar")) {
-		configSetKey("gui.portal.minicalendar",true);
-	}
 	if(!configContainsKey("gui.effects.hover.portal")) {
 		configSetKey("gui.effects.hover.portal",true);
 	}
@@ -209,16 +214,13 @@ register("OX_Configuration_Loaded", function() {
 		configSetKey("gui.effects.global",false);
 		configSetKey("gui.effects.fading",false);
 	}
-	if(!configContainsKey("gui.portal.infobox")) {
-		configSetKey("gui.portal.infobox",true);
-	}
 	if (!configContainsKey("gui.categories.local")) {
 		configSetKey("gui.categories.local", []);
 		ox.categories.utils.migrateTags();
 	}
-	if (!configContainsKey("gui.FolderTreeState")) {
-		configSetKey("gui.FolderTreeState",new Object);
-	}			
+//	if (!configContainsKey("gui.FolderTreeState")) {
+//		configSetKey("gui.FolderTreeState",new Object);
+//	}			
 	if (!configContainsKey("gui.contacts.gridsort") || !isNaN(configGetKey("gui.contacts.gridsort")))   {
 		configSetKey("gui.contacts.gridsort","last_name");
 	}
@@ -257,16 +259,49 @@ register("OX_Configuration_Loaded", function() {
 	if(!configContainsKey("gui.portal.externalcontents")) {
 		configSetKey("gui.portal.externalcontents",new Array());
 	}
+	
+	// expert mode
+    if (!configContainsKey("ui.global.expert.mode")) {
+        configSetKey("ui.global.expert.mode", { value: false, configurable: true });
+    }
+    
+	// embedded windows
+	if (!configContainsKey("ui.global.windows.mode")) {
+        configSetKey("ui.global.windows.mode", { value: "embedded", configurable: true });
+    }
+	
+	// toolbar
+    if (!configContainsKey("ui.global.toolbar.mode")) {
+        configSetKey("ui.global.toolbar.mode", { value: "tabbased", configurable: true });
+    }
+    
+    // show contact image
+    if (!configContainsKey("ui.mail.showContactImage")) {
+        configSetKey("ui.mail.showContactImage", { value: true, configurable: true });
+    }
+	
+    if (configuration_changed_outside === true) {
+        setTimeout(function() {
+            triggerEvent("OX_Save_Configuration",false,true);
+            configuration_changed_outside = false;
+        }, 5000);
+    }
+    
 	triggerEvent("OX_Configuration_Set_Empty");
 });
-registerModule("configuration", "Configuration",100); /*i18n*/
+
+registerModule("configuration", _("Configuration"), 100);
+
+// Configuration changed?
 function configuration_changed() {
-	for (var i in configuration_changed_fields) {
-		if(configuration_changed_fields[i] === true) 
+	for (var id in configuration_changed_fields) {
+		if (configuration_changed_fields[id] === true) {
 			return true;
+		}
 	}
 	return false;
 }
+
 var configuration_changed_fields=new Object();
 var configuration_changed_outside=false;
 configuration_changed_fields["timezone"]=false;
@@ -284,6 +319,7 @@ var changed_inv = false;
 var foldersChanged = 0;
 var j = 0;
 var configVisited = false;
+var configToolbars = {};
 
 (function() {
 	register("Loaded", function() {});
@@ -381,6 +417,10 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 				}
 			}
 		}
+		// make sure all config fields are marked as "not changed"
+		for (var id in configuration_changed_fields) {
+		    configuration_changed_fields[id] = false;
+		}
 	}
 	
     var ro_ConfigSettings = [
@@ -390,17 +430,17 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
         "mail.addresses", "mail.defaultaddress", "mail.folder",
         "mail.spambutton", "modules", "participants.showDialog",
         "participants.showWithoutEmail", "reloadtimes", "serverVersion",
-        "spambutton"
+        "spambutton", "ui"
     ];
 	
-	function saveConfigtoServer(path,params,success1,error1,myjson) {
+	function saveConfigtoServer(path,params,success1,error1) {
 		showmessage=true;
-		var reqstring=AjaxRoot + "/config";
+		var reqstring= "config"; //AjaxRoot + "/config";
 		var myparams;
 		if (path && path != "") {
 			reqstring=reqstring+"/"+path;
 		}
-		reqstring=reqstring+"?session="+session;
+		//reqstring=reqstring+"?session="+session;
 		if (params && params != "") {
 			myparams=configGetKey(params);
 		} else {
@@ -420,27 +460,37 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
             if (!splitkey || !splitkey.length) continue;
             delete tmp[splitkey[splitkey.length-1]];
 		}
-		myjson.put(reqstring, myparams, null, success1, error1);
+		// use http api (fixes IE9 logout bug)
+		ox.api.http.PUT({
+		    module: reqstring,
+            appendColumns: false,
+		    data: myparams,
+		    success: success1,
+		    error: error1
+		});
+		//myjson.put(reqstring, myparams, null, success1, error1);
 	}
-	var myjson=new JSON();
 	if(force) {
 		for (var i in configuration_changed_fields) {
 			configuration_changed_fields[i] = false;
 		}
-		saveConfigtoServer("","",myok,myerror,myjson);
+		saveConfigtoServer("","",myok,myerror);
 		configuration_changed_outside=false;
 	}
     if (temporary.folderTabs.viewModified()) {
         temporary.folderTabs.saveView(configuration_changed_fields.folder ?
             emptyFunction :
             function() {
-                oMainFolderTree.cache.updateFolders(
+        		ox.api.folder.refresh({ folders: [temporary.folderTabs.folder.id] });
+                /*
+        		oMain-FolderTree.cache.updateFolders(
                     [temporary.folderTabs.folder.id],
                     function() {
-                        oMainFolderTree.load_view(
-                            oMainFolderTree.cache.folders.root,
-                            oMainFolderTree.tree, true, false);
-                    });
+                        oMain-FolderTree.load_view(
+                            oMain-FolderTree.cache.folders.root,
+                            oMain-FolderTree.tree, true, false);
+                    
+        			});*/
             });
         showmessage = false;
     }
@@ -450,31 +500,84 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 		showmessage=false;
 	}
 	if(configuration_changed_fields["mail"] == true) {
-		saveConfigtoServer("mail","mail",myok,myerror,myjson);
+		saveConfigtoServer("mail","mail",myok,myerror);
 		openrequests++;
 		configuration_changed_fields["mail"] = false;
 	}
-	if(configuration_changed_fields["timezone"] == true) {
-		saveConfigtoServer("timezone","timezone",myok,myerror,myjson);
-		openrequests++;
-		configuration_changed_fields["timezone"] = false;
+	
+	function timezoneChanged(data) {
+	    if (data) {
+	        configSetKey("currentTime", data.currentTime);
+	        configSetKey("availableTimeZones", data.availableTimeZones);
+	        // redraw timezone combo-box
+            cs_drawTimezoneCombo(data.availableTimeZones);
+            // update reminders
+            if (jQuery.isFunction(updateReminders)) {
+                updateReminders();
+            }
+	    }
+	    triggerEvent("OX_SetTime");
+	    triggerEvent("TimezoneChanged", configGetKey("timezone"));
+	    myok();
 	}
-	if(configuration_changed_fields["language"] == true) {
-        saveConfigtoServer("language", "language", function() {
-            (new JSON).get(AjaxRoot + "/config/availableTimeZones?session=" +
-                session, null, function(tz) {
-                    configSetKey("availableTimeZones", tz.data);
-                    myok();
-                });
-        }, myerror, myjson);
-		openrequests++;
-		configuration_changed_fields["language"] = false;
+	
+	if (configuration_changed_fields["timezone"] === true
+	        || configuration_changed_fields["language"] === true) {
+	    ox.api.http.PUT({
+	        module: "config",
+	        processData: false,
+	        data: { 
+	            "timezone": ox.api.config.get("timezone"),
+                "language": ox.api.config.get("language")
+	        },
+	        success: function (data) {
+	            ox.api.http.PUT({
+	                module: "multiple",
+	                appendColumns: false,
+	                processData: false,
+	                data: [
+	                   { module: "config/currentTime", action: "GET" },
+	                   { module: "config/availableTimeZones", action: "GET" }
+                    ],
+	                success: function (response) {
+	                    // response not empty?
+	                    if (!response && !response.length) {
+	                        openrequests--;
+	                        return;
+	                    }
+	                    data = { "currentTime": response[0].data, 
+	                            "availableTimeZones": response[1].data
+	                    };
+	                    timezoneChanged(data);
+                        //workaround for foldertree updates after language changes
+                        ox.api.cache.folder0.clear();
+                        ox.api.cache.folder1.clear();
+                        ox.api.cache.folderFlat.clear();
+                        ox.api.folder.dispatcher.trigger("modify");
+	                    configuration_changed_fields["timezone"] = false;
+	                    configuration_changed_fields["language"] = false;
+	                    openrequests--;
+	                }
+	            });
+	        },
+	        error: myerror
+	    });
+	    openrequests++;
 	}
 	if(configuration_changed_fields["gui"] == true) {
-		saveConfigtoServer("gui","gui",myok,myerror,myjson);
+		saveConfigtoServer("gui","gui",function(){
+		    myok();
+		    triggerEvent("OX_Calendar_Teamlist_Changed");}
+		,myerror);
+		
 		openrequests++;
 		configuration_changed_fields["gui"] = false;
 	}
+	if(configuration_changed_fields["ui"] == true) {
+	    saveConfigtoServer("ui", "ui", myok, myerror);
+        openrequests++;
+        configuration_changed_fields["ui"] = false;
+    }
 	if (configuration_changed_fields["tasknotification"] == true) {		
         delete(config["tasknotification"]);
 		// todo: each modules section should have an own area later!!
@@ -488,7 +591,7 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 		configuration_changed_fields["calendarnotification"] = false;
 	}
 	if(configuration_changed_fields["modules"] == true) {
-		saveConfigtoServer("modules","modules",myok,myerror,myjson);
+		saveConfigtoServer("modules","modules",myok,myerror);
 		openrequests++;
 		configuration_changed_fields["modules"] = false;
 	}
@@ -524,40 +627,24 @@ function displaySignatureConfig(val) {
 	 sig.value = val;
 }
 
-function LogoutPopup() { };
-// final logout call, can be overwritten
-LogoutPopup.doLogout = function() {
-	window.onbeforeunload = null;
-	new JSON().get(AjaxRoot + "/login?action=logout&session=" + session, null, function() {
-		window.setTimeout( function() { 
-			window.location.replace(logout_location.format()); 
-		}, 0);
-	},function() { 
-		window.setTimeout( function() { 
-			window.location.replace(logout_location.format()); 
-		}, 0);			
-		return true;
-	});
-}
-LogoutPopup.openWindow = emptyFunction;
-LogoutPopup.closeWindow = emptyFunction;
-LogoutPopup.commityes = function () {
-	triggerEvent("OX_Save_Configuration",true,true, LogoutPopup.doLogout, 
-			function(data) {
-				window.onbeforeunload = null;
-				if (typeof data != "object" || data.code == "SES-0203") {
-					window.setTimeout( function() { 
-						window.location.replace(logout_location.format()); 
-					}, 0);
-				} else {
-					newConfirm(_("Server Error:"),
-							_("Your configuration settings could not be saved. All your changes will be lost. Do you really want to continue?") + "\n\n" + formatError(data), 
-							AlertPopup.YESNO, null, null, LogoutPopup.doLogout, emptyFunction
-					);
-				}
-				return true;
-			}
-	);
-}
-LogoutPopup.commitno = LogoutPopup.doLogout;
+var setConfigPath = function (domNode) {
+    var node = ox.widgets.configTree.nodeIndex[currentpath2.join("/")];
+    var path = node.name instanceof I18nString ? node.name : _(node.name);
+    while (node.parentNode) {
+        node = node.parentNode;
+        path = _(node.name) + " / " + path;
+    }
+    domNode.firstChild.nodeValue = path;
+};
+
+var deleteFolderConfig = function () {
+    // get folder
+    ox.api.folder.get({
+        folder: configfolder,
+        success: function (data) {
+            if (ox.api.folder.can("delete", data)) removeFolder(configfolder);
+        }
+    });
+};
+
 fileloaded();
\ No newline at end of file
