@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -17,6 +17,10 @@ registerView("configuration/mail/preferences",
 	function () { 
 		showNode("config_mail"); 
 		$("config_mail").style.display="block";
+        
+        // toolbar
+        temporary.configuration.showToolbar(
+            temporary.configuration.defaultToolbar);
 	},
 	function() {
 		register("OX_SAVE_OBJECT",cm_saveConfiguration);
@@ -44,16 +48,18 @@ registerView("configuration/mail/preferences",
 function cm_saveConfiguration() {
 	if (configuration_changed_fields["gui"]) {
 		configSetKey("gui.mail.view", cm_default_level1.getKey());
+        menulastviews.mail = cm_default_level1.getKey();
 		configSetKey("gui.mail.view_spam", cm_default_level2.getKey());
-		configSetKey("gui.mail.notifyacknoledge",getBoolofInt(getValueofRadioBox("cm_notifyacknoledge")));		
+		configSetKey("gui.mail.notifyacknoledge",getBoolofInt(getValueofRadioBox("cm_notifyacknoledge")));
 		configSetKey("gui.mail.formatmessage",getStringofRadioBox("cm_formatmessage"));
-		configSetKey("gui.mail.autocomplete",getBoolofInt(getValueofRadioBox("cm_autocomplete")));		
+		configSetKey("gui.mail.autocomplete",getBoolofInt(getValueofRadioBox("cm_autocomplete")));
 		configSetKey("gui.mail.auto_save_drafts", cm_auto_save_mail_drafts.getKey());
-		configSetKey("gui.mail.defaul_mail_font", cm_default_mail_font.getKey());	
+		configSetKey("gui.mail.defaul_mail_font", cm_default_mail_font.getKey());
 		configSetKey("gui.mail.defaul_mail_font_size", cm_default_mail_font_size.getKey());
 		configSetKey("gui.effects.hover.mail",getBoolofInt(getValueofRadioBox("cm_enablehovermail")));
 		configSetKey("gui.mail.select_first_message",getBoolofInt(getValueofRadioBox("cm_emailSelectFirstMessage")));
 		configSetKey("gui.mail.editor_featureset", cm_editor_featureset.getKey());
+		configSetKey("gui.mail.showname", getBoolofInt(getValueofRadioBox("cm_showname")));
 	}
 	if (configuration_changed_fields["mail"]) {
 		configSetKey("mail.vcard",getBoolofInt(getValueofRadioBox("cm_appendvcard")));		
@@ -64,7 +70,7 @@ function cm_saveConfiguration() {
 		configSetKey("mail.emoticons",getBoolofInt(getValueofRadioBox("cm_emoticons")));
 		configSetKey("mail.forwardmessage",getStringofRadioBox("cm_forwardmessage"));
 		configSetKey("mail.linewrap",$("cm_linewrap").value);
-		configSetKey("mail.sendaddress", cm_default_sendaddress.getKey());	
+		configSetKey("mail.sendaddress", cm_default_sendaddress.getKey());
 	}
 	if (configuration_changed_fields["modules"]) {
 		configSetKey("modules.mail.allowhtmlimages", getBoolofInt(getValueofRadioBox("cm_preloadimages")));
@@ -74,6 +80,10 @@ function cm_saveConfiguration() {
 		}
 		configSetKey("modules.mail.replyallcc", getBoolofInt(getValueofRadioBox("cm_replyallcc")));
 	}
+    if (configuration_changed_fields.ui) {
+        configSetKey("ui.mail.showContactImage.value",
+            getBoolofInt(getValueofRadioBox("cm_showimage")));
+    }
 	
 	triggerEvent("OX_Save_Configuration",false,false);
 }
@@ -91,9 +101,9 @@ var cm_init_bool=false;
 
 register("OX_Configuration_Loaded",cm_onconfigload);
 function cm_onconfigload() {
-	addDefaultView("mail/list/unthreaded","List view");/*i18n*/
-	addDefaultView("mail/hsplit/unthreaded","H-split view");/*i18n*/
-	addDefaultView("mail/vsplit/unthreaded","V-split view");/*i18n*/
+    addDefaultView("mail/list/unthreaded", _("List view"));
+    addDefaultView("mail/hsplit/unthreaded", _("H-split view"));
+    addDefaultView("mail/vsplit/unthreaded", _("V-split view"));
 }
 
 function cm_leave() { }
@@ -123,6 +133,10 @@ function cm_enter() {
 		setValueofRadioBox("cm_notifyacknoledge",configGetKey("gui.mail.notifyacknoledge"));
 		configuration_changed_fields["gui"]=false;
 	}
+    if (configContainsKey("ui.mail.showContactImage")) {
+        setValueofRadioBox("cm_showimage", configGetKey("ui.mail.showContactImage.value"));
+        configuration_changed_fields["ui"]=false;
+    }
 	if(configContainsKey("mail.appendmailtext")) {
 		setValueofRadioBox("cm_appendmailtext",configGetKey("mail.appendmailtext"));
 		configuration_changed_fields["mail"]=false;
@@ -143,9 +157,13 @@ function cm_enter() {
 		setValueofRadioBox("cm_colorquoted",configGetKey("mail.colorquoted"));
 		configuration_changed_fields["mail"]=false;
 	}
-	if(configContainsKey("mail.emoticons")) {
-		setValueofRadioBox("cm_emoticons",configGetKey("mail.emoticons"));
-		configuration_changed_fields["mail"]=false;
+    if(configContainsKey("mail.emoticons")) {
+        setValueofRadioBox("cm_emoticons",configGetKey("mail.emoticons"));
+        configuration_changed_fields["mail"]=false;
+    }
+	if (configContainsKey("gui.mail.showname")) {
+		setValueofRadioBox("cm_showname", configGetKey("gui.mail.showname"));
+		configuration_changed_fields.mail = false;
 	}
 	if(configContainsKey("gui.mail.formatmessage")) {
 		setStringofRadioBox("cm_formatmessage",configGetKey("gui.mail.formatmessage"));
@@ -197,15 +215,16 @@ function cm_enter() {
         if (   configContainsKey("modules.mail.contactCollectFolder")
             && configGetKey("modules.mail.contactCollectFolder") != 0)
         {
-            oMainFolderTree.cache.get_folder(
-                configGetKey("modules.mail.contactCollectFolder"),
-                function(folder) { 
+            ox.api.folder.get({
+                folder: configGetKey("modules.mail.contactCollectFolder"),
+                success: function (data) { 
                     //#. %s is the folder name.
                     //#, c-format
                     $("cm_emailCollection_text").firstChild.nodeValue = format(
                         _("Automatically collect contacts in the folder \"%s\""),
-                        [folder.oxfolder.data.title]);
-                });
+                        [data.title]);
+                }
+            });
         } else {
             $("cm_emailCollection_text").firstChild.nodeValue =
                 _("Automatically collect contacts");
@@ -220,7 +239,10 @@ function cm_enter() {
         setIntofRadioBox("cm_replyallcc",configGetKey("modules.mail.replyallcc"));
         configuration_changed_fields["gui"]=false;
     }
-	$("cm_header").firstChild.nodeValue=getconfigPathSelected().substring(1);	
+	setConfigPath($("cm_header"));
+	
+    // configurable: show image contact
+    applyConfigurableFlag("#configurable-showContactImage", "ui.mail.showContactImage");
 	
 	// register tabs
 	setTabLists(new Array('contentMailConfigCommon','contentMailConfigCompose','contentMailConfigDisplay'),
@@ -245,7 +267,7 @@ function cm_init() {
 	cm_default_sendaddress= new ComboBox3(window, "cm_default_sendaddress", "30em", 0, true,"OX_Configuration_Settings_Changed_Mail", 3);
 	var aliases = configContainsKey("mail.addresses") ? configGetKey("mail.addresses") : new Array();
 	for (a=0; a < aliases.length; a++) {
-		cm_default_sendaddress.addElement(aliases[a],aliases[a]);
+        cm_default_sendaddress.addElement(noI18n(aliases[a]), aliases[a]);
 	}
 	cm_default_sendaddress.getDomNode();
 	
@@ -255,48 +277,49 @@ function cm_init() {
 	
 	var myarray=[60000,180000,300000,600000,900000,1800000];
 	cm_auto_save_mail_drafts = new ComboBox3(window, "cm_auto_save_mail_drafts", "15em", 0, true,"OX_Configuration_Settings_Changed_GUI", 3);
-	cm_auto_save_mail_drafts.addElement(_("Disabled"),0); /*i18n*/
-	var m = function(n) { return function() { return getInterval(n); }; }; 
+    cm_auto_save_mail_drafts.addElement(_("Disabled"), 0);
 	for(var i=0;i<myarray.length;i++) {
 		if(!myarray[i]== 0) {
-			cm_auto_save_mail_drafts.addElement("",(myarray[i]/60000),m((myarray[i])));
+            cm_auto_save_mail_drafts.addElement(getInterval(myarray[i]),
+                                                myarray[i] / 60000);
 		}
 	}
 	cm_auto_save_mail_drafts.getDomNode();
 	
 	cm_default_mail_font = new ComboBox3(window, "cm_default_mail_font", "15em", 0, true,"OX_Configuration_Settings_Changed_GUI", 5);
-	cm_default_mail_font.addElement(_("Default"),'default');
-	cm_default_mail_font.addElement("Andale Mono",'andale mono,times'); 
-	cm_default_mail_font.addElement("Arial",'arial,helvetica,sans-serif'); 
-	cm_default_mail_font.addElement("Arial Black","arial black,avant garde");
-	cm_default_mail_font.addElement("Book Antiqua","book antiqua,palatino");
-	cm_default_mail_font.addElement("Comic Sans MS","comic sans ms,sans-serif");
-	cm_default_mail_font.addElement("Courier New","courier new,courier");
-	cm_default_mail_font.addElement("Georgia","georgia,palatino");
-	cm_default_mail_font.addElement("Helvetica","helvetica");
-	cm_default_mail_font.addElement("Impact","impact,chicago");
-	cm_default_mail_font.addElement("Symbol","symbol");
-	cm_default_mail_font.addElement("Tahoma","tahoma,arial,helvetica,sans-serif");
-	cm_default_mail_font.addElement("Terminal","terminal,monaco");
-	cm_default_mail_font.addElement("Times New Roman","times new roman,times");
-	cm_default_mail_font.addElement("Trebuchet MS","trebuchet ms,geneva");
-	cm_default_mail_font.addElement("Verdana","verdana,geneva");
-	cm_default_mail_font.addElement("Webdings","webdings");
-	cm_default_mail_font.addElement("Wingdings","wingdings,zapf dingbats");					
+    cm_default_mail_font.addElement(_("Default"), "default");
+    cm_default_mail_font.addElement(noI18n("Andale Mono"), "andale mono,times");
+    cm_default_mail_font.addElement(noI18n("Arial"), "arial,helvetica,sans-serif");
+    cm_default_mail_font.addElement(noI18n("Arial Black"), "arial black,avant garde");
+    cm_default_mail_font.addElement(noI18n("Book Antiqua"), "book antiqua,palatino");
+    cm_default_mail_font.addElement(noI18n("Comic Sans MS"), "comic sans ms,sans-serif");
+    cm_default_mail_font.addElement(noI18n("Courier New"), "courier new,courier");
+    cm_default_mail_font.addElement(noI18n("Georgia"), "georgia,palatino");
+    cm_default_mail_font.addElement(noI18n("Helvetica"), "helvetica");
+    cm_default_mail_font.addElement(noI18n("Impact"), "impact,chicago");
+    cm_default_mail_font.addElement(noI18n("Symbol"), "symbol");
+    cm_default_mail_font.addElement(noI18n("Tahoma"), "tahoma,arial,helvetica,sans-serif");
+    cm_default_mail_font.addElement(noI18n("Terminal"), "terminal,monaco");
+    cm_default_mail_font.addElement(noI18n("Times New Roman"), "times new roman,times");
+    cm_default_mail_font.addElement(noI18n("Trebuchet MS"), "trebuchet ms,geneva");
+    cm_default_mail_font.addElement(noI18n("Verdana"), "verdana,geneva");
+    cm_default_mail_font.addElement(noI18n("Webdings"), "webdings");
+    cm_default_mail_font.addElement(noI18n("Wingdings"), "wingdings,zapf dingbats");
 	cm_default_mail_font.getDomNode();
 	
-	cm_default_mail_font_size = new ComboBox3(window, "cm_default_mail_font_size", "6em", 0, true,"OX_Configuration_Settings_Changed_GUI", 3);
-	cm_default_mail_font_size.addElement(_("Default"),'default');
-	cm_default_mail_font_size.addElement("1 (8pt)",1); 
-	cm_default_mail_font_size.addElement("2 (10pt)",2);
-	cm_default_mail_font_size.addElement("3 (12pt)",3); 
-	cm_default_mail_font_size.addElement("4 (14pt)",4);
-	cm_default_mail_font_size.addElement("5 (18pt)",5);
-	cm_default_mail_font_size.addElement("6 (24pt)",6);
-	cm_default_mail_font_size.addElement("7 (36pt)",7);  	
+	cm_default_mail_font_size = new ComboBox3(window, "cm_default_mail_font_size", "15em", 0, true,"OX_Configuration_Settings_Changed_GUI", 3);
+    cm_default_mail_font_size.addElement(_("Default"), "default");
+    cm_default_mail_font_size.addElement(noI18n("1 (8pt)"), 1);
+    cm_default_mail_font_size.addElement(noI18n("2 (10pt)"), 2);
+    cm_default_mail_font_size.addElement(noI18n("3 (12pt)"), 3);
+    cm_default_mail_font_size.addElement(noI18n("4 (14pt)"), 4);
+    cm_default_mail_font_size.addElement(noI18n("5 (18pt)"), 5);
+    cm_default_mail_font_size.addElement(noI18n("6 (24pt)"), 6);
+    cm_default_mail_font_size.addElement(noI18n("7 (36pt)"), 7);
 	cm_default_mail_font_size.getDomNode();
 	
 	cm_editor_featureset = new ComboBox3(window, "cm_editor_featureset", "15em", 0, true,"OX_Configuration_Settings_Changed_GUI", 3);
+	cm_editor_featureset.addElement(_("Minimized"),'3');
 	cm_editor_featureset.addElement(_("Default"),'1');
 	cm_editor_featureset.addElement(_("Enhanced"),'2'); 
 	cm_editor_featureset.getDomNode();
