@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -15,7 +15,8 @@
 
 register("OX_Configuration_Settings_Changed_Language",cs_changedLanguage);
 register("OX_Configuration_Settings_Changed_Timezone",cs_changedTimezone);
-register("OX_Configuration_Settings_Changed_GUI",cs_changedGui);
+register("OX_Configuration_Settings_Changed_UI", cs_changedUI);
+register("OX_Configuration_Settings_Changed_GUI", cs_changedGui);
 register("OX_Configuration_Settings_Changed_Mail",cs_changedMail);
 register("OX_Configuration_Settings_Changed_Modules",cs_changedModules);
 register("OX_Configuration_Settings_Changed_Calendar_Notification",cs_changedCalendarNotification);
@@ -31,8 +32,11 @@ function cs_changedMail() {
 function cs_changedModules() {
 	configuration_changed_fields["modules"]=true;
 }
+function cs_changedUI() {
+	configuration_changed_fields["ui"]=true;
+}
 function cs_changedGui() {
-	configuration_changed_fields["gui"]=true;
+    configuration_changed_fields["gui"]=true;
 }
 function cs_changedTimezone() {
 	configuration_changed_fields["timezone"]=true;
@@ -100,10 +104,40 @@ function setStringofRadioBox(nameofradios,value) {
 		} 
 	}
 }
+
+var applyConfigurableFlag = function (selector, key) {
+    // is configurable?
+    var flag = configGetKey(key + ".configurable");
+    // not defined?
+    if (flag === null && configGetKey(key) !== null) {
+        // make it configurable
+        configSetKey(key + ".configurable", true);
+    }
+    if (flag === false) {
+        jQuery(selector).hide();
+    } else {
+        jQuery(selector).show();
+    }
+};
+
 registerView("configuration/settings",
 	function() { 
 		showNode("config"); 
 		$("config").style.display="block";
+        
+        // toolbar
+        if (!configToolbars.settings) {
+            configToolbars.settings = temporary.configuration.newToolbar(
+                _("Options"), [temporary.configuration.saveButton], "options");
+        }
+        temporary.configuration.showToolbar(configToolbars.settings);
+        
+        // configurable: expert mode
+        applyConfigurableFlag("#configurable-expert", "ui.global.expert.mode");
+        // configurable: embedded mode
+        applyConfigurableFlag("#configurable-windows", "ui.global.windows.mode");
+        // configurable: toolbar
+        applyConfigurableFlag("#configurable-toolbar", "ui.global.toolbar.mode");
 	},
 		
 	function() { 
@@ -111,7 +145,6 @@ registerView("configuration/settings",
 		register("OX_Cancel_Object",cs_cancelConfiguration);
 		register("LanguageChanged",cs_changeHeader);
 		//init config
-		markConfigTreeNode('configuration/settings');
 		cs_enter(); 
         changeTab('tabConfiguration1', 'panelConfiguration1');
         $("panelConfiguration1").className="tabPanelFirstHi tabPanelHiColor background-color-content font-style-lable border-color-content-default";        
@@ -139,7 +172,7 @@ registerView("configuration/settings",
 
 function cs_changeHeader() {
 	if(currentpath2.join("/") == "configuration/settings") {
-		$("cs_header").firstChild.nodeValue=getconfigPathSelected().substring(1);
+		setConfigPath($("cs_header"));
 	}
 }
 
@@ -150,13 +183,14 @@ var configSettingsEventList = null;
 var cc_actualTree = null;
 
 function cs_saveConfiguration() {
-	if(configuration_changed_fields["timezone"]) {
+	if (configuration_changed_fields["timezone"]) {
 		configSetKey("timezone",cs_timezone.getKey());
 	}
 	if(configuration_changed_fields["language"]) {
 		configSetKey("language",cs_language.getKey());
-		setLanguage(configGetKey("language"));
-		cs_region_enter();
+		setLanguage(configGetKey("language"), function() {
+		    cs_region_enter();
+		});
 	}
     if (configuration_changed_fields["modules"]) {
         if (cc_actualTree === null) {
@@ -168,28 +202,64 @@ function cs_saveConfiguration() {
                 ox.JSON.put(AjaxRoot + "/config/modules/folder/tree?session=" +
                     session, selectedTree, function() {
                         actualTree = selectedTree;
-                        ox.Configuration.info(_("The new folder tree setting will take effect after a new login."/*i18n*/));
-                });
+                        ox.UINotifier.info(_("The new folder tree setting will take effect after a new login."/*i18n*/));
+                    }, null, true);
             }
         }
     }
-	if (configuration_changed_fields["gui"]) {		
-		var selectedTheme = cs_theme.getKey();		
-		if (selectedTheme != configGetKey("gui.theme").path && configContainsKey("modules.themes." + selectedTheme)) {
-			triggerEvent("OX_New_Info",4,_("Theme will be applied after a new login."/*i18n*/));
-			configSetKey("gui.theme", { name: configGetKey("modules.themes")[selectedTheme], path: selectedTheme });
-		}
-		
-		var selectedPage = cs_landingPage.getKey();		
+    
+    if (configuration_changed_fields.ui) {
+        
+        // windows
+        var val = getStringofRadioBox("cs_windows");
+        configSetKey("ui.global.windows.mode.value", val);
+        if (val === "embedded") {
+            embeddedWindows.enable(); // embedded
+        } else {
+            embeddedWindows.disable(); // popups
+        }
+        
+        // toolbar
+        val = getStringofRadioBox("cs_toolbar");
+        if (val !== configGetKey("ui.global.toolbar.mode.value")) {
+            configSetKey("ui.global.toolbar.mode.value", getStringofRadioBox("cs_toolbar"));
+            ox.UINotifier.info(_("The panel setting will take effect after a new login."/*i18n*/));
+        }
+        
+    }
+    
+    if (configuration_changed_fields["gui"]) {
+        
+        // switch theme?
+        var selectedTheme = cs_theme.getKey();
+        if (configContainsKey(["modules", "themes", selectedTheme])) {
+            // update (out of following if!)
+            var themeName = configGetKey("modules.themes")[selectedTheme];
+            configSetKey("gui.theme", { name: themeName, path: selectedTheme });
+            // don't switch on-the-fly
+            if (selectedTheme != oxThemeStyle.path) {
+                // notify
+                ox.UINotifier.info(
+                    _("Theme will be applied after a new login."/*i18n*/)
+                );
+            }
+        }
+        
+		// langing page
+		var selectedPage = cs_landingPage.getKey();
 		if (selectedPage) {
 			configSetKey("gui.global.landing_page", { module: selectedPage });
 		}
-			
+		
+		// expert tree?
+		var useExpert = getValueofRadioBox("cs_expert");
+		if (useExpert != configGetKey("gui.global.expert_tree")) {
+		    configSetKey("gui.global.expert_tree", useExpert);
+		    ox.UIController.setExpertTree(useExpert == 1 ? true : false);
+		}
+
  		configSetKey("gui.global.save",getValueofRadioBox("cs_saveconfig"));
 		configSetKey("gui.global.autorefresh",cs_autorefresh.getKey());
-		configSetKey("gui.portal.tooltip",getBoolofInt(getValueofRadioBox("cs_showquickinfo")));
-		configSetKey("gui.portal.infobox",getBoolofInt(getValueofRadioBox("cs_showinfobox")));
-		configSetKey("gui.portal.minicalendar",getBoolofInt(getValueofRadioBox("cs_showminicalendar")));
 		configSetKey("gui.effects.fading",getBoolofInt(getValueofRadioBox("cs_enableeffects")));
 		configSetKey("gui.effects.global",getBoolofInt(getValueofRadioBox("cs_enableeffects")));
 		configSetKey("gui.effects.hover.portal",getBoolofInt(getValueofRadioBox("cs_enablehoverportal")));
@@ -246,7 +316,7 @@ function cs_region_enter() {
 		$("cs_time_userdefined:0").disabled = true;
 		$("cs_time_userdefined:1").disabled = true;
 		$("cs_time_predefined:1").checked = true
-		var current_time_format = _("HH:mm");
+		var current_time_format = expectI18n(_("HH:mm"));
 	}
 	if(current_time_format.indexOf("a") != -1) {
 		$("cs_time_userdefined:0").checked = true;
@@ -300,6 +370,7 @@ function cs_region_set_date_format() {
 	} else {
 		cs_dateformat.disable();
 		cs_date_separator.disable();
+        //#. Default date format string
 		var current_date_format = _("yyyy-MM-dd");
 		var current_date_separator = false;
 	}
@@ -341,28 +412,35 @@ function cs_enter() {
 		cs_landingPage.setKey(configGetKey("gui.global.landing_page").module);
 		configuration_changed_fields["gui"]=false;
 	}
+	
+	// expert tree
+    if (configContainsKey("gui.global.expert_tree")) {
+        setIntofRadioBox("cs_expert", configGetKey("gui.global.expert_tree"));
+        configuration_changed_fields["gui"] = false;
+    }
+    
+    // embedded windows
+    if (configContainsKey("ui.global.windows.mode.value")) {
+        setStringofRadioBox("cs_windows", configGetKey("ui.global.windows.mode.value"));
+        configuration_changed_fields["ui"] = false;
+    }
+    
+    // toolbar
+    if (configContainsKey("ui.global.toolbar.mode.value")) {
+        setStringofRadioBox("cs_toolbar", configGetKey("ui.global.toolbar.mode.value"));
+        configuration_changed_fields["ui"] = false;
+    }
+    
 	cs_autorefresh.setKey(configGetKey("gui.global.autorefresh"));
 	if (configContainsKey("gui.global.save")) {
 		var id = configGetKey("gui.global.save");
 		setIntofRadioBox("cs_saveconfig", id);
 		configuration_changed_fields["gui"]=false;
 	}
-	if(configContainsKey("gui.portal.tooltip")) {
-		setIntofRadioBox("cs_showquickinfo",configGetKey("gui.portal.tooltip"));
-		configuration_changed_fields["gui"]=false;
-	}
-	if(configContainsKey("gui.portal.infobox")) {
-		setIntofRadioBox("cs_showinfobox",configGetKey("gui.portal.infobox"));
-		configuration_changed_fields["gui"]=false;
-	}
 	if(configContainsKey("gui.effects.global")) {
 		setIntofRadioBox("cs_enableeffects",configGetKey("gui.effects.global"));
 		configuration_changed_fields["gui"]=false;
 	}
-	if(configContainsKey("gui.portal.minicalendar")) {
-		setIntofRadioBox("cs_showminicalendar",configGetKey("gui.portal.minicalendar"));
-		configuration_changed_fields["gui"]=false;
-	}
 	if(configContainsKey("gui.effects.hover.portal")) {
 		setIntofRadioBox("cs_enablehoverportal",configGetKey("gui.effects.hover.portal"));
 		configuration_changed_fields["gui"]=false;
@@ -391,7 +469,7 @@ function cs_enter() {
 		setIntofRadioBox("cs_hoverspeed",configGetKey("gui.effects.hover.speed"));
 		configuration_changed_fields["gui"]=false;
 	}
-	$("cs_header").firstChild.nodeValue=getconfigPathSelected().substring(1);
+	setConfigPath($("cs_header"));
 	setTabLists(configSettingsTabsList, configSettingsPanelsList, null);
 } 
 
@@ -415,76 +493,82 @@ function cs_disableallhover() {
 		configuration_changed_fields["gui"]=true;
 }
 
-function cs_init() {
-    if(!configGetKey("modules.portal.module")) { $("cs_portal_hover").style.display="none"; }
-    if(!configGetKey("modules.mail.module")) { $("cs_mail_hover").style.display="none"; }
-    if(!configGetKey("modules.calendar.module")) { $("cs_calendar_hover").style.display="none"; }
-    if(!configGetKey("modules.contacts.module")) { $("cs_contacts_hover").style.display="none"; }
-    if(!configGetKey("modules.tasks.module")) { $("cs_tasks_hover").style.display="none"; }
-    if(!configGetKey("modules.infostore.module")) { $("cs_infostore_hover").style.display="none"; }
-	
-	var myarray=configGetKey("reloadtimes");
-	cs_autorefresh = new ComboBox3(window, "cs_autorefresh", "15em", 0, true,"OX_Configuration_Settings_Changed_GUI", 3);
-	cs_autorefresh.addElement("Never",0);/*i18n*/
-	var mTmp = function(n) { return function() { return getInterval(n); }; };
-	if(configContainsKey("reloadtimes")) {
-		for(var i=0;i<myarray.length;i++) {
-			if(!myarray[i]== 0) {
-				cs_autorefresh.addElement("",(myarray[i]/60000),mTmp(myarray[i]));
-			}
-		}
-	}
-	cs_autorefresh.getDomNode();
-	
-	// fake cb to prevent combobox translation 
-	function cb_tmpLang(element) {
-		return function() {
-			return element;
-		}
-	}
-	
-	cs_language = new ComboBox3(window, "cs_language", "15em", 0, true, "OX_Configuration_Settings_Changed_Language", 3);
-	for(var i in corewindow.all_languages) {
-		if (i) cs_language.addElement(corewindow.all_languages[i], i,
-		                       cb_tmpLang(corewindow.all_languages[i]));	
-	}
-	cs_language.getDomNode();
-	
-	cs_timezone = new ComboBox3(window, "cs_timezone", "25em", 1, true, "OX_Configuration_Settings_Changed_Timezone", 8);
-    var timezones = configGetKey("availableTimeZones");
+// (re-)draw timezone combo
+function cs_drawTimezoneCombo(timezones) {
+    var timezones = timezones || configGetKey("availableTimeZones");
+    jQuery("#cs_timezone").empty();
+    cs_timezone = new ComboBox3(window, "cs_timezone", "25em", 1, 
+            true, "OX_Configuration_Settings_Changed_Timezone", 8);
     var tzarray = [];
     for (var i in timezones) tzarray.push({key: i, value: timezones[i] });
     tzarray.sort(function(a, b) {
         return a.value < b.value ? -1 : a.value > b.value ? 1 : 0;
     });
-    for(var i = 0; i < tzarray.length; i++) {
-        cs_timezone.addElement(tzarray[i].value, tzarray[i].key);
+    for (var i = 0; i < tzarray.length; i++) {
+        cs_timezone.addElement(noI18n(tzarray[i].value), tzarray[i].key);
     }
-	cs_timezone.getDomNode();
+    cs_timezone.getDomNode();
+    cs_timezone.setKey(configGetKey("timezone"));
+}
+
+function cs_init() {
+    var modules = ox.api.ui.listModules();
+    // disable module specific settings if disabled
+    for (var i=0; i < modules.length; i++) {
+        if (modules[i].disabled === true && $("cs_" + modules[i].name + "_hover")) {
+            $("cs_" + modules[i].name + "_hover").style.display="none";
+        }
+    }
+	
+	var myarray=configGetKey("reloadtimes");
+	cs_autorefresh = new ComboBox3(window, "cs_autorefresh", "15em", 0, true,"OX_Configuration_Settings_Changed_GUI", 3);
+    cs_autorefresh.addElement(_("Never"), 0);
+	if(configContainsKey("reloadtimes")) {
+		for(var i=0;i<myarray.length;i++) {
+			if(!myarray[i]== 0) {
+				cs_autorefresh.addElement(getInterval(myarray[i]),
+				                          myarray[i]/60000);
+			}
+		}
+	}
+	cs_autorefresh.getDomNode();
+	
+	cs_language = new ComboBox3(window, "cs_language", "15em", 0, true, "OX_Configuration_Settings_Changed_Language", 3);
+	for(var i in corewindow.all_languages) {
+	    if (!i) continue;
+	    var lang = corewindow.all_languages[i];
+	    if (typeof lang == "string") lang = noI18n(lang);
+        cs_language.addElement(lang, i);
+	}
+	cs_language.getDomNode();
+	
+	// set timezone combo-box
+	cs_drawTimezoneCombo(configGetKey("availableTimeZones"));
 	
 	cs_dateformat = new ComboBox3(window, "cs_dateformat", "9em", 0, true, "OX_Configuration_Settings_Changed_Region_Date", 8);
-	cs_dateformat.addElement("M/d/yyyy"/*i18n*/, 	"M/d/yyyy");
-	cs_dateformat.addElement("M/d/yy"/*i18n*/, 		"M/d/yy");
-	cs_dateformat.addElement("MM/dd/yy"/*i18n*/, 	"MM/dd/yy");
-	cs_dateformat.addElement("MM/dd/yyyy"/*i18n*/, 	"MM/dd/yyyy");
-	cs_dateformat.addElement("yy/MM/dd"/*i18n*/, 	"yy/MM/dd");
-	cs_dateformat.addElement("dd/MM/yyyy"/*i18n*/, 	"dd/MM/yyyy");
-	cs_dateformat.addElement("dd/MM/yy"/*i18n*/, 	"dd/MM/yy");
-	cs_dateformat.addElement("dd.MM.yyyy"/*i18n*/,	"dd.MM.yyyy");	
-	cs_dateformat.addElement("dd.MM.yy"/*i18n*/, 	"dd.MM.yy");
-	cs_dateformat.addElement("d.MM.yy"/*i18n*/, 	"d.MM.yy");
-	cs_dateformat.addElement("d.M.yy"/*i18n*/, 		"d.M.yy");
-	cs_dateformat.addElement("d.M.yyyy"/*i18n*/, 	"d.M.yyyy");
-	cs_dateformat.addElement("yyyy-MM-dd", 	"yyyy-MM-dd",
-        function() { return pgettext("label", "yyyy-MM-dd"); });
-	cs_dateformat.addElement("dd-MMM-yy"/*i18n*/, 	"dd-MMM-yy");
+	cs_dateformat.addElement(_("M/d/yyyy"),   "M/d/yyyy");
+	cs_dateformat.addElement(_("M/d/yy"),     "M/d/yy");
+	cs_dateformat.addElement(_("MM/dd/yy"),   "MM/dd/yy");
+	cs_dateformat.addElement(_("MM/dd/yyyy"), "MM/dd/yyyy");
+	cs_dateformat.addElement(_("yy/MM/dd"),   "yy/MM/dd");
+	cs_dateformat.addElement(_("dd/MM/yyyy"), "dd/MM/yyyy");
+	cs_dateformat.addElement(_("dd/MM/yy"),   "dd/MM/yy");
+	cs_dateformat.addElement(_("dd.MM.yyyy"), "dd.MM.yyyy");	
+	cs_dateformat.addElement(_("dd.MM.yy"),   "dd.MM.yy");
+	cs_dateformat.addElement(_("d.MM.yy"),    "d.MM.yy");
+	cs_dateformat.addElement(_("d.M.yy"),     "d.M.yy");
+	cs_dateformat.addElement(_("d.M.yyyy"),   "d.M.yyyy");
+	//#. normal translation. replace letters only (e.g. jjjj-MM-tt)
+	//#. not to be confused with the default format
+	cs_dateformat.addElement(pgettext("label", "yyyy-MM-dd"), "yyyy-MM-dd");
+	cs_dateformat.addElement(_("dd-MMM-yy"),  "dd-MMM-yy");
 	cs_dateformat.getDomNode();
 	
 	cs_date_separator = new ComboBox3(window, "cs_dateseparator", "9em", 0, true, "OX_Configuration_Settings_Changed_Region_Date", 3);
-	cs_date_separator.addElement("default"/*i18n*/, 	"default");
-	cs_date_separator.addElement("/", 				"/");
-	cs_date_separator.addElement(".", 				".");
-	cs_date_separator.addElement("-", 				"-");
+	cs_date_separator.addElement(_("default"), "default");
+	cs_date_separator.addElement(noI18n("/"),  "/");
+	cs_date_separator.addElement(noI18n("."),  ".");
+	cs_date_separator.addElement(noI18n("-"),  "-");
 	cs_date_separator.getDomNode();
     
     var themes = [];
@@ -497,28 +581,32 @@ function cs_init() {
         	   return (a.name.toUpperCase() < b.name.toUpperCase() ? -1 : 1); 
         	});
     } else {
-        themes.push({ name: "Default", path: "default" });
+        themes.push({ name: _("Default"), path: "default" });
     }
     
 	cs_theme = new ComboBox3(window, "cs_theme", "30em", 0, true, "OX_Configuration_Settings_Changed_GUI", 3);
 	for(var i=0;i<themes.length;i++) {
-		cs_theme.addElement(themes[i].name, themes[i].path);	
+        cs_theme.addElement(
+            themes[i].name instanceof I18nString ? themes[i].name
+                                                 : noI18n(themes[i].name),
+            themes[i].path);	
 	}	
     cs_theme.getDomNode();
     
     
 	cs_landingPage = new ComboBox3(window, "cs_landing_page", "30em", 0, true, "OX_Configuration_Settings_Changed_GUI", 3);
+	var modules = ox.api.ui.listModules();
 	for(var i in modules) {
-		if (modules[i].disable == false && modules[i].name != "configuration") {
-			cs_landingPage.addElement(modules[i].text, modules[i].name);
+		if (modules[i].disabled == false && modules[i].name != "configuration") {
+			cs_landingPage.addElement(modules[i].title, modules[i].name);
 		}
 	}	
 	cs_landingPage.getDomNode();
 	
 	cs_tree = new ComboBox3(window, "cs_tree", "15em", 0, true,
 	    "OX_Configuration_Settings_Changed_Tree", 2);
-	cs_tree.addElement("Classic"/*i18n*/, 0);
-	cs_tree.addElement("New"/*i18n*/, 1);
+	cs_tree.addElement(_("Classic"), 0);
+	cs_tree.addElement(_("New"), 1);
 	cs_tree.getDomNode();
 }
 
