@@ -6,28 +6,50 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
  * 
  */
 
+/**
+ * A class for translated strings.
+ * Each I18n object has a toString() method which returns the translation based
+ * on the current language. All user-visible widgets expect instances of this
+ * class, and convert them to strings when the user changes the GUI language.
+ * @param {function()} toString A callback function which returns a translated
+ * text using the current GUI language.
+ */
+function I18nString(toString) { this.toString = toString; }
+I18nString.prototype = new String();
+I18nString.prototype.valueOf = function() { return this.toString(); };
+// TODO print warnings if one of the inherited methods is used.
+
 /**
  * Translates a string
  * @function
  * @param {String} text The original English text to translate.
- * @type String
+ * @type I18nString
  * @return The translated text.
  * @ignore
  */
 var _;
 
+/**
+ * Converts a string to a translated string without translation.
+ * Use only for user-entered data.
+ * @param {String} text The text which should not be translated.
+ * @type I18nString
+ * @return The text as an I18nString object.
+ */
+var noI18n;
+
 /**
  * Translates a string
  * @function
  * @param {String} text The original English text to translate.
- * @type String
+ * @type I18nString
  * @return The translated text.
  * @ignore
  */
@@ -39,7 +61,7 @@ var gettext;
  * @param {String} context A context to differentiate multiple identical texts
  * with different translations.
  * @param {String} text The original English text to translate.
- * @type String
+ * @type I18nString
  * @return The translated text.
  * @ignore
  */
@@ -52,7 +74,7 @@ var pgettext;
  * @param {String} context A context to differentiate multiple identical texts
  * with different translations.
  * @param {String} text The original English text to translate.
- * @type String
+ * @type I18nString
  * @return The translated text.
  */
 var dpgettext;
@@ -66,7 +88,7 @@ var dpgettext;
  * @param {String} context An optional context to differentiate multiple
  * identical texts with different translations.
  * @param {String} domain An optional i18n domain to use for the translation.
- * @type String
+ * @type I18nString
  * @return The translated text.
  * @ignore
  */
@@ -80,7 +102,7 @@ var ngettext;
  * @param {String} singular The original English text for the singular form.
  * @param {String} plural The original English text for the plural form.
  * @param {Number} n The number which determines which text form is used.
- * @type String
+ * @type I18nString
  * @return The translated text.
  * @ignore
  */
@@ -95,7 +117,7 @@ var npgettext;
  * @param {String} singular The original English text for the singular form.
  * @param {String} plural The original English text for the plural form.
  * @param {Number} n The number which determines which text form is used.
- * @type String
+ * @type I18nString
  * @return The translated text.
  */
 var dnpgettext;
@@ -129,32 +151,60 @@ var setLanguage;
  */
 var getDictionary;
 
+/**
+ * Returns an array with currently registered i18n domains. I18n domains are
+ * used by plugins to allow for independent translation.
+ * @function
+ * @type Array
+ * @return An array of strings, including one empty string for the default
+ * domain.
+ */
+var listI18nDomains;
+
+/**
+ * Installs a PO file from a string parameter instead of downloading it from
+ * the server.
+ * In case of a syntax error, an exception is thrown.
+ * If the specified language file is already loaded, it will be replaced.
+ * When replacing a file for the currently active language, the settings take
+ * effect immediately.
+ * @function
+ * @param {String} domain The i18n domain of the file. Usually the ID of
+ * a plugin or the empty string for the translation of the core.
+ * @param {String} language The language of the file.
+ * @param {String} data The contents of the PO file.
+ */
+var replacePOFile;
+
 /**
  * Formats a string by replacing printf-style format specifiers in the string
  * with dynamic parameters. Flags, width, precision and length modifiers are
  * not supported. All type conversions are performed by the standard toString()
  * JavaScript method.
- * @param {I18nString} string The format string.
+ * @param {String or I18nString} string The format string.
  * @param params Either an array with parameters or multiple separate
  * parameters.
- * @type I18nString
+ * @type String or I18nString
  * @return The formatted string.
  */
 function format(string, params) {
 	var param_array = params;
-	if (typeof(params) != "object") {
+	if (Object.prototype.toString.call(params) != "[object Array]") {
 		param_array = new Array(arguments.length - 1);
 		for (var i = 1; i < arguments.length; i++)
 			param_array[i - 1] = arguments[i];
 	}
-    if (typeof string == "function") {
-        return function() { return formatRaw(string(), param_array); };
+    if (string instanceof I18nString) {
+        return new I18nString(function() {
+            return formatRaw(string, param_array);
+        });
     } else {
         return formatRaw(string, param_array);
     }
 }
 
 /**
+ * @private
  * Formats a string by replacing printf-style format specifiers in the string
  * with dynamic parameters. Flags, width, precision and length modifiers are
  * not supported. All type conversions (except from I18nString) are performed
@@ -186,15 +236,64 @@ function formatRaw(string, params) {
  * @ignore
  */
 function formatError(result, formatString) {
-	//#. %1$s is the error code.
-	//#. %2$s is the formatted error message.
-    //#. %3$s is the unique error ID.
-	//#, c-format
-	return format(formatString || _("Error: %2$s (%1$s, %3$s)"), result.code,
+    if (!formatString) {
+        switch (result.category) {
+            case 5:
+            case 7:
+            case 8:
+            case 10:
+                //#. %1$s is the error code.
+                //#. %2$s is the formatted error message (not used).
+                //#. %3$s is the unique error ID.
+                //#, c-format
+                formatString = _("An error occurred. (%1$s, %3$s)");
+                break;
+            case 6:
+                //#. %1$s is the error code.
+                //#. %2$s is the formatted error message (not used).
+                //#. %3$s is the unique error ID.
+                //#, c-format
+                formatString = _("An error occurred. Please try again later. (%1$s, %3$s)");
+                break;
+            case 13:
+                //#. %1$s is the error code (not used).
+                //#. %2$s is the formatted error message.
+                //#. %3$s is the unique error ID (not used).
+                //#, c-format
+                formatString = _("Warning: %2$s");
+                break;
+            default:
+                //#. %1$s is the error code (not used).
+                //#. %2$s is the formatted error message.
+                //#. %3$s is the unique error ID (not used).
+                //#, c-format
+                formatString = _("Error: %2$s");
+        }
+    }
+	return format(formatString, result.code,
                   format(_(result.error), result.error_params),
                   result.error_id);
 }
 
+/**
+ * Utility function which checks for untranslated strings.
+ * Should be used by widget implementations to convert I18nString to strings
+ * immediately before displaying them.
+ * @param {I18nString} text The translated text.
+ * @type String
+ * @return The current translation of the text as a string.
+ */
+function expectI18n(text) {
+    expectI18n = debug ? function(text) {
+        if (!(text instanceof I18nString)) {
+            console.warn("Untranslated text:",
+                typeof text == "function" ? text() : text, getStackTrace());
+        }
+        return String(text);
+    } : String;
+    return expectI18n(text);
+}
+
 (function() {
     var current, current_lang;
     var domains = { "": "lang/%s.js" };
@@ -203,13 +302,26 @@ function formatError(result, formatString) {
 	var counter = 0;
 
 	_ = gettext = function(text) { return dpgettext("", "", text); };
+	
+	noI18n = function(text) { return new I18nString(constant(text)); };
     
     pgettext = function(context, text) { return dpgettext("", context, text); };
     
-    dpgettext = function(domain, context, text) {
-        var c = current && current[domain || ""];
-        var key = context ? context + "\0" + text : text;
-        return c && c.dictionary[key] || text;
+    function dpgettext_(domain, context, text) {
+        return new I18nString(function() {
+            var c = current && current[domain || ""];
+            var key = context ? context + "\0" + text : text;
+            return c && c.dictionary[key] || text;
+        });
+    }
+    dpgettext = function() {
+        dpgettext = debug ? function(domain, context, text) {
+            if (text instanceof I18nString) {
+                console.error("Retranslation", text);
+            }
+            return dpgettext_.apply(this, arguments);
+        } : dpgettext_;
+        return dpgettext.apply(this, arguments);
     };
     
     ngettext = function(singular, plural, n) {
@@ -222,13 +334,16 @@ function formatError(result, formatString) {
     
     dnpgettext = function(domain, context, singular, plural, n) {
 		var text = n != 1 ? plural : singular;
-        var c = current && current[domain || ""];
-        if (!c) return text;
-        var key = context ? [context, "\0", singular, "\x01", plural].join("")
-                          : [               singular, "\x01", plural].join("");
-		var translation = c.dictionary[key];
-		if (!translation) return text;
-		return translation[Number(c.plural(n))] || text;
+		return new I18nString(function() {
+            var c = current && current[domain || ""];
+            if (!c) return text;
+            var key = context ?
+                [context, "\0", singular, "\x01", plural].join("") :
+                [               singular, "\x01", plural].join("");
+    		var translation = c.dictionary[key];
+    		if (!translation) return text;
+    		return translation[Number(c.plural(n))] || text;
+		});
 	};
 
     function parse(pattern, file) {
@@ -239,21 +354,41 @@ function formatError(result, formatString) {
         }
     }
     
-    bindtextdomain = function(domain, pattern) {
+    bindtextdomain = function(domain, pattern, cont) {
         domains[domain] = pattern;
-        if (languages[current_lang] === current) setLanguage(current_lang);
+        if (languages[current_lang] === current) {
+            setLanguage(current_lang, cont);
+        } else {
+            if (cont) { cont(); }
+        }
+    };
+    
+    listI18nDomains = function() {
+        var result = [];
+        for (var i in domains) result.push(i);
+        return result;
+    };
+    
+    replacePOFile = function(domain, language, data) {
+        if (!languages[language]) languages[language] = {};
+        languages[language][domain] = parsePO(data);
+        if (language == current_lang) setLanguage(current_lang);
     };
 
-	setLanguage = function(name) {
+	setLanguage = function (name, cont) {
+	    if (!name) {
+	        if (cont) cont();
+	        return;
+	    }
         current_lang = name;
         var new_lang = languages[name];
 		if (!new_lang) {
-            loadLanguage(name);
+            loadLanguage(name, cont);
             return;
         }
         for (var i in domains) {
             if (!(i in new_lang)) {
-                loadLanguage(name);
+                loadLanguage(name, cont);
                 return;
             }
         }
@@ -284,21 +419,68 @@ function formatError(result, formatString) {
 		}
         triggerEvent("LanguageChangedInternal");
 		triggerEvent("LanguageChanged");
+		if (cont) { cont(name); }
     };
     
-    function loadLanguage(name) {
+    loadOnce = (function () {
+        
+        var pending = {};
+        
+        var process = function (url, type, args) {
+            // get callbacks
+            var list = pending[url][type], i = 0, $i = list.length;
+            // loop
+            for (; i < $i; i++) {
+                // call back
+                if (list[i]) {
+                    list[i].apply(window, args || []);
+                }
+            }
+            list = null;
+            delete pending[url];
+        };
+        
+        return function (url, success, error) {
+            
+            if (pending[url] === undefined) {
+                // mark as pending
+                pending[url] = { success: [success], error: [error] };
+                // load file
+                jQuery.ajax({
+                    url: url,
+                    dataType: "text",
+                    success: function () {
+                        // success!
+                        process(url, "success", arguments);
+                    },
+                    error: function () {
+                        // error!
+                        process(url, "error", arguments);
+                    }
+                });
+            } else {
+                // enqueue
+                pending[url].success.push(success);
+                pending[url].error.push(error);
+            }
+        };
+        
+    }());
+    
+    function loadLanguage(name, cont) {
 		// check the main window
         if (corewindow != window) {
             var core_dict = corewindow.getDictionary(name);
             if (core_dict) {
     			current = languages[name] = core_dict;
-                setLanguage(name);
+                setLanguage(name, cont);
                 return;
     		}
         }
         var curr = languages[name];
         if (!curr) curr = languages[name] = {};
-        var join = new Join(function() { setLanguage(name); });
+        var join = new Join(function() { setLanguage(name, cont); });
+        var lock = join.add();
         for (var d in domains) {
             if (!(d in curr)) {
             	// get file name
@@ -307,26 +489,31 @@ function formatError(result, formatString) {
             	file = file.replace(/(de_DE|en_GB|en_US)\.js/, "$1.jsz");
             	// inject version
             	var url = urlify(file);
-            	// get language file
-                (new JSON()).get(url, null,
-                    join.add((function(domain) {
+            	// get language file (once!)
+            	loadOnce(
+            	    url,
+            	    // success
+            	    join.add((function(domain) {
                         return function(file) {
                             try {
-                                languages[name][domain] =
-                                    parse(domains[domain], file);
+                                languages[name][domain] = parse(domains[domain], file);
                             } catch (e) {
                                 triggerEvent("OX_New_Error", 4, e);
                                 join.add(); // prevent setLanguage()
                             }
                         };
-                    })(d)), join.alt((function(domain) {
-                        return function(result, status) {
+                    })(d)),
+                    // error
+                    join.alt((function(domain) {
+                        return function(xhr) {
                             languages[name][domain] = false;
-                            return status == 404;
+                            return String(xhr.status) === "404";
                         };
-                    })(d)), true);
+                    })(d))
+                );
             }
 		}
+        lock();
 	}
 	
 	getDictionary = function(name) { return languages[name]; };	
@@ -334,6 +521,14 @@ function formatError(result, formatString) {
 })();
 
 function parsePO(file) {
+    
+    var po = { nplurals: 1, plural: function(n) { return 0; }, dictionary: {} };
+    
+    // empty PO file?
+    if (/^\s*$/.test(file)) {
+        return po;
+    }
+    
     parsePO.tokenizer.lastIndex = 0;
     var line_no = 1;
     
@@ -373,13 +568,11 @@ function parsePO(file) {
     if (clause("msgid") != "") throw new Error("Missing PO file header");
     var header = clause("msgstr");
     if (parsePO.headerRegExp.exec(header)) {
-        var po = (new Function("return " + header.replace(parsePO.headerRegExp,
+        po = (new Function("return " + header.replace(parsePO.headerRegExp,
             "{ nplurals: $1, plural: function(n) { return $2; }, dictionary: {} }"
             )))();
-    } else {
-        var po = { nplurals: 1, plural: function(n) { return 0; },
-                   dictionary: {} };
     }
+    
     while (lookahead) {
         var ctx = clause("msgctxt", true);
         var id = clause("msgid");
@@ -404,7 +597,7 @@ parsePO.tokenizer = new RegExp(
     '^(#.*|[ \\t\\v\\f]+)$' +                  // comment or empty line
     '|(\\r\\n|\\r|\\n)' +                      // linebreak (for line numbering)
     '|^(msg[\\[\\]\\w]+)(?:$|[ \\t\\v\\f]+)' + // keyword
-    '|[ \\t\\v\\f]*(".*")\\s*$' +              // string
+    '|[ \\t\\v\\f]*("[^\r\n]*")\\s*$' +        // string
     '|(.)',                                    // anything else is an error
     "gm");
 
@@ -430,15 +623,21 @@ parsePO.headerRegExp = new RegExp(
  */
 function I18nNode(callback, template) {
     if (template) for (var i in template) this[i] = template[i];
-    if (typeof callback != "function") {
-        if (debug) {
-            (console.warn || console.log || alert)(format(
-                "The string \"%s\" is not internationalized!", callback));
-            eval("debugger");
-        }
-        this.callback = function() { return _(callback); };
+    if (callback instanceof I18nString) {
+        this.callback = function() { return String(callback); };
     } else {
-        this.callback = callback;
+        if (typeof callback != "function") {
+            if (debug) {
+                console.warn("Untranslated string:", callback, getStackTrace());
+            }
+            this.callback = function() { return _(callback); };
+        } else {
+            if (debug) {
+                console.warn("Untranslated string:", callback(),
+                             getStackTrace());
+            }
+            this.callback = callback;
+        }
     }
     this.index = ++I18nNode.counter;
 	this.node = document.createTextNode(this.callback());
@@ -458,7 +657,7 @@ I18nNode.prototype = {
                 this.callback, typeof this.callback));
         } else {
 /**#nocode+*/
-            this.node.data = this.callback();
+            this.node.nodeValue = this.callback();
 /**#nocode-*/
         }
     },
@@ -498,8 +697,8 @@ register("LanguageChanged", function() {
  * @ignore
  */
 function addTranslated(text, context, domain) {
-	return (new I18nNode(typeof text == "function" ? text
-        : function() { return dpgettext(domain, context, text); })).node;
+	return (new I18nNode(text instanceof I18nString ? text :
+	    dpgettext(domain, context, text))).node;
 }
 
 /**
@@ -516,6 +715,16 @@ function isToday(utc) {
     return diff >= 0 && diff < 864e5; // ms/day
 }
 
+/**
+ * Same as isToday but using local time
+ */
+function isLocalToday(t) {
+    var local = new Date(now()), utc = new Date(t);
+    return local.getUTCDate() === utc.getUTCDate() && 
+        local.getUTCMonth() === utc.getUTCMonth() && 
+        local.getUTCFullYear() === utc.getUTCFullYear();
+}
+
 /**
  * The first week with at least daysInFirstWeek days in a given year is defined
  * as the first week of that year.
@@ -683,16 +892,19 @@ var weekdays = [];
 		Z: function() { return ""; }
 	};
 	formatDateTime = function(format, date) {
-		return format.replace(regex,
-			function(match, fmt, text, quote) {
-				if (fmt) {
-					return funs[fmt.charAt(0)](fmt.length, date);
-				} else if (text) {
-					return text;
-				} else if (quote) {
-					return "'";
-				}
-			});
+        return format instanceof I18nString ? new I18nString(fmt) : fmt();
+	    function fmt() {
+            return String(format).replace(regex,
+                function(match, fmt, text, quote) {
+                    if (fmt) {
+                        return funs[fmt.charAt(0)](fmt.length, date);
+                    } else if (text) {
+                        return text;
+                    } else if (quote) {
+                        return "'";
+                    }
+                });
+	    }
 	};
     
     var f = "G+|y+|M+|w+|W+|D+|d+|F+|E+|a+|H+|k+|K+|h+|m+|s+|S+|z+|Z+";
@@ -718,7 +930,7 @@ var weekdays = [];
     register("LanguageChangedInternal", recreateMaps);
     
     function escape(rex) {
-        return rex.replace(/[$^\\.*+?()[\]{}|]/g, "\\$");
+        return String(rex).replace(/[$^\\.*+?()[\]{}|]/g, "\\$");
     }
 
     var numRex = "([+-]?\\d+)";
@@ -764,7 +976,7 @@ var weekdays = [];
                           : function(s, d) { d.m = s - 1; };
         },
         w: emptyFunction, W: emptyFunction, D: emptyFunction,
-        d: function(n) { return function(s, d) { d.d = s }; },
+        d: function(n) { return function(s, d) { d.d = s; }; },
         F: emptyFunction, E: emptyFunction,
         a: function(n) { return function(s, d) { d.pm = s == _("PM"); }; },
         H: function(n) { return function(s, d) { d.h = s; }; },
@@ -816,7 +1028,17 @@ var weekdays = [];
         var date = new Date(0);
         date.setUTCFullYear(d.y, d.m, d.d);
         date.setUTCHours(d.h, d.min, d.s, d.ms);
-        return date;
+        // double check
+        var yy = parseInt(d.y, 10), mm = parseInt(d.m, 10), dd = parseInt(d.d, 10);
+        if (    date.getUTCFullYear() === yy &&
+                date.getUTCMonth() === mm &&
+                date.getUTCDate() === dd) {
+            // ok!
+            return date;
+        } else {
+            // example: 2010-30-02, 2010-01-01 (as dd-mm-yy)
+            return null;
+        }
     };
 
 })();
@@ -859,6 +1081,7 @@ var parseDateString;
     function updateFormats() {
         var date_def = configGetKey("gui.global.region.date.predefined") != 0;
         var time_def = configGetKey("gui.global.region.time.predefined") != 0;
+        //#. Default date format string
         var date = date_def ? _("yyyy-MM-dd")
                             : configGetKey("gui.global.region.date.format");
         var time = time_def ? _("HH:mm")
@@ -1049,13 +1272,36 @@ function getInterval(t, until) {
 }
 
 var currencies = [
-            { iso: "CAD", name: "Canadian dollar", isoLangCodes: [ "CA" ] },
-            { iso: "CHF", name: "Swiss franc", isoLangCodes: [ "CH" ] },
-            { iso: "DKK", name: "Danish krone", isoLangCodes: [ "DK" ] },
-            { iso: "EUR", name: "Euro", isoLangCodes: [ "AT", "BE", "CY", "FI", "FR", "DE", "GR", "IE", "IT", "LU", "MT", "NL", "PT", "SI", "ES" ] },
-            { iso: "GBP", name: "Pound sterling", isoLangCodes: [ "GB" ] },
-            { iso: "PLN", name: "Zloty", isoLangCodes: [ "PL" ] },
-            { iso: "RUB", name: "Russian rouble", isoLangCodes: [ "RU" ] },
-            { iso: "SEK", name: "Swedish krona", isoLangCodes: [ "SE" ] },
-            { iso: "USD", name: "US dollar", isoLangCodes: [ "US" ] }
-        ];    
+            { iso: "CAD" /*i18n*/, name: "Canadian dollar" /*i18n*/, isoLangCodes: [ "CA" ] },
+            { iso: "CHF" /*i18n*/, name: "Swiss franc" /*i18n*/, isoLangCodes: [ "CH" ] },
+            { iso: "DKK" /*i18n*/, name: "Danish krone" /*i18n*/, isoLangCodes: [ "DK" ] },
+            { iso: "EUR" /*i18n*/, name: "Euro" /*i18n*/, isoLangCodes: [ "AT", "BE", "CY", "FI", "FR", "DE", "GR", "IE", "IT", "LU", "MT", "NL", "PT", "SI", "ES" ] },
+            { iso: "GBP" /*i18n*/, name: "Pound sterling" /*i18n*/, isoLangCodes: [ "GB" ] },
+            { iso: "PLN" /*i18n*/, name: "Zloty" /*i18n*/, isoLangCodes: [ "PL" ] },
+            { iso: "RUB" /*i18n*/, name: "Russian rouble" /*i18n*/, isoLangCodes: [ "RU" ] },
+            { iso: "SEK" /*i18n*/, name: "Swedish krona" /*i18n*/, isoLangCodes: [ "SE" ] },
+            { iso: "USD" /*i18n*/, name: "US dollar" /*i18n*/, isoLangCodes: [ "US" ] },
+            { iso: "JPY" /*i18n*/, name: "Japanese Yen" /*i18n*/, isoLangCodes: [ "JP" ] },
+            { iso: "RMB" /*i18n*/, name: "Renminbi" /*i18n*/, isoLangCodes: [ "CN", "TW" ] }
+        ];
+
+// time-based greeting phrase
+var getGreetingPhrase  = function (time) {
+    // vars
+    var hour, phrase;
+    // now?
+    if (time === undefined) {
+        hour = new Date().getHours();
+    } else {
+        hour = new Date(time).getHours();
+    }
+    // find proper phrase
+    if (hour >= 5 && hour <= 11) {
+        phrase = _("Good morning");
+    } else if (hour >= 18 && hour <= 23) {
+        phrase = _("Good evening");
+    } else {
+        phrase = _("Hello");
+    }
+    return phrase;
+};
