@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -17,7 +17,7 @@ var bInfoSplitLoaded = false;
 var bInfoSplitCreated = false;
 var gridInfoSplit;
 var editInfoItemId = -1;
-var newInfoJson = new JSON();
+var newInfoJson = new JSONX();
 var infostoreRequest;
 var gridVersionsInfoSplit;
 var aCoumnsToFetch = new Array(705,705,4,702,703,704,710,2,709);
@@ -33,17 +33,18 @@ register("Loaded", function() {
 	infostore_folderPathDetail.className="linkstyle";
 });
 
-function fn_infostore_getDetails(objects, forceUpdate) {	
+function fn_infostore_getDetails(objects, forceUpdate, changeView) {
     if (!objects.length || activemodule != "infostore") return;
         
     // changing the selection jumps back to overview tab
-    if (currentpath2[1] == "split" && currentpath2[2] != "overview") { 
+    if ((changeView === undefined || changeView === true) 
+            && currentpath2[1] === "split" && currentpath2[2] !== "overview") { 
         triggerEvent("OX_Switch_View", "infostore/split/overview");
     }
     
     enableInfostoreLoadingScreen(true);
         
-    var collection={}
+    var collection={};
     collection.objects=[objects[0]];
     collection.columns=null;
     if (infostoreRequest) {
@@ -52,14 +53,14 @@ function fn_infostore_getDetails(objects, forceUpdate) {
     }
         
     infostoreRequest=OXCache.newRequest(null, "infostore", collection, function(daten) {
-        if (!daten || !daten.objects) {
+        if (!daten || !daten.objects || !daten.objects.length) {
             enableInfostoreLoadingScreen(false);
             return;
         }
         getVersions(); // updating versions
         updateInfostoreSplit(daten.objects[0]);
     }, function(daten) {
-        if (!daten || !daten.objects) {
+        if (!daten || !daten.objects || !daten.objects.length) {
             enableInfostoreLoadingScreen(false);
             return;
         }
@@ -105,13 +106,20 @@ function enableInfostoreLoadingScreen(enabled) {
 }
 
 function openInfostoreFile(evt, sValueCl, nObjectIdCl, triggerSave) {
-    var sContentType = 'application/octet-stream';
-    var sURL = AjaxRoot + '/infostore/' 
-                + encodeURIComponent(sValueCl)
-                + '?action=document&session=' + session
-                + (triggerSave ? '&content_type=' + encodeURIComponent(sContentType) : "")
-                + '&id=' + encodeURIComponent(nObjectIdCl);
-    newWindow(sURL, getWindowOptions(null, null, (!triggerSave ? "scrollbars=yes" : "")));
+    
+    // Chrome always downloads or directly opens a file (i.e., it never shows content inline)
+    if (triggerSave || ox.browser.Chrome) {
+        // download
+        ox.api.infostore.download({
+            id: nObjectIdCl,
+            filename: sValueCl
+        });
+    } else {
+        ox.api.infostore.open({
+            id: nObjectIdCl,
+            filename: sValueCl
+        });
+    }
     stopEvent(evt);
 }
 
@@ -170,6 +178,7 @@ function updateInfostoreSplit(object) {
                   var oNodAncS = newnode("img", { paddingRight:"5px" },{ className: "cursorPointer", align:"absmiddle", src:getFullImgSrc("img/menu/attachment_save.gif") })
                   oNodAncS.onclick = (function(idvalue, object) { 
             	         return function(e) {
+            	            // save
             	         	openInfostoreFile(e || event, idvalue, object["id"], true);
             	         } 
     	          })(idvalue, object);
@@ -177,8 +186,9 @@ function updateInfostoreSplit(object) {
                   
 	              function _openFile(idvalue, object) { 
                 	  return function(e) {
+                	      // called from link
                 		  openInfostoreFile(e || event, idvalue, object["id"]);
-                	  } 
+                	  }
                   }
 	              
                   var oNodAnc = newnode("span", 0, {className:"linkstyle"},
@@ -205,9 +215,18 @@ function updateInfostoreSplit(object) {
                         $("infosplit.link_info").style.display="";
                   }
                   removeChildNodes($("infosplit."+idfield));
-                  $("infosplit."+idfield).appendChild(
-                        newnode("a",0,{className:"linkstyle", href: idvalue, target: "_blank"},
-                                [ document.createTextNode(idvalue)]));
+                  // adjust link
+                  var href = /^(\w+\.)+\w+(\/|$)/i.test(idvalue) ? "http://" + idvalue : idvalue;
+                  // add <A> element
+                  $("infosplit." + idfield).appendChild(
+                      newnode("a", 0, {
+                          className: "linkstyle",
+                          href: href,
+                          target: "_blank"
+                      }, [
+                          document.createTextNode(idvalue)
+                      ])
+                  );
                   continue;
                   break;
             case "file_size":
@@ -304,9 +323,11 @@ function updateInfostoreSplit(object) {
         },0);
 }
 
-function cb_infostore_selection_changed() {
-    if (!infostoreSelection.getSelected().length) return;   
-    fn_infostore_getDetails(infostoreSelection.getSelected());        
+function cb_infostore_selection_changed(forceUpdate, changeView) {
+    if (!infostoreSelection.getSelected().length) {
+        return;
+    }
+    fn_infostore_getDetails(infostoreSelection.getSelected(), forceUpdate, changeView);
 }
 
 function clearInfostoreSplitDetails() {
@@ -352,7 +373,7 @@ function loadLiveGridInfoSplit() {
 				sortable: false,		
 				set: function(div, content) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "1px", width: "16", height: "16" },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "1px", width: "16px", height: "16px" },{ align: "top" }));
 					}
 					div.firstChild.src = content["locked_until"] > 0 ? 
 					       getFullImgSrc("img/folder/document_locked.gif") : 
@@ -360,7 +381,7 @@ function loadLiveGridInfoSplit() {
 				},
 				clear: function(div) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "1px", width: "16", height: "16" },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "1px", width: "16px", height: "16px" },{ align: "top" }));
 					}
 					div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
 				}
@@ -372,7 +393,7 @@ function loadLiveGridInfoSplit() {
 				style: { padding: 0, textAlign: "center" },
 				set: function(div, content) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "2px", width: "7", height: "14"  },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "2px", width: "7px", height: "14px"  },{ align: "top" }));
 					}
 					div.firstChild.src = (content["file_size"]>0) ? getFullImgSrc("img/mail/attachment.gif")
 					                             : getFullImgSrc("img/mail/noattachment.gif");
@@ -393,7 +414,7 @@ function loadLiveGridInfoSplit() {
 				},
 				clear: function(div) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "2px", width: "7", height: "14" },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "2px", width: "7px", height: "14px" },{ align: "top" }));
 					}
 					div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
 				}
@@ -411,6 +432,7 @@ function loadLiveGridInfoSplit() {
 				i18n: true,
 				sortable: true,
 				sort : "file_size",
+				style: {textAlign: "right"},
 				width: "6em",
 				set: function (div, text) {
 					if (text < 0) {
@@ -483,21 +505,20 @@ function loadLiveGridInfoSplit() {
 				clear: LiveGrid.makeClear("")
 			}, {
 				name : ["color_label"],		
-				text: "Flag", /*i18n*/
-				i18n: true,				
+				text: "&#160;",
 				sortable: true,
 				sort : "color_label",
 				width: "4em",
 				style: { padding: 0, textAlign: "center" },
 				set: function(div, content) {
                     if (!div.firstChild) {
-                        div.appendChild(newnode("img", { paddingTop: "2px", width: "16", height: "16" },{ align: "top" }));
+                        div.appendChild(newnode("img", { paddingTop: "2px", width: "16px", height: "16px" },{ align: "top" }));
                     }
                     div.firstChild.src = getFullImgSrc("img/menu/tag_"+ (content || 0 ) +".gif");
                 },
                 clear: function(div) {
                     if (!div.firstChild) {
-                        div.appendChild(newnode("img", { paddingTop: "2px", width: "16", height: "16" },{ align: "top" }));
+                        div.appendChild(newnode("img", { paddingTop: "2px", width: "16px", height: "16px" },{ align: "top" }));
                     }
                     div.firstChild.src = getFullImgSrc("img/menu/tag_0.gif");
                 }
@@ -510,39 +531,41 @@ function loadLiveGridInfoSplit() {
 		gridInfoSplit.events.register("Selected", function(ids){
 			setLastSelected(ids);			
 			if (ids == 1)  {                
-                cb_infostore_selection_changed();                
+                cb_infostore_selection_changed();
             } else if (currentpath2[1]=="split") {
                 clearInfostoreSplitDetails();
             }
-            checkLockUnLock(gridInfoSplit.getSelectedIDs());
-            triggerEvent("Selected", gridInfoSplit.getSelectedIDs());
+            var selected = gridInfoSplit.getSelectedIDs();
+			checkLockUnLock(selected);
+            checkLockUnLock.wait(function() {
+                triggerEvent("Selected", selected);
+            });
 		});
 		gridInfoSplit.events.register("Activated", function(ids){
 			if(ids && ids.length > 0) {
-			    checkLockUnLock.wait(function() {
-    				if(   menucheckRight("WRITE")
-                       && menucountlockable + menucounteditable == 1)
-                    {
-    					editItem();
-                    } else {
-                        triggerEvent("OX_New_Error", 4,
-                            _("You do not have write permission for this object."));
-                    }
-			    });
+			    // instead of edit, download them
+			    // firefox - for whatever reason - needs a delay (some conflict with doubleclick)
+			    setTimeout(function () {
+                    saveFileinInfoStore(ids);
+                }, 250);
 			} else {
 				triggerEvent("OX_Before_Create_InfoStore");
 			}
 		});
-		gridInfoSplit.events.register("Delete", function(ids) {
-			if (menucheckRight("DELETE") && (ids.length > 0) && (ids.length == menucountlockable))
-				deleteItems();
-			}	
-		);
+        gridInfoSplit.events.register("Delete", function(ids) {
+            checkLockUnLock.wait(function() {
+                if (menucheckRight("DELETE") && ids.length > 0 && 
+                        ids.length == menucountlockable + menucounteditable) {
+                    deleteItems();
+                }
+            });
+        });
 		gridInfoSplit.events.register("Changed",infostore_HeaderUpdate);
-		var hv = gridInfoSplit.addHover(OXInfostoreHover.getContent().node, function(id) {
-	        OXInfostoreHover.actualHover=hv;
-	        OXInfostoreHover.refillContent(id.id,id.folder_id);                 
-	    });
+		var hv = gridInfoSplit.addHover(OXInfostoreHover.getContent().node,
+		    function(id, manual) {
+    	        OXInfostoreHover.actualHover=hv;
+    	        OXInfostoreHover.refillContent(id.id,id.folder_id);                 
+    	    });
 	    hv.setSize(OXInfostoreHover.contentobject.node);
 	}
     if (bInfoListCreated) {    
@@ -562,8 +585,8 @@ function loadDetailDocumentVersions(arg, cb_functionDetail) {
             
             if (div.firstChild) { div.firstChild.data = sDisplayString; }
             else { div.appendChild(document.createTextNode(text)); }
-        }   
-        if(!bVersionCreated) {
+        }
+        if (!bVersionCreated) {
 	        bVersionCreated = true; 
 	        var clear = LiveGrid.makeClear("...");
 	        var DomListDiv = $("lg_versions_info_split");
@@ -630,17 +653,28 @@ function loadDetailDocumentVersions(arg, cb_functionDetail) {
 	        DomListDivHeader.appendChild(gridVersionsInfoSplit.getHeader());
 	        gridVersionsInfoSplit.getTable(DomListDiv);
 	        gridVersionsInfoSplit.events.register("Selected", function(ids) {
-	            refreshDetailVersions(ids);                 
-	            triggerEvent("SubSelected",ids);
+	            refreshDetailVersions(ids);
+	            // map current array f|_|ck3l selection to a valid object selection
+	            var result = [];
+	            versionsStorage.newIterate(gridVersionsInfoSplit.getSelectedIDs(), jQuery.noop, 
+                function(id, obj) {
+	                // 705,705,4,702,703,704,710,2,709
+	                result.push({ version: obj[1], creation_date: obj[2], 
+	                    filename: obj[3], file_mimetype: obj[4], file_size: obj[5], 
+	                    current_version: obj[6], created_by: obj[7], 
+	                    version_comment: obj[8] });
+	            }, function() { 
+	                triggerEvent("SubSelected", result);
+	            });
 	        });
 	        getVersions();
             var menu = gridVersionsInfoSplit.contextmenu = new ContextMenu();
-            var current = new MenuItem("Current"/*i18n*/,
+            var current = new MenuItem(_("Current"),
                 function() { triggerEvent('OX_InfoStore_Version_Current'); });
             current.setIcon("img/menu/infostorecurrentversion.gif",
                             "img/menu/infostorecurrentversion_d.gif");
             menu.addItem(current);
-            var del = new MenuItem("Delete"/*i18n*/,
+            var del = new MenuItem(_("Delete"),
                 function() { triggerEvent('OX_InfoStore_Version_Delete'); });
             del.setIcon("img/menu/delete.gif", "img/menu/delete_d.gif");
             menu.addItem(del);
@@ -679,14 +713,14 @@ function loadDetailDocumentVersions(arg, cb_functionDetail) {
 }
 
 function getVersions(cb_functionVersion) {
-    versionsStorage = new Storage(0, []);
     function cb_versions(arg) {
+        versionsStorage = new Storage(0, []);
         versionsStorage.append(arg.data);
         versionsStorage.timestamp = arg.timestamp;
         nCurrentDetailItemTimestamp = versionsStorage.timestamp;
         gridVersionsInfoSplit.enable(versionsStorage);
-        bDetailVersionLoaded = true; 
-        if(cb_functionVersion) cb_functionVersion();
+        bDetailVersionLoaded = true;
+        if (cb_functionVersion) cb_functionVersion();
     }
     if (gridVersionsInfoSplit) {
         doAjaxFetchAllVersions(cb_versions);
@@ -699,7 +733,7 @@ function doAjaxFetchAllVersions(callback) {
     var sColumns = aCoumnsToFetch.join(",");
     var oObjectIdObj = oLastSelectedInfoObject[0];
     var sAjaxRequest = AjaxRoot + "/infostore?action=versions&id=" + oObjectIdObj.id + "&columns="+sColumns+"&session=" + session;
-    new JSON().get(sAjaxRequest, null,callback);
+    new JSONX().get(sAjaxRequest, null,callback);
 }
 
 function refreshDetailVersions(ids) {
@@ -721,11 +755,11 @@ function refreshDetailVersions(ids) {
                 var stopId = sDOMID;
                 var arr = new Array();
                 arr[0] = sValue;
-                function fnSetUserColumn(arg) {                   
+                function fnSetUserColumn(arg) {
                     if (document.getElementById(stopId)) {
                         if ($(stopId).firstChild)
                             removeChildNodes($(stopId));
-                        $(stopId).appendChild(document.createTextNode(arg[newValue].display_name || ""))
+                        $(stopId).appendChild(document.createTextNode(arg[newValue].display_name || ""));
                     }
                 }
                 sValue = internalCache.getUsers(arr,fnSetUserColumn);
@@ -761,7 +795,7 @@ function refreshDetailVersions(ids) {
                         $(sDOMID).appendChild(newnode("br"));
                     }                   
                 } else {
-                    $(sDOMID).appendChild(document.createTextNode(sValue));             
+                    $(sDOMID).appendChild(document.createTextNode(sValue));
                 }
             }
         }
@@ -770,11 +804,13 @@ function refreshDetailVersions(ids) {
 
 function deleteDetailVersion() {
     function cbyes() {
-        var oObjectIdObj = oLastSelectedInfoObject[0];  
+        var oObjectIdObj = oLastSelectedInfoObject[0];
         var aVersions = gridVersionsInfoSplit.getSelectedIDs();
         var nTimeStamp = versionsStorage.timestamp;
-        
-        function cb_detach_version(arg) { getVersions(); }
+        function cb_detach_version(arg) { 
+            //getVersions();
+            cb_infostore_selection_changed(true, false);
+        }
         doAjaxDetachVersion(oObjectIdObj,aVersions,nTimeStamp,cb_detach_version);
     }
     newConfirm(_("Delete Version"),_('Are you sure you want to delete the selected version?'),AlertPopup.YESNO,null,null,cbyes);
@@ -801,15 +837,14 @@ function setCurrentVersion() {
 }
 
 function doAjaxRequestUpdateItem(oId,newInfoItem,nTimeStamp,callback) {
-    var nId = parseInt(oId.id);
-    var sAjaxRequest = AjaxRoot + "/infostore?action=update&id="+nId+"&timestamp="+nTimeStamp+"&session=" + session;
-    new JSON().put(sAjaxRequest, newInfoItem, null,callback);      
+    var sAjaxRequest = AjaxRoot + "/infostore?action=update&id="+oId.id+"&timestamp="+nTimeStamp+"&session=" + session;
+    new JSONX().put(sAjaxRequest, newInfoItem, null,callback);      
 }
 
 function doAjaxDetachVersion(oObjectIdObj,aVersions,nTimeStamp,callback) {
     var sAjaxRequest = AjaxRoot + "/infostore?action=detach&id=" + oObjectIdObj.id +"&session=" + session + 
                                     "&folder=" +oObjectIdObj.folder + "&timestamp=" + nTimeStamp;
-    new JSON().put(sAjaxRequest, aVersions,null,callback);
+    new JSONX().put(sAjaxRequest, aVersions,null,callback);
 }
 
 fileloaded();
\ No newline at end of file
