@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
@@ -45,7 +45,7 @@
  */
 function LiveGrid(columns, selection, module) {
 	this.disablehover=false;
-	this.emptylivegridtext="This folder is empty";/*i18n*/
+	this.emptylivegridtext = _("This folder is empty");
 
 	/**
 	 * @private
@@ -171,11 +171,16 @@ function LiveGrid(columns, selection, module) {
 	 */
 	this.click_cb = function(e) { Self.click(e); };
 	
-	this.language_cb = function(e) { Self.scroll(true); }
+	this.language_cb = function(e) { Self.scroll(true); };
 	/**
 	 * @private
 	 */
-	this.dblclick_cb = function(e) { Self.dblclick(e); };
+	this.dblclick_cb = function (e) {
+	    // not top element?
+        if (e.target !== Self.parent) {
+            Self.dblclick(e);
+        }
+	};
 	
 	/**
 	 * @private
@@ -210,9 +215,9 @@ function LiveGrid(columns, selection, module) {
 	/**
 	 * @private
 	 */
-	this.selected_cb = function(count) {
+	this.selected_cb = function(count, e) {
 		Self.updateStyles();
-		Self.events.trigger("Selected", count);
+		Self.events.trigger("Selected", count, e);
 	};
 	
 	/**
@@ -229,6 +234,9 @@ function LiveGrid(columns, selection, module) {
 	 * </dl>
 	 */
 	this.events = new Events();
+	
+	// update width (hack for portal refactoring; live grids grow endlessly)
+	this.autoWidth = true;
 }
 
 function getRowIndex(e) {
@@ -333,13 +341,12 @@ LiveGrid.prototype = {
 			} else
 				innerCell = outerCell = this.headers[i] = this.outer_headers[i] =
 					newnode("th", this.columns[i].style, {className: headerClassName});
-			if (this.columns[i].i18n) {
-				var node = new I18nNode(function() {
-                    return pgettext(this.context, this.text);
-                });
-				node.text = this.columns[i].text;
-                node.context = this.columns[i].i18n;
-                if (node.context === true) node.context = ""; 
+			if (this.columns[i].text instanceof I18nString) {
+                innerCell.appendChild(addTranslated(this.columns[i].text));
+            } else if (this.columns[i].i18n) {
+			    var ctx = this.columns[i].i18n;
+                if (ctx === true) ctx = "";
+				var node = new I18nNode(pgettext(ctx, this.columns[i].text));
 				node.parent = innerCell;
 				node.update = function() {
 					this.parent.title = this.node.data = this.callback();
@@ -376,6 +383,7 @@ LiveGrid.prototype = {
 	 * The parent node should have an explicit size and "overflow: auto".
 	 */
 	getTable: function(parent) {
+	    parent.onselectstart = function() { return false; };
 		this.rows = {};
 		var last = this.columns.length - 1;
 		this.parent = parent;
@@ -406,9 +414,10 @@ LiveGrid.prototype = {
 	 * @param {Object} hover A DOM node which serves as a hover. It should be
 	 * attached directly to the body and have the CSS style
 	 * "position: absolute".
-	 * @param {Function} callback A callback function which is called when
-	 * the hover is shown. As its only parameter, it receives the ID of
-	 * the entry over which the mouse is hovering.
+     * @param {Function} callback A callback function which is called when
+     * the hover is shown. As parameters, it receives the ID of
+     * the entry over which the mouse is hovering and whether the hover was
+     * triggered manually.
 	 * @type {Object}
 	 * @return A new Hover object. The enable and disable methods of the hover
 	 * object will be called automatically by the LiveGrid.
@@ -422,10 +431,10 @@ LiveGrid.prototype = {
             Self.hoverSizeNode = node;
             return Hover.prototype.setSize.call(this, node);
         }
-		this.hover.onShow = function(node) {
+		this.hover.onShow = function(node, manual) {
 			var i = node.oxRowIndex;
 			if (i !== undefined)
-				callback(Self.storage.ids[i]);
+				callback(Self.storage.ids[i], manual);
 			else
 				return false;
 		}
@@ -473,7 +482,7 @@ LiveGrid.prototype = {
 				var td = doc.createElement("td");
 				trs[n].appendChild(td);
 				var col = Self.columns[i];
-				col.set(td, col.index ? obj[col.index] : obj);
+				col.set(td, col.index ? obj[col.index] : obj, obj);
 			}
 		}
 		function final_() {
@@ -507,7 +516,7 @@ LiveGrid.prototype = {
             LiveGrid.setSortClass(this.outer_headers[index], false);
         }
         var index = this.ids[id];
-        if (index || index === 0) {
+        if ((index || index === 0) && this.arrows[index] !== undefined) {
     		this.arrows[index].src = 
     			order == "asc" ? getFullImgSrc("img/arrows/sort_up.gif") :
     			order == "desc" ? getFullImgSrc("img/arrows/sort_down.gif") :
@@ -537,22 +546,25 @@ LiveGrid.prototype = {
 	 * the selection. If the entire selection was deleted, the first unselected
 	 * item at or after the focus is selected.
 	 */
-	deleteIDs: function(ids) {
-		var sids = {};
-		for (var i = 0; i < ids.length; i++)
-			sids[this.storage.serialize(ids[i])] = true;
-		while (this.storage.getSID(this.focus) in sids) this.focus++;
-		var newID = this.storage.ids[this.focus];
-		this.storage.removeIDs(ids);
-		this.selection.deselectSIDs(sids);
-		this.focus = newID ? this.storage.getIndex(newID) : 0;
-		if (!this.selection.count)
-			this.selection.click(this.focus);
+	deleteIDs: function (ids) {
+	    if (this.storage) {
+    		var sids = {};
+    		for (var i = 0; i < ids.length; i++)
+    			sids[this.storage.serialize(ids[i])] = true;
+    		while (this.storage.getSID(this.focus) in sids) this.focus++;
+    		var newID = this.storage.ids[this.focus];
+    		this.storage.removeIDs(ids);
+    		this.selection.deselectSIDs(sids);
+    		this.focus = newID ? this.storage.getIndex(newID) : 0;
+    		if (!this.selection.count)
+    			this.selection.click(this.focus);
+	    }
 	},
 	
 	updateSelected: function(callback) {
-		if (this.storage)
+		if (this.storage) {
 			this.storage.localUpdate(this.selection.getSelected(), callback);
+		}
 	},
 
 	/**
@@ -572,7 +584,8 @@ LiveGrid.prototype = {
 			addDOMEvent(this.parent, "keypress", this.keypress_cb);
 			addDOMEvent(this.parent, "mousedown", this.mousedown_cb);
 			addDOMEvent(this.parent, "click", this.click_cb);
-			addDOMEvent(this.parent, "dblclick", this.dblclick_cb);
+			// bind double click via jQuery (due to bug #14560)
+            jQuery(this.parent).bind("dblclick", this.dblclick_cb);
 			addDOMEvent(this.parent, "focus", this.focus_cb);
 			addDOMEvent(this.parent, "blur", this.blur_cb);
             if (this.contextmenu)
@@ -625,7 +638,7 @@ LiveGrid.prototype = {
 		removeDOMEvent(this.parent, "keypress", this.keypress_cb);
 		removeDOMEvent(this.parent, "mousedown", this.mousedown_cb);
 		removeDOMEvent(this.parent, "click", this.click_cb);
-		removeDOMEvent(this.parent, "dblclick", this.dblclick_cb);
+		jQuery(this.parent).unbind("dblclick", this.dblclick_cb);
 		removeDOMEvent(this.parent, "focus", this.focus_cb);
 		removeDOMEvent(this.parent, "blur", this.blur_cb);
         if (this.contextmenu)
@@ -732,8 +745,12 @@ LiveGrid.prototype = {
 		var hDivStyle = this.heightDiv.style;
 		if (newHeight != hDivStyle.height) hDivStyle.height = newHeight;
 		var Self = this;
-		if (this.heightDiv.offsetWidth != this.parent.clientWidth)
-			hDivStyle.width = Self.parent.clientWidth + "px";
+		// update width?
+		if (this.autoWidth) {
+		    if (this.heightDiv.offsetWidth != this.parent.clientWidth) {
+		        hDivStyle.width = Self.parent.clientWidth + "px";
+		    }
+		}
 		var scrolltop = this.parent.scrollTop;
 		var from2 = Math.max(0, Math.floor(                           scrolltop  / this.rowHeight / this.granularity) * this.granularity - this.preview);
 		var to2 = Math.min(len, Math.ceil((this.parent.clientHeight + scrolltop) / this.rowHeight / this.granularity) * this.granularity + this.preview);
@@ -768,7 +785,7 @@ LiveGrid.prototype = {
                 var cellrow = Self.rows[n].cells;
 				for (var i in cellrow) {
 					var col = Self.columns[i];
-					col.set(cellrow[i], col.index ? obj[col.index] : obj);
+					col.set(cellrow[i], col.index ? obj[col.index] : obj, obj);
 				}
 			}, function() { Self.iterateRequest = null; }, 20);
 		}
@@ -822,8 +839,9 @@ LiveGrid.prototype = {
 			break;
 		case 40: // arrow down
 			if (this.focus < this.rowCount - 1) this.focus++;
-			if (!(Mac ? e.metaKey : e.ctrlKey))
+			if (!(Mac ? e.metaKey : e.ctrlKey)) {
 				this.selection.click(this.focus, e);
+			}
 			this.showFocus();
 			break;
 		case 33: // page up
@@ -1023,7 +1041,7 @@ LiveGrid.localSort = function(id, order) {
 
 function LiveGrid2(columns, selection, module) {
     this.disablehover=false;
-    this.emptylivegridtext="This folder is empty";/*i18n*/
+    this.emptylivegridtext = _("This folder is empty");
 
     /**
      * @private
@@ -1044,7 +1062,7 @@ function LiveGrid2(columns, selection, module) {
      * @private
      */
     this.module = module;
-
+    this.dndModule = module;
     /**
      * Index of the anchor row.
      * The anchor is used for multiple-selects with the Shift key.
@@ -1077,6 +1095,8 @@ function LiveGrid2(columns, selection, module) {
         if (!this.sort_id && columns[i].sortable) this.sort_id = columns[i].sort;
 
     this.lineHeight = 1.6;
+    this.rowHeight = 0;
+    this.rowMargin = 0;
     
     /**
      * @private
@@ -1152,7 +1172,9 @@ function LiveGrid2(columns, selection, module) {
     /**
      * @private
      */
-    this.dblclick_cb = function(e) { Self.dblclick(e); };
+    this.dblclick_cb = function (e) {
+    	Self.dblclick(e);
+    };
     
     /**
      * @private
@@ -1188,9 +1210,9 @@ function LiveGrid2(columns, selection, module) {
     /**
      * @private
      */
-    this.selected_cb = function(count) {
+    this.selected_cb = function(count,e ) {
     	Self.updateStyles();
-        Self.events.trigger("Selected", count);
+        Self.events.trigger("Selected", count, e);
     };
     
     /**
@@ -1325,12 +1347,12 @@ LiveGrid2.prototype = {
             } else
                 innerCell = outerCell = this.headers[i] = this.outer_headers[i] =
                     newnode("th", this.columns[i].style, {className: headerClassName});
-            if (this.columns[i].i18n) {
-                var node = new I18nNode(function() {
-                    return pgettext(this.context, this.text); });
-                node.text = this.columns[i].text;
-                node.context = this.columns[i].i18n;
-                if (node.context === true) node.context = "";
+            if (this.columns[i].text instanceof I18nString) {
+                innerCell.appendChild(addTranslated(this.columns[i].text));
+            } else if (this.columns[i].i18n) {
+                var ctx = this.columns[i].i18n;
+                if (ctx === true) ctx = ""; 
+                var node = new I18nNode(pgettext(ctx, this.columns[i].text));
                 node.parent = innerCell;
                 node.update = function() {
                     this.parent.title = this.node.data = this.callback();
@@ -1367,6 +1389,7 @@ LiveGrid2.prototype = {
      * The parent node should have an explicit size and "overflow: auto".
      */
     getTable: function(parent) {
+        parent.onselectstart = function() { return false; };
         this.rows = {};
         var last = this.columns.length - 1;
         this.parent = parent;
@@ -1398,8 +1421,9 @@ LiveGrid2.prototype = {
      * attached directly to the body and have the CSS style
      * "position: absolute".
      * @param {Function} callback A callback function which is called when
-     * the hover is shown. As its only parameter, it receives the ID of
-     * the entry over which the mouse is hovering.
+     * the hover is shown. As parameters, it receives the ID of
+     * the entry over which the mouse is hovering and whether the hover was
+     * triggered manually.
      * @type {Object}
      * @return A new Hover object. The enable and disable methods of the hover
      * object will be called automatically by the LiveGrid2.
@@ -1413,10 +1437,10 @@ LiveGrid2.prototype = {
             Self.hoverSizeNode = node;
             return Hover.prototype.setSize.call(this, node);
         }
-        this.hover.onShow = function(node) {
+        this.hover.onShow = function(node, manual) {
             var i = node.oxRowIndex;
             if (i !== undefined)
-                callback(Self.collection.objects[i]);
+                callback(Self.collection.objects[i], manual);
             else
                 return false;
         }
@@ -1464,7 +1488,7 @@ LiveGrid2.prototype = {
                 var td = doc.createElement("td");
                 trs[n].appendChild(td);
                 var col = Self.columns[i];
-                col.set(td, col.index ? obj[col.index] : obj);
+                col.set(td, col.index ? obj[col.index] : obj, obj);
             }
         }
         function final_() {
@@ -1494,9 +1518,9 @@ LiveGrid2.prototype = {
                         tr.appendChild(td);
 					    var col = Self.columns[i2];
                         if(col.name.length==1) {
-						  col.set(td,  obj[col.name[0]]);	
+						  col.set(td, obj[col.name[0]], obj);
 						} else {
-					      col.set(td,  obj);
+					      col.set(td, obj, obj);
 						}
   				    }
 				    trs.push(tr); 
@@ -1614,7 +1638,8 @@ LiveGrid2.prototype = {
             OXCache.unregister(this.listRequest.uniqueName);
             delete this.listRequest;
         }   
-        if(!this.collection) {
+        if(!this.collection && this.collection !== false) {
+            this.collection = false;
 			for (var i in Self.arrows) {
                 addDOMEvent(Self.outer_headers[i], "click", Self.arrow_events[i]);
 			}
@@ -1623,7 +1648,8 @@ LiveGrid2.prototype = {
             addDOMEvent(Self.parent, "keypress", Self.keypress_cb);
             addDOMEvent(Self.parent, "mousedown", Self.mousedown_cb);
             addDOMEvent(Self.parent, "click", Self.click_cb);
-            addDOMEvent(Self.parent, "dblclick", Self.dblclick_cb);
+            // bind double click via jQuery (due to bug #14560)
+            jQuery(this.parent).bind("dblclick", this.dblclick_cb);
             addDOMEvent(Self.parent, "focus", Self.focus_cb);
             addDOMEvent(Self.parent, "blur", Self.blur_cb);
             if (this.contextmenu)
@@ -1631,20 +1657,20 @@ LiveGrid2.prototype = {
             if (Self.hover && !Self.disablehover) Self.hover.enable();
             resizeEvents.register("Resized", Self.scroll_cb);
             register("LanguageChanged",Self.language_cb);
-            if (Self.module && (Self.module != "links")) {
+            if (Self.dndModule && (Self.dndModule != "links")) {
                 var disabled;
                 var validfield;
-                switch(Self.module) {
+                switch(Self.dndModule) {
                     case "calendar": disabled=calendardefaultdisabled;  validfield="title"; break;
                     case "tasks":   disabled=taskdefaultdisabled; validfield="title"; break;
                     case "contacts": disabled=contactdefaultdisabled; validfield="display_name"; break;
                     case "infostore": disabled=infostoredefaultdisabled; validfield="title"; break;
                     case "mail": disabled=maildefaultdisabled; validfield="subject"; break;
                 }
-                Self.dragEvent = registerSource(Self.heightDiv, Self.module, function() 
+                Self.dragEvent = registerSource(Self.heightDiv, Self.dndModule, function() 
                 {
                     var myelements=clone(Self.selection.getSelected());
-                    objMoveCopy.begin(Self.module,myelements);
+                    objMoveCopy.begin(Self.dndModule,myelements);
                     return objMoveCopy;
                 },null,null,disabled,defaultdisabledremove);
             }
@@ -1668,7 +1694,9 @@ LiveGrid2.prototype = {
                     if (isNaN(index)) {
                         index = Math.min(oldFocus, Self.rowCount - 1);
                     }
-                    if (Self.selection.setCollection(Self.collection, index)) {
+                    if (Self.selection.setCollection(Self.collection,
+                            Self.selection.count ? index : undefined))
+                    {
                         Self.focus = index;
                     }
                     Self.change_cb(0,data.objects.length); 
@@ -1705,7 +1733,7 @@ LiveGrid2.prototype = {
         removeDOMEvent(this.parent, "keypress", this.keypress_cb);
         removeDOMEvent(this.parent, "mousedown", this.mousedown_cb);
         removeDOMEvent(this.parent, "click", this.click_cb);
-        removeDOMEvent(this.parent, "dblclick", this.dblclick_cb);
+        jQuery(this.parent).unbind("dblclick", this.dblclick_cb);
         removeDOMEvent(this.parent, "focus", this.focus_cb);
         removeDOMEvent(this.parent, "blur", this.blur_cb);
         if (this.contextmenu)
@@ -1713,7 +1741,7 @@ LiveGrid2.prototype = {
         unregister("LanguageChanged",this.language_cb);
         if (this.hover) this.hover.disable();
         resizeEvents.unregister("Resized", this.scroll_cb);
-        if (this.module) {
+        if (this.dndModule) {
             unregisterSource(this.parent, this.dragEvent);
         }
     },
@@ -1732,7 +1760,7 @@ LiveGrid2.prototype = {
             this.columns[i].clear(cell);
         }
         this.heightDiv.appendChild(row.tr);
-        if (!this.rowHeight) this.rowHeight = row.tr.offsetHeight;
+        if (!this.rowHeight) this.rowHeight = row.tr.offsetHeight + this.rowMargin;
         return row;
     },
 
@@ -1858,9 +1886,11 @@ LiveGrid2.prototype = {
                     for (var i2 in cellrow) {
                         var col = Self.columns[i2];
                         if(col.name.length==1 && col.name[0].indexOf("/") < 0) {
-                          col.set(cellrow[i2], data.objects[i][col.name[0]]);   
+                            col.set(cellrow[i2], data.objects[i][col.name[0]],
+                                data.objects, Self);
                         } else {
-                          col.set(cellrow[i2], data.objects[i]);
+                            col.set(cellrow[i2], data.objects[i], data.objects,
+                                Self);
                         }
                     }
                 }
@@ -1878,9 +1908,12 @@ LiveGrid2.prototype = {
                     for (var i2 in cellrow) {
                         var col = Self.columns[i2];
                         if(col.name.length==1 && col.name[0].indexOf("/") < 0) {
-                          col.set(cellrow[i2], this.listRequest.set[i][col.name[0]]);   
+                            col.set(cellrow[i2],
+                                this.listRequest.set[i][col.name[0]], null,
+                                Self);
                         } else {
-                          col.set(cellrow[i2], this.listRequest.set[i]);
+                            col.set(cellrow[i2], this.listRequest.set[i], null,
+                                  Self);
                         }
                     }
                 }
@@ -1936,8 +1969,9 @@ LiveGrid2.prototype = {
             break;
         case 40: // arrow down
             if (this.focus < this.rowCount - 1) this.focus++;
-            if (!(Mac ? e.metaKey : e.ctrlKey))
+            if (!(Mac ? e.metaKey : e.ctrlKey)) {
                 this.selection.click(this.focus, e);
+            }
             this.showFocus();
             break;
         case 33: // page up
@@ -1985,15 +2019,20 @@ LiveGrid2.prototype = {
     mousedown: function(e) {
         this.clickprocessed = false;
         var focus = getRowIndex(e);
-        if (this.collection.objects.length < this.height) {
-            if (focus === undefined) focus = -1; else this.focus = focus;
-            if(!this.selection.get(focus)) {
+        // might be undefined (timing issue): this.collection.objects - so check that
+        if (this.collection.objects && this.collection.objects.length < this.height) {
+            if (focus === undefined) {
+                focus = -1;
+            } else {
+                this.focus = focus;
+            }
+            if (!this.selection.get(focus)) {
                 this.clickprocessed=true;
                 this.selection.click(focus, e);
             }
         } else if (focus !== undefined) {
             this.focus = focus;
-            if(!this.selection.get(focus)) {
+            if (!this.selection.get(focus)) {
                 this.clickprocessed=true;
                 this.selection.click(focus, e);
             }
@@ -2013,9 +2052,12 @@ LiveGrid2.prototype = {
      * @private
      */
     click: function(e) {
-        if (this.clickprocessed) return;
+        if (this.clickprocessed) {
+            return;
+        }
         var focus = getRowIndex(e);
-        if (this.collection.objects.length < this.height) {
+        // might be undefined (timing issue): this.collection.objects - so check that
+        if (this.collection.objects && this.collection.objects.length < this.height) {
             if (focus === undefined) focus = -1; else this.focus = focus;
             this.selection.click(focus, e);
         } else if (focus !== undefined) {
