@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Stefan Preuss <stefan.preuss@open-xchange.com>
@@ -17,8 +17,6 @@
 var refToMain = ox.api.window.core;
 var session = refToMain.session;
 var config = refToMain.config;
-var getPermAsString = refToMain.getPermAsString;
-var oMainFolderTree = refToMain.oMainFolderTree;
 var isPrintableView = refToMain.isPrintableView;
 var registerPrintView = refToMain.registerPrintView;
 var OXMailMapping = refToMain.OXMailMapping, OXCache = refToMain.OXCache;
@@ -45,6 +43,7 @@ for (var i in smilies) regexps.push(i.replace(/([$^\\.*+?()[\]{}|])/, "\\$1"));
 var regexpstr = "(^| |\\n|<br>)(" + regexps.join("|") + ")";
 var regexp = new RegExp(regexpstr, "g");
 var sortVsplitHeader;
+var triggerReady = jQuery.noop;
 
 function replaceSmilies(text) {
 	return text.replace(regexp, function(_, space, match) {
@@ -52,38 +51,25 @@ function replaceSmilies(text) {
 	});
 }
 
-function replaceLeadingSpaces(text) {
-	return text.replace(/(^|<br>)([ \t]+)|([ \t]{2,}|\t)/g,
-		function(_, prefix, m1, m2) {
-			var match = (m1 || m2).replace(/\t/g, "        "); // TODO: real tabs
-			var retval = new Array((match.length + 3) >> 1);
-			retval[0] = prefix || "";
-			var max = match.length >> 1;
-			for (var i = 1; i <= max; i++) retval[i] = "&nbsp; ";
-			if (match.length & 1) retval[retval.length - 1] = "&nbsp;";
-			return retval.join("");
-		});
-}
-
 function getMailDetailObject() {
-	var myarray=new Array();
-	var myobject=new Object();
-	myobject.id=url["id"];
-	myobject.folder_id=url["folder"] || url["folder_id"]; 
+	var myobject = {};
+	myobject.id = url["id"];
+	myobject.folder_id = url["folder"] || url["folder_id"]; 
 	return myobject;
 }
 
 var menucheckRight=function(right) {
 	return refToMain.menuhasRight([getMailDetailObject()],right);	
-}
+};
 
-registerPrintView("mail_detail");
+registerPrintView("mail_detail/detail");
 
 //var oNestedMessage = null;
 function loadDetailMail() {	
 	activemodule="mail_detail";
 	initContents("mail_detail");
 	mail_message = getMailDetailObject();
+	ox.UIController.presetModule("mail_detail");
 	initAll();
 }
 
@@ -95,8 +81,8 @@ function triggerEventInOpener(eventToTrigger) {
 	refToMain.triggerEvent(eventToTrigger);
 }
 
-function isStdFolder(folder) {
-    return (url["folder"] == corewindow.configGetKey("mail.folder." + folder));
+function isStdFolder(type) {
+    return url.folder ? refToMain.isStdFolder(type, url.folder) : false;
 }
 
 register("Loaded", initMailDetail);
@@ -105,8 +91,8 @@ register("OX_Attachment_Open_Nested", function(){ openNestedMessage() });
 register("OX_Attachment_Save", function() { openAttachment("SAVE"); });
 register("OX_Attachment_SaveInfoStore", mail_saveAttachmentInDocStore);
 register("OX_Add_Flag", setFlagInMailView);
-register("OX_Mail_Close", function() { corewindow.ox.api.window.close(url.guid); });
-register("OX_Cancel_Object", function() { corewindow.ox.api.window.close(url.guid); });
+register("OX_Mail_Close", function() { ctrl.close(true); });
+register("OX_Cancel_Object", function() { ctrl.close(true); });
 register("OX_Mail_Delete", 
 		function() {
 			deleteMails(url["folder"], 
@@ -119,11 +105,11 @@ register("OX_Mail_Delete",
 	);
 register("OX_Mail_SaveMail", 
 		function() {
-			var tF = parent.frames["mail.detail.pop.attachment.save"];	
+			var tF = $("mail.detail.pop.attachment.save");
 			var n_url = AjaxRoot + '/mail?action=get'
 				+ '&session=' + session + '&folder=' + encodeURIComponent(url["folder"])
 				+ '&id=' + encodeURIComponent(url["id"]);
-			tF.location.href=n_url+"&src=1&save=1";
+			tF.src=n_url+"&src=1&save=1";
 		}
 	);	
 register("OX_NEW_MAIL", function(){ newMail(""); });
@@ -134,7 +120,9 @@ register("OX_Mail_Edit_Draft", function(){ newMail("draft"); });
 register("OX_Mail_Mark", mail_mark);
 register("OX_Mail_Flag", markAsMail);
 register("OX_Mail_Spam", markAsSpam);
-registerView("mail_detail",
+register("OX_Mail_Ham", markAsHam);
+
+registerView("mail_detail/detail",
 	null,
 	function() { 
 		register("OX_Print", mail_printDetailMail);
@@ -147,7 +135,7 @@ registerView("mail_detail",
         triggerEvent("OX_Selected_Draft", false);
 	},
 	function () {
-		menuclearSearchMail();
+	    triggerEvent('OX_Delete_Search');
         triggerEvent("OX_Selected_Draft", false);
 	},
 	null
@@ -169,20 +157,12 @@ function mail_saveAttachmentInDocStore() {
 	        corewindow.propertiesPopUp = win;
 	    }
 	});
-//	propertiesPopUp = corewindow.newWindow("newInfoItemMain.html#attachmail=" + selAttachment.id + "&edit_id=" + -1
-//			+ "&filename=" + encodeURIComponent(selAttachment.filename)
-//			+ "&mailid=" + encodeURIComponent(url["id"])
-//			+ "&mailfolder=" + encodeURIComponent(url["folder"])
-//			, getWindowOptions(), 
-//			{ "folder": encodeURIComponent(message.folder_id), "id": encodeURIComponent(message.id), "attach_id": encodeURIComponent(selAttachment.id) });	
-//	if (propertiesPopUp) propertiesPopUp.focus();
-//	corewindow.propertiesPopUp = propertiesPopUp;
 }
 	
 /**
  * Delete messages
  */ 
-function deleteMails(folder, ids) {         
+function deleteMails(folder, ids) {
     // return if ids is empty or a delete is still in progress
     if (!ids || ids.length == 0) return;
     function cb() {
@@ -193,14 +173,14 @@ function deleteMails(folder, ids) {
                 corewindow.grid.selection.click(obj ? focusPos : 0);  
             }            
         }
-        setTimeout(function() { 
-        	corewindow.ox.api.window.close(url.guid);
+        setTimeout(function() {
+            ctrl.close(true);
         }, 0);
     }
     if (configGetKey("mail.deletemail") || configGetKey("mail.folder.trash") == url["folder"]) {
         newConfirm(_("Delete E-Mails"),_('Are you sure you want to delete the selected E-Mails?'),AlertPopup.YESNO,null,null,
         function () {
-            corewindow.OXMailMapping.deleteObjects(ids,true,cb)
+            corewindow.OXMailMapping.deleteObjects(ids,true,cb);
         }, null);
     } else {
         corewindow.OXMailMapping.deleteObjects(ids,false,cb);
@@ -258,6 +238,15 @@ function markAsSpam() {
     triggerEvent("OX_Mail_Close");
 }
 
+/**
+ * Marks message as Hpam 
+ */
+function markAsHam() {
+    corewindow.oMailFunctions.markAsHam(
+        { module: "mail", folder_id: url["folder"], id: url["id"] });
+    triggerEvent("OX_Mail_Close");
+}
+
 /**
  * Marks message as 'Answered, Read, Deleted, ...' 
  * @param - mailFlag
@@ -286,63 +275,59 @@ function setFlagInMailView(tag){
  * Open a new message window
  */
 function newMail(action) {
+    var params = { folder: url.folder, id: url.id, action: action };
+    // set account id if available
+    if (detailmessage && detailmessage["whole_message"] && detailmessage["whole_message"]["account_id"]) {
+        // is an existing account?
+        if (ox.api.cache.account.get(detailmessage["whole_message"]["account_id"]) !== undefined) {
+            params.account = detailmessage["whole_message"]["account_id"];
+        }
+    }
     // use api
-    ox.api.mail.open({ params: {
-        folder: url.folder, id: url.id, action: action
-    }});
-//	var newMail = corewindow.newWindow("newMail.html#folder=" 
-//		+ encodeURIComponent(url["folder"])
-//		+ "&id=" + encodeURIComponent(url["id"])
-//        + "&noimg=" + !corewindow.loadblockedimages
-//		+ "&action=" + action, getWindowOptions());
-//	newMail.focus;
+    ox.api.mail.open({ params: params });
 }
 	
 function initMailDetail() {
 	session = refToMain.session;
 	
 	var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
+	ox.gui.themePath = getFullImgSrc("");
     removeCSSFilesForNewWindow(themeStyle.path);
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
 	
-	var detailedMail = new Object();
+	var detailedMail = {};
 	detailedMail.id = url["id"];
 	detailedMail.folder_id = url["folder"];
 	detailedMail.type = url["type"];
 	var aObjectMail = new Array(detailedMail);
 	
-	 setTimeout(function() { 
-        triggerEvent("OX_Switch_View","mail_detail");
+    // adding new menu 
+    ox.gui.initToolBarNewWindowMailDetail();
+    
+    triggerReady = function (object) {
+        
+        // disable loading screen
+        $("loading_data_bg").style.display = "none";
+        
+        var metaData = {
+            module: "mail",
+            activemodule: activemodule,
+            handle: url.guid,
+            id: url.id ? url.id : null,
+            folder_id: url.folder ? url.folder : null,
+            title: object ? object.subject || "" : ""
+        };
+        
+        // trigger default selection
+        ox.ToolBarController.processSelection("default", true, aObjectMail, true);
+        ox.api.window.core.triggerEvent("OX_Window_Ready", metaData, window);
+        object = metaData = null;
+    };
+    
+    setTimeout(function () { 
+        triggerEvent("OX_Switch_View","mail_detail/detail");
         initMessageContent(corewindow.loadblockedimages);
         triggerEvent("Selected", aObjectMail); 
     }, 0);
-    
-    var menu = new PulldownMenu($("menu_mail_mark"));
-    var entries = { seen: "Read", /*i18n*/ unseen: "Unread", /*i18n*/
-        answer: "Answered", /*i18n*/ answered: "Unanswered", /*i18n*/
-        "delete": "Deleted", /*i18n*/ undelete: "Undeleted" }; /*i18n*/
-    function fillItems(menu) {
-        var items = {};
-        for (var i in entries) {
-            var item = items[i] = new MenuItem(entries[i], (function(flag) {
-                return function() { triggerEvent("OX_Mail_Flag", flag); };
-            })(i));
-            menu.addItem(item);
-        }
-        menu.onShow = function() {
-            var r = menucheckRight("READ");
-            items.seen.setVisible(r);
-            items.unseen.setVisible(r);
-            var d = menucheckRight("DELETE");
-            items["delete"].setVisible(d);
-            items.undelete.setVisible(d);
-            var w = menucheckRight("WRITE");
-            items.answer.setVisible(w);
-            items.answered.setVisible(w);
-        };
-    }
-    $("menu_mail_mark").oxSubmenu = fillItems;
-    fillItems(menu);
 }
 
 var loadBlockedImages = function() {
@@ -352,16 +337,29 @@ var loadBlockedImages = function() {
     if (corewindow.mail_lastSelectedId.id == message.id) {
         setTimeout(corewindow.loadBlockedImages,0);
     }
-}
+};
 
-function initMessageContent(loadblockedimages) {	
-	if ("oNestedMessage" in window && oNestedMessage && oNestedMessage.length) {
+var toggleImipTab = function(button, what) {
+    jQuery("td", $("mail.detail.imip.toolbar"))
+        .removeClass("oxTabCurrent")
+        .filter("." + what)
+        .addClass("oxTabCurrent");
+    if (what === "inv") {
+        jQuery($('mail.detail.content')).hide();
+    } else {
+        jQuery($('mail.detail.content')).show();
+    }
+};
+
+function initMessageContent(loadblockedimages) {
+	var oNestedMessage = ox.api.window.getData(url.guid).oNestedMessage;
+	if (oNestedMessage && oNestedMessage.length) {
 		message.id = oNestedMessage[0].id;
 		message.folder_id = message.folder_id || url["folder"];
 		oNestedMessage[0].folder_id = message.folder_id;
-		fillContentsFromJson(oNestedMessage[0], message.folder_id);
+		drawMessage(oNestedMessage[0], message.folder_id);
 	} else {
-		message.id = url["id"]
+		message.id = url["id"];
 		message.folder_id = url["folder"];
 				
 		var collection={};
@@ -381,23 +379,51 @@ function initMessageContent(loadblockedimages) {
         }
 		
 		if (detailrequest) { OXCache.unregister(detailrequest.uniqueName); }
-		detailrequest = OXCache.newRequest(null,"mail",collection,
-		    function(daten) {
-                if(daten.objects[0]) {
-                    mailFetchTimestamp = daten.timestamp;
-                    fillContentsFromJson(daten.objects[0], message.folder_id);
-                }           
-            },			
-	        function(daten) {
-	            if(daten.objects[0]) {
-	                mailFetchTimestamp = daten.timestamp;
-	                fillContentsFromJson(daten.objects[0], message.folder_id);
-	            }           
-	        });
+		
+		// get mail
+		var cont = function (daten) {
+            if (daten.objects[0]) {
+                mailFetchTimestamp = daten.timestamp;
+                showMessage(daten.objects[0], message.folder_id);
+            }
+        };
+
+        jQuery(".mail_content_view").css({ visibility: "hidden" });
+        jQuery($("mail.detail.content")).show();
+        
+		detailrequest = OXCache.newRequest(null, "mail", collection, cont, cont, false, triggerReady);
 	}
 }
 
-function fillContentsFromJson(message, folder) {
+function showMessage(message, folder) {
+    function _cb(itipObject) {
+        if (itipObject === undefined) {
+            jQuery("#mail\\.detail\\.imip\\.toolbar").hide();
+            resizeSplit("mail.detail.imip.toolbar", 0);
+        } else {
+            // select first tab
+            jQuery("td", $("mail.detail.imip.toolbar")).removeClass("oxTabCurrent").first().addClass("oxTabCurrent");
+            // show toolbar and resize to correct height
+            jQuery("#mail\\.detail\\.imip\\.toolbar").show();
+            resizeSplit("mail.detail.imip.toolbar", "26px");
+            
+            itipObject.node = jQuery("#mail\\.detail\\.imip");
+            itipObject.success = function() {
+                jQuery($("mail.detail.content")).hide();
+                jQuery(".mail_content_view").css({ visibility: "visible" });
+            };
+            ox.mail.itip.paint(itipObject);
+        }
+        drawMessage(message, folder);
+    }
+    
+    ox.mail.itip.parseMessage({
+        callback: _cb,
+        message: message
+    });
+}
+
+function drawMessage(message, folder) {
 	nested_msgs = "";
 	if(message["nested_msgs"] && message["nested_msgs"].length) {
 		nested_msgs = message["nested_msgs"];
@@ -405,8 +431,12 @@ function fillContentsFromJson(message, folder) {
 	}
 	detailmessage=new Object();
 	detailmessage["whole_message"]=message;
-	if(message["from"])
-		detailmessage["from"]=refToMain.getAdressString(message["from"], false);
+	if(message["from"]) {
+		detailmessage["from"] = refToMain.getAdressString(message["from"], false);
+		if (configGetKey("ui.mail.showContactImage.value") === true && message.from.length) {
+		    ox.mail.drawContactImage(message.from[0][1]);
+		}
+	}
 	if(message["to"])  
 		detailmessage["to"]=refToMain.getAdressString(message["to"], false);
 	if(message["cc"])  
@@ -418,6 +448,10 @@ function fillContentsFromJson(message, folder) {
 	detailmessage["priority"]=message["priority"];
 	detailmessage["color-label"]=message["color_label"];
 	
+	// set document title as well
+	var title = message["subject"] || "";
+	document.title = _("E-Mail") + (title ? ": " : "") + title;
+	
 	$("mail.detail.pop.detail.row.organization").style.display="none";
 	if (message["headers"] && message["headers"]["Organization"]) {
 		$("mail.detail.pop.detail.header.organization").firstChild.data=message["headers"]["Organization"];
@@ -437,26 +471,27 @@ function fillContentsFromJson(message, folder) {
 	setColor_label(message["color_label"]);
 	setSubject(message["subject"]);
 	setPriority(message["priority"]);
-	setDate(message["received_date"] || message["sent_date"]);
+	var dateToShow = message["received_date"];
+    if (isStdFolder("sent") || isStdFolder("drafts")) {
+        dateToShow = message["sent_date"];
+    }
+	setDate(dateToShow);
+	// change header description if the folder is sent or draft
+    jQuery(".received").text(isStdFolder("sent") ||  isStdFolder("drafts") ? 
+            _("Sent").toString() : _("Received").toString());
 	setMessageText(message);
 	msgref = message["msgref"];
 	setFlagImage(message["flags"]);
 	
-	// disable loading screen
-    $("loading_data_bg").style.display="none";
+	jQuery(".mail_content_view").css({ visibility: "visible" });
+	
+    triggerReady(message);
 }
 
 function setColor_label(colorlabel) {
     $("mail.detail.pop.detail.flag").src = getFullImgSrc("img/menu/tag_"+(colorlabel||0)+".gif");
 }
 
-function setHeightOfEmailDiv(oDiv){
-    oDiv.style.height = 1.6 + "em"; 
-    if (oDiv.scrollHeight > 22) {
-        oDiv.style.height = oDiv.clientHeight *2 + "px";
-    }
-}
-
 function setAdressHeader(fType, address) {
     var oDivEmails = $("mail.detail.pop.detail.header." + fType);
     var rDivEmails = $("mail.detail.pop.detail.row." + fType);
@@ -466,11 +501,8 @@ function setAdressHeader(fType, address) {
     } else if (oDivEmails && address && address != "") {
         removeChildNodes(oDivEmails);
         if (rDivEmails != undefined) rDivEmails.style.display="";
-        getAdressStringLinked(oDivEmails, address, false);
-    }
-    setTimeout(function() { 
-        setHeightOfEmailDiv(oDivEmails); 
-	}, 0);   
+        getAdressStringLinked(oDivEmails, address, configGetKey("gui.mail.showname"));
+    } 
     
     return oDivEmails;
 }
@@ -491,14 +523,16 @@ function setPriority(priority) {
 
 function setSubject(subject) {
     if (subject)
-        $("mail.detail.pop.detail.header.subject").firstChild.nodeValue = subject;  
+        $("mail.detail.pop.detail.header.subject").firstChild.nodeValue = subject.replace(/(.{1,20})/g, "$1\u200B");
 }
 
 function setDate(date) {
     if (date) {
         date = refToMain.formatDate(date, "datetime");
-        $("mail.detail.pop.detail.header.received_date").firstChild.nodeValue = date;   
+    } else {
+        date = "";
     }
+    $("mail.detail.pop.detail.header.received_date").firstChild.nodeValue = date;
 }
 
 var detailNestedMessage = null;
@@ -531,7 +565,7 @@ function setMessageText(message) {
 		if (ct.search(/text\//) != -1 && con != null) {
 			if (ct.search(/text\/plain/) != -1) {
 				var tmpcnn=(configGetKey("mail.emoticons") ? replaceSmilies(con) : con);
-				tmpcnn=replaceLeadingSpaces(tmpcnn);
+				tmpcnn=replaceSpaces(tmpcnn);
 				cnn += "<div class=\"plainTextContent\">" + tmpcnn + "</div>";
 			} else { 
 				cnn += "<div>" + con + "</div>";
@@ -543,14 +577,19 @@ function setMessageText(message) {
 				var aimg = getMimeImage(ct).match(/empty.png/g) ? getFullImgSrc("img/mail/attachment.gif") : getMimeImage(ct.toLowerCase());
                 attachExists = true;
                 
+                var filename = String(conArr.filename),
+                    filenameAbbr = filename.length >= 30 ? filename.substr(0, 27) + "..." : filename;
+                    
                 var oDOMDiv = newnode("div", { MozUserSelect: "none" }, { className: "mailDetailAttachmentsCont" },[
-				  newnode("img", { verticalAlign: "middle" }, { src: aimg, padding: "3px" }),
+				  newnode("img", { }, { src: aimg, padding: "3px" }),
 				  //#. Displayed label for attachments
 				  //#. %1$s is the file name.
 				  //#. %2$s is the file size.
 				  //#, c-format
-                  newnode("span",0,{ className: "nothing" }, [ document.createTextNode(format(_(" %1$s (%2$s); "), 
-                		  conArr["filename"], bytesToString(conArr["size"]))) ])
+                  newnode("span", { }, { title: filename, className: "nothing" },
+                      [ document.createTextNode(format(_(" %1$s (%2$s) "), 
+                          filenameAbbr, bytesToString(conArr.size, 0)))
+                      ])
                 ]); 
                 // prevent text selection on dbl click
                 oDOMDiv.onselectstart = function() { return false; };
@@ -570,7 +609,7 @@ function setMessageText(message) {
                     });                            
                     if (menucountsubselected == 0) {
                     	selectAttachment(selAttach, false, false);
-                    	menucountsubselected=1;
+                    	menucountsubselected = 1;
                     }
                 })({ node: oDOMDiv, data: conArr}); 
                 mda.appendChild(oDOMDiv);
@@ -586,7 +625,7 @@ function setMessageText(message) {
 			(function(o) {
 				var oNestedMessage = new Array(nested_msgs[o]);
 				attachments.push({ filename: nested_msgs[o].filename || nested_msgs[o].subject, content_type: "message/rfc822", size: nested_msgs[o].size });
-				var textAttachment = addTranslated(nested_msgs[o].filename || nested_msgs[o].subject || "message/rfc822 Part" );
+				var textAttachment = newtext(nested_msgs[o].filename || nested_msgs[o].subject || "message/rfc822 Part" );
 				var blank = document.createTextNode(" ");
 				var oDOMDiv = newnode("div", { MozUserSelect: "none" }, { className: "mailDetailAttachmentsCont" },
 					[ newnode("img",0,{ src: getFullImgSrc("img/mail/unread.gif"), align: "top", title: textAttachment.data, padding: "3px"}),
@@ -633,7 +672,7 @@ function setMessageText(message) {
                     }
 				})(oDOMDiv, oNestedMessage);
 				mda.appendChild(oDOMDiv);
-			})(nMessage)
+			})(nMessage);
 		}
 	}
 	
@@ -658,27 +697,95 @@ function setMessageText(message) {
     } else {
         $("mail.detail.pop.header.image_protection").style.display="none";
     }  	
-		
+    
 	var ih = getFrameElement("mail.detail.pop.detail.content");
     if (ih && ih.document) {
         ih = ih.document;
         ih.open();
         ih.writeln(cnn);
         ih.close();
-        setTimeout(function(){                                      
+        setTimeout(function() {
             var head = ih.getElementsByTagName("head");
+            var body = ih.getElementsByTagName("body");
+            var colorQuoted = configGetKey("mail.colorquoted") === true;
             if (head && head.length) {
+                // adjust base path
                 head[0].appendChild(
-                   newnode("link",null,{type : "text/css",  rel:"stylesheet", href : "themes/"+configGetKey("gui.theme").path+"/css/iframe.css" },null,ih));
+                    newnode("base", null, { href:  "[protocol]://[hostname][path]newInfoItemHidden.html".format() }, null, ih));
+                // would not work for safari without explicit head tag
+                head[0].appendChild(
+                   newnode("link", null,{ type: "text/css", rel: "stylesheet", href: ox.gui.themePath + "css/iframe.css" }, null, ih));
             }
             try {
-				ih.getElementsByTagName("body")[0].style.margin=".5em";
-			} catch (e) { }
+                if (body && body.length) {
+                    // set margin
+                    body[0].style.margin = ".5em";
+                    // colored quotes?
+                    if (colorQuoted) {
+                        body[0].className = "colored-quotes";
+                    }
+                }
+            } catch (e) {
+                console.log("wat: ", e);
+            }
+            
+            if (message.headers && message.headers["X-OX-Reminder"]) {
+                var object = message.headers["X-OX-Reminder"].split(",");
+                if (object.length === 3 && object[1] !== 0) {
+                    var node = jQuery(".calendar-buttons", body);
+                    if (node.is("div")) {
+                        var actions = { 3: _("Tentative"), 2: _("Decline"), 1: _("Accept") };
+                        jQuery.each(actions, function(idx, action) {
+                            node.append(
+                                jQuery("<a>")
+                                .attr({ href: "#" })
+                                .addClass("action link")
+                                .text(action.toString())
+                                .click(function(e) {
+                                    corewindow.acceptdeny_updateConfirm([{
+                                        objectid: object[0],
+                                        folder_id: object[1],
+                                        module: "calendar"
+                                    }], 
+                                    idx,
+                                    "",
+                                    function() {
+                                        //deleteMails(message.folder_id, [ message ]);
+                                        ox.UINotifier.ok(_("Confirmation status has been saved."));
+                                    });
+                                    return false;
+                                })
+                            );
+                        });
+                        node.show();
+                    }
+                    delete(node);
+                }
+                delete(objects);
+            }
+            
             parseDirectLinksInMails(ih);
         }, 0);
     }
-    setTimeout(function () { 
-    	resizeSplit(mda.id, attachExists ? "3.19em" : "0em"); 
+    setTimeout(function () {
+        // one line
+        var should = "2.25em";
+        // reset height to get the real scrollheight
+        jQuery($(mda.id)).css({ height: should });
+        // measure scroll height
+        var scrollHeight = jQuery($(mda.id)).prop("scrollHeight");
+        // if scroll height >= 2 lines we resize the attachment div
+        if (isNaN(scrollHeight) === false) {
+            var height = Math.round(scrollHeight/pxPerEm);
+            if (height >= 8)  {
+                // 3 rows max
+                should = "6.2em";
+            } else if (height >= 4) {
+                // 2 rows
+                should = "4.20em";
+            }
+        }
+        resizeSplit(mda.id, attachExists ? should : "0em");
     }, 0);
 }
 
@@ -709,7 +816,21 @@ function selectAttachment(selAttach, multi, context) {
 }
 
 function openNestedMessage() {
-
+	// view mail
+	var detailMail = ox.api.mail.view({
+        params: {
+            id: url.id,
+            folder: url.folder,
+            sid: detailNestedMessage.sid,
+            type: "isNestedMessage"
+        },
+		data: {
+            oNestedMessage: detailNestedMessage
+        }
+    });
+	
+	
+	/*
 	var detailMail=corewindow.newWindow("detailMail.html#type=isNestedMessage&id="
 		+ encodeURIComponent(url["id"])
 		+ "&folder="+ encodeURIComponent(url["folder"])
@@ -719,12 +840,19 @@ function openNestedMessage() {
 	detailMail.oNestedMessage = detailNestedMessage;
 	if (detailMail) {
 		detailMail.focus();
-	}
+	}*/
 }
 
 function openAttachment(action) {	
 	var selAttach = selectedAttachments[0].data;
     if (action != "SAVE" && (isVcard(selAttach.content_type) || isIcal(selAttach.content_type))) {
+        if (isIcal(selAttach.content_type) && ox.api.config.get("modules.calendar.module", false) === false) {
+            triggerEvent("Feature_Not_Available", "modules/mail/open-ical", window);
+            return;
+        } else if (isVcard(selAttach.content_type) && ox.api.config.get("modules.contacts.module", false) === false) {
+            triggerEvent("Feature_Not_Available", "modules/mail/open-vcard", window);
+            return;
+        }
         showIcalVcard(selAttach);
         return;
     }
@@ -734,7 +862,7 @@ function openAttachment(action) {
 				 selectedAttachments.length > 1 ? "zip_attachments" : "attachment")
 		 + '&session=' + session 
 		 + '&folder=' + encodeURIComponent(url["folder"])
-		 + '&id=' + encodeURIComponent(url["id"])			 
+		 + '&id=' + encodeURIComponent(url["id"]);
 	if (action == "OPEN") {
 		var attachWin = corewindow.newWindow(
 			n_url + "&attachment=" + selAttach.id + "&save=0&filter=1",
@@ -774,12 +902,16 @@ function callback_error(arg) {
 	newServerError(arg);
 }
 
-/**
- * unregister from object cache before the window closes
- */
-window.onbeforeunload = function() {
-	if (detailrequest) { 
-		OXCache.unregister(detailrequest.uniqueName);
-		detailrequest=null; 
-	}
-};
+// init window controller
+
+var ctrl = windowController = new WindowController();
+
+ctrl.set("unload", function () {
+    if (detailrequest) { 
+        OXCache.unregister(detailrequest.uniqueName);
+        detailrequest = null;
+    }
+});
+
+//alloc memory (for leak test; 250 MB)
+//window.leak = new Array( 250 * 0xCCCC ).join( 0xFFFFFFFF );
