@@ -6,41 +6,112 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
  */
+var OX_UI_Visible = true;
 
-function centerPopupWindow(popupwindow) {
-    var windowheight=$("body").offsetHeight;
-    var windowwidth=$("body").offsetWidth;
-    var tmpnode=popupwindow.cloneNode(true);
-    tmpnode.style.display="block";
-    tmpnode.style.zIndex=-1;
-    body.appendChild(tmpnode);
-    var popupwindowheight=tmpnode.offsetHeight;
-    var popupwindowwidth=tmpnode.offsetWidth;
-    body.removeChild(tmpnode);
-    popupwindow.style.left =((windowwidth/2) -(popupwindowwidth/2)) +"px";
-    popupwindow.style.top =((windowheight/2) -(popupwindowheight/2)) +"px";
+function centerPopupWindow(popupwindow, width, height) {
+
+    var $ = jQuery,
+        display,
+        content,
+        // copy dimensions
+        w = width,
+        h = height;
+    
+    // maybe hidden?
+    if (OX_UI_Visible === false) {
+        
+        var fn = function () {
+            unregister("OX_Visible", fn);
+            OX_UI_Visible = true;
+            setTimeout(function () {
+                centerPopupWindow(popupwindow, width, height);
+            }, 0);
+        };
+        
+        register("OX_Visible", fn);
+        
+    } else {
+        
+        function center() {
+            // get available width & height
+            var availWidth = jQuery(window).width();
+            var availHeight = jQuery(window).height();
+            // center
+            $(popupwindow).css({
+                left: Math.floor((availWidth - w) / 2) + "px",
+                top: Math.floor((availHeight - h) / 2) + "px"
+            });
+        };
+        
+        // show
+        display = $(popupwindow).css("display");
+        $(popupwindow).css({
+            visibility: "hidden",
+            display: "block" // use hard show
+        });
+        
+        // get width & height
+        content = $(".popup_center_area", popupwindow);
+        
+        // get width
+        if (w === undefined) {
+            w = content.children().width();
+        }
+        
+        // get height
+        if (h === undefined) {
+            // getting the height of all elements for the final maximum height
+            h = 0;
+            content.children().each(function(index) {
+                h = h + $(this).height();
+            });
+        }
+        
+        // adjust outer element
+        if (w > 0 && (h + 0) > 0) {
+            $(popupwindow).css({ width: w + "px", height: h + 0 + "px" });
+        }
+        
+        // center outer element
+        center();
+        
+        // hide?
+        if (display === "none") {
+            $(popupwindow).hide();
+        } else {
+            $(popupwindow).css("display", "block");
+        }
+        
+        $(popupwindow).css("visibility", "visible");
+    }
 }
 
 register("Loaded", function() {
-    addDOMEvent($("body"), "contextmenu", function(e) {
-        switch ((e.target || e.srcElement).nodeName.toLowerCase()) {
+    jQuery("#body").bind("contextmenu", function(e) {
+        var elem = e.target || e.srcElement;
+        switch (elem.nodeName.toLowerCase()) {
             case "textarea":
+            case "input":
             case "a":
                 break;
             default:
-                stopEvent(e);
-                return false;
+                // handle special className to allow context menu
+                if (!elem.className || elem.className.match(/enablectxmenu/g) === null) {
+                    e.stopPropagation();
+                    return false;
+                }
         }
+        return true;
     });
     for (var i in init.movable) {
         var node = $(init.movable[i]);
 		var parent = $(node.id.substring(0, node.id.length-2));
-        (function(node, parent) {
+		(function(node, parent) {
             addDOMEvent(node, "mousedown", function(e) {
                 if (e.button != LeftButton) return;
                 moving = parent;
@@ -62,8 +133,10 @@ register("Loaded", function() {
                     else if(leftposition+parent.offsetWidth > $("body").offsetWidth) {
                         leftposition=$("body").offsetWidth-parent.offsetWidth;
                     }
-                    moving.style.left = leftposition + "px";
-                    moving.style.top = topposition + "px";
+                    if (moving) {
+                        moving.style.left = leftposition + "px";
+                        moving.style.top = topposition + "px";
+                    }
                     stopEvent(e);
                 }
                 function upHandler(e) {
@@ -81,9 +154,11 @@ register("Loaded", function() {
                 //addDOMEvent(body, "mouseout", upHandler);
                 cancelDefault(e);
             });
+            
             addDOMEvent(node.firstChild, "click", function() {
-                parent.style.display = "none";
-            });
+            	parent.style.display = "none";
+	        });
+
         })(node, parent);
     }
 });
@@ -117,7 +192,8 @@ function removeOnClose(popupwindow, onclose) {
  */
 function Popup(node) {
     this.node = node;
-    body.appendChild(this.node);
+    this.zIndex = 1;
+    document.body.appendChild(this.node);
 }
 
 /** @private */
@@ -140,7 +216,8 @@ Popup.prototype = {
                     Popup.stopAnimation = null;
                 });
         }
-        style.display = "";
+        style.zIndex = this.zIndex || 1;
+        style.display = "block";
         hideIFrames();
     },
     
@@ -176,13 +253,25 @@ Popup.prototype = {
      * A positive value will keep a rectangle at y to y + h always covered,
      * a negative value will keep a rectangle at y + h to y always cleared.
      */
-    position: function(x, y, w, h) {
-        if (x + this.node.offsetWidth > body.offsetWidth)
-            x = x + (w || 0) - this.node.offsetWidth;
-        if (y + this.node.offsetHeight > body.offsetHeight)
-            y = y + (h || 0) - this.node.offsetHeight;
-        this.node.style.left = x + "px";
-        this.node.style.top = y + "px";
+    position: function (x, y, w, h) {
+        // prepare
+        var $ = jQuery, node = $(this.node);
+        var width = node.outerWidth(), height = node.outerHeight();
+        // x
+        if (x + width > $(document.body).width()) {
+            x = x + (w || 0) - width;
+        }
+        if (x < 0) x = 0;
+        // y
+        if (y + height > $(document.body).height()) {
+            y = y + (h || 0) - height;
+        }
+        if (y < 0) y = 0;
+        // set new position
+        node.css({
+            left: x + "px",
+            top: y + "px"
+        });
     }
 };
 
@@ -272,17 +361,12 @@ MousePopup.prototype = extend(Popup, {
 
 if (document.addEventListener) {
     MousePopup.prototype.registerHide = function() {
-        body.parentNode.addEventListener("click", this.clickHandler, true);
-        body.parentNode.addEventListener("contextmenu", this.clickHandler,
-            true);
+        jQuery("html").bind("click", this.clickHandler); // allows external trigger
         body.parentNode.addEventListener("mousedown", this.clickHandler, true);
     };
     MousePopup.prototype.unregisterHide = function() {
-        body.parentNode.removeEventListener("click", this.clickHandler, true);
-        body.parentNode.removeEventListener("contextmenu", this.clickHandler,
-            true);
-        body.parentNode.removeEventListener("mousedown", this.clickHandler,
-            true);
+        jQuery("html").unbind("click", this.clickHandler);
+        body.parentNode.removeEventListener("mousedown", this.clickHandler, true);
     };
 } else {
     MousePopup.activePopups = {};
@@ -293,7 +377,8 @@ if (document.addEventListener) {
     };
     MousePopup.prototype.registerHide = function() {
         if (!MousePopup.active) {
-            addDOMEvent(body, "click", this.clickHandler);
+            jQuery("body").bind("click", this.clickHandler); // allows external trigger
+            // addDOMEvent(body, "click", this.clickHandler);
             addDOMEvent(body, "mousedown", this.clickHandler);
             addDOMEvent(body, "mouseover", this.mouseHandler);
             addDOMEvent(body, "mouseout", this.mouseHandler);
@@ -305,7 +390,7 @@ if (document.addEventListener) {
     };
     MousePopup.prototype.unregisterHide = function() {
         if (!MousePopup.active) {
-            removeDOMEvent(body, "click", this.clickHandler);
+            jQuery("body").unbind("click", this.clickHandler);
             removeDOMEvent(body, "mousedown", this.clickHandler);
             removeDOMEvent(body, "mouseover", this.mouseHandler);
             removeDOMEvent(body, "mouseout", this.mouseHandler);
@@ -325,7 +410,7 @@ function PopupMenu() {
         position: "absolute",
         display: "none"
     }, {
-        className: "PopupMenuDiv background-color-popup-menu border-color-popup-menu font-size-small",
+        className: "PopupMenuDiv font-size-small",
         oxPopupMenu: true
     }));
     this.items = [];
@@ -363,8 +448,10 @@ PopupMenu.prototype = extend(MousePopup, {
      * @protected
      */
     show: function() {
-        if (this.isVisible) return;
-        if (this.onShow) this.onShow();
+        if (this.isVisible) {
+            return;
+        }
+        if (this.onShow) this.onShow(this.getContext());
         MousePopup.prototype.show.call(this);
         for (var i in this.items) this.items[i].show();
         PopupMenu.last = this;
@@ -382,19 +469,24 @@ PopupMenu.prototype = extend(MousePopup, {
         this.hide();
         if (this.parent instanceof MenuItem) this.parent.close();
     },
-
+    
     addItem: function(item) {
         this.items.push(item);
         this.node.appendChild(item.node);
         item.parent = this;
         if (item.icon) this.iconAdded();
-        if (item.submenu) this.submenuAdded();
+        if (item.submenu) {
+            this.submenuAdded();
+            item.submenu.zIndex = this.zIndex + 1;
+        } else {
+            item.zIndex = this.zIndex + 1;
+        }
     },
     
     removeItem: function(item) {
         for (var i = 0; i < this.items.length; i++) {
             if (this.items[i] == item) {
-                this.items = this.items.splice(i, 1);
+                this.items.splice(i, 1);
                 this.node.removeChild(item.node);
                 break;
             }
@@ -414,7 +506,10 @@ PopupMenu.prototype = extend(MousePopup, {
     /**
      * Returns the context of the popup menu.
      */
-    getContext: function() { return this.parent.getContext(); },
+    getContext: function() {
+        var p = this.parent;
+        return p && p.getContext !== undefined ? p.getContext() : {};
+    },
     
     /**
      * @ignore
@@ -471,7 +566,7 @@ function MenuItem(text, action) {
         }
         function handleClick() {
             if (Self.enabled) {
-                if (Self.action && Self.action() !== false)
+                if (Self.action && Self.action(Self.getContext()) !== false)
                     Self.parent.close();
             } else {
                 if (Self.disabled_action && Self.disabled_action() !== false)
@@ -510,9 +605,12 @@ function MenuItem(text, action) {
     function deselect() { Self.node.className = "PopupEntryDiv"; }
     function open() {
         Self.submenu.show();
-        var pos = getAbsolutePosition(Self.node);
-        Self.submenu.position(pos.x + Self.node.offsetWidth, pos.y,
-                              -Self.node.offsetWidth, Self.node.offsetHeight);
+        var node = jQuery(Self.node);
+        var parent = jQuery(Self.parent.node);
+        var width = parent.outerWidth();
+        var o = node.offset(), op = parent.offset();
+        // set position of submenu
+        Self.submenu.position(op.left + width - 3, o.top - 5);
     }
     function close() { Self.submenu.hide(); }
 }
@@ -539,12 +637,15 @@ MenuItem.prototype = {
         this.disabled_icon = disabled_icon;
         if (icon) {
             if (this.img) {
+                // update image src
                 this.img.src = this.getIcon();
             } else {
                 this.img = newnode("img", {
                     position: "absolute", left: 0, top: 0, bottom: 0,
-                    margin: "auto"
-                }, { src: this.getIcon() });
+                    margin: "auto", width: "16px", height: "16px"
+                }, { alt: "", src: getFullImgSrc("img/dummy.gif") });
+                // we do not set the proper image source right now because
+                // too much images will be loaded and lots of them miss the cache
                 this.node.insertBefore(this.img, this.node.firstChild);
             }
             if (this.parent) this.parent.iconAdded();
@@ -562,10 +663,11 @@ MenuItem.prototype = {
     
     setChecked: function(checked) {
         if (this.checkbox) {
+            this.checkbox.defaultChecked = checked;
             this.checkbox.checked = checked;
         } else {
             this.checkbox = newnode("input", 0,
-                { type: "checkbox", className: "noborder", checked: checked });
+                { type: "checkbox", className: "noborder", defaultChecked: checked, checked: checked });
             this.node.insertBefore(this.checkbox, this.node.firstChild);
         }
         return this;
@@ -576,11 +678,15 @@ MenuItem.prototype = {
     },
     
     show: function() {
-        if (this.onShow) this.onShow();
+        if (this.onShow) this.onShow(this.getContext());
         this.fsm.reset();
+        this.node.zIndex = this.zIndex;
         this.node.className = this.enabled ? "PopupEntryDiv"
                                            : "PopupEntryDivDisabled font-color-disabled";
-        if (this.img) this.img.src = this.getIcon();
+        if (this.img) {
+            // update src - might trigger initial loading
+            this.img.src = this.getIcon();
+        }
     },
 
     hide: function() {
@@ -648,23 +754,51 @@ MenuItem.prototype = {
      * Automatically disables the menu item if its submenus do not have a single
      * enabled option.
      */
-    autoSetEnabled: function() { this.setEnabled(this.getAutoEnabled()); },
+    autoSetEnabled: function() {
+        this.getAutoEnabled(function (flag) {
+            this.setEnabled(flag);
+        });
+    },
     
-    getAutoEnabled: function() {
-        if (!this.submenu) return this.enabled && this.visible;
-        for (var i = 0; i < this.submenu.items.length; i++) {
-            var item = this.submenu.items[i];
-            if (item.getAutoEnabled && item.getAutoEnabled()) return true;
+    // use continuation since it might be async
+    getAutoEnabled: function (cont) {
+        // has no sub menu?
+        if (!this.submenu) {
+            cont(this.enabled && this.visible);
+        } else {
+            // flag
+            var found = false;
+            // join
+            var join = new Join(function () {
+                cont(found);
+            });
+            var lock = join.add();
+            // loop over items
+            var i = 0, items = this.submenu.items, $l = items.length, item, callback;
+            for (; i < $l; i++) {
+                // supports auto enabled?
+                if (items[i].getAutoEnabled) {
+                    // closure
+                    (function (item) {
+                        // call back
+                        item.getAutoEnabled(join.add(function (flag) {
+                            found = found || flag;
+                        }));
+                    }(items[i]));
+                }
+            }
+            lock();
         }
-        return false;
     },
     
     /**
      * Returns the context in which this item is used. Usually, this is
      * the current selection for which a context menu is displayed.
      */
-    getContext: function() { return this.parent.getContext(); }
-    
+    getContext: function() {
+        var p = this.parent;
+        return p && p.getContext !== undefined ? p.getContext() : {};
+    }
 };
 
 /**
@@ -767,7 +901,7 @@ Value.eval = function(f, callback) {
  */
 function MenuSeparator() {
     this.node = newnode("div",
-        { border: "1px inset gray", margin: "0.6em 0" });
+        { borderTop: "1px solid #ccc", margin: "0.6em 0" });
     var Self = this;
     addDOMEvent(this.node, "mouseover",
         function() { Self.parent.itemSelected(); });
@@ -796,14 +930,15 @@ ContextMenu.prototype = extend(PopupMenu, {
      * @param {Number} y The Y coordinate of the menu (usually Event.clientY).
      * @param context The context which is passed to all children of the menu.
      */
-    display: function(x, y, context) {
+    display: function (x, y, context) {
         this.context = context;
-        this.show();
         this.position(x, y);
+        this.show();
     },
-
-    getContext: function() { return this.context; }
-
+    
+    getContext: function () {
+        return this.context;
+    }
 });
 
 /**
@@ -844,3 +979,51 @@ PulldownMenu.prototype = extend(PopupMenu, {
     }
 
 });
+
+function PulldownPopup(trigger, node, manual) {
+    node.oxPopupMenu = true;
+    MousePopup.call(this, node);
+    this.trigger = trigger;
+    var Self = this;
+    if (!manual) {
+        addDOMEvent(trigger, "click", function(e) {
+            if (PopupMenu.last == Self) PopupMenu.last = null; else Self.show();
+            cancelBubbling(e);
+        });
+    }
+    trigger.oxPulldownTrigger = true;
+}
+
+PulldownPopup.prototype = extend(MousePopup, {
+
+    show: function() {
+        if (this.isVisible) {
+            return;
+        }
+        this.node.style.minWidth = this.trigger.offsetWidth + "px";
+        if (this.onShow) this.onShow();
+        MousePopup.prototype.show.call(this);
+        PopupMenu.last = this;
+        var ref = jQuery(this.trigger),
+            off = ref.offset();
+        this.position(
+            off.left,
+            off.top + ref.height(),
+            ref.width(),
+            -ref.height()
+        );
+    },
+    
+    hide: function() {
+        if (!this.isVisible) return;
+        MousePopup.prototype.hide.call(this);
+        if (this.onHide) this.onHide();
+    },
+    
+    captureEvents: PulldownMenu.prototype.captureEvents,
+    
+    manualShow: function() {
+        if (PopupMenu.last == this) PopupMenu.last = null; else this.show();
+    }
+    
+});
