@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Dirk Hartmann <dirk.hartmann@open-xchange.com>
@@ -14,7 +14,7 @@
  */
 
 var taskobject = new Object();
-var json = new JSON();
+var json = new JSONX();
 var activefolder;
 var taskDetailId = 0;
 var lastTimestamp = (corewindow.taskTimestamp > 0) ? corewindow.taskTimestamp : 1;
@@ -43,27 +43,60 @@ var tmp_attachment, tmp_participant, newTaskFolderTree;
 var miniRemindVisible = false, task_categories = "", allOk = 0;
 var checkTaskNumberFormat = 0, taskCloseBit = false, savePending = false;
 var globalseries, externalParticipants = null, externalCounter = 0;
+var triggerReady = jQuery.noop;
+var messageOnCancel = false;
+var messageCloseWindow = _("Do you really want to discard your changes and close the window?");
+
+// modal dialog
+function setModalBusy(state){
+    if (state == true){
+        ox.api.setModal(true);
+        jQuery("#modal-dialog-decorator").addClass("busy");
+    }else{
+        ox.api.setModal(false);
+        jQuery("#modal-dialog-decorator").removeClass("busy");
+    }
+}
 
 function initNewTaskLoaded() {
-	var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
-    removeCSSFilesForNewWindow(themeStyle.path);
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
 }
 
 function fn_changeTimstamp(newTStamp) {
 	lastTimestamp = newTStamp;
 }
 
-function setNumberOfAttNewTask(nCountParam) {
+function setNumberOfAttNewTask(nCountParam, silent) {
 	$("tasks_number_of_attachments").firstChild.data = nCountParam;
+	if (!silent) ce();
 }
 
 register("Loaded", function () {
+    
 	globalseries = new SeriesView();
 	globalseries.initView();
+	
 	addOnClose($('series_window'), function () { 
 		globalseries.hideView(); 
 	});
+	
+	triggerReady = function () {
+	    
+	    // init toolbar
+	    ox.gui.initToolBarNewWindowTask();
+	    
+	    triggerEvent("OX_menu_Change_Height", true);
+	    
+        var metaData = {
+            module: "tasks",
+            activemodule: activemodule,
+            handle: url.guid,
+            id: (url.id != undefined) ? url.id : null,
+            folder_id: url.folder,
+            title: url.module === "new" ? corewindow._("New Task") : $("title").value
+        };
+        ox.api.window.core.triggerEvent("OX_Window_Ready", metaData, window);
+    };
+    
 	newTaskOnload();
 });
 
@@ -71,7 +104,10 @@ register("OX_Timestamp_Changed_By_Attach", fn_changeTimstamp);
 registerView("task_new", null, null, null, null);
 
 registerView("task_new/task",
-	function() { 
+	function() {
+        if ((corewindow.ox.upsell.isVisible("infostore") && corewindow.ox.upsell.isVisible("tasks-attachments")) === false) {
+            $("panel4").style.display = "none";
+        }
 		$("tab1").style.display="block";
 		$("panel1").className="tabPanelFirstHi tabPanelHiColor background-color-content font-style-lable border-color-content-default";	
 	},
@@ -134,8 +170,8 @@ registerView("task_new/participant",
                 for (var i in parts) {
                     var found = new Array();
                     for (var j in extStorage.data.data) {
-                        if (extStorage.data.data[j][5] === parts[i].email) {
-                            found.push(parts[i].email);                          
+                        if (extStorage.data.data[j][5].toLowerCase() === parts[i].email.toLowerCase()) {
+                            found.push(parts[i].email);
                         }
                     }
                     if (found.length) {
@@ -149,6 +185,7 @@ registerView("task_new/participant",
                         );
                     }
                 }
+                ce();
             }
             externalParticipants = new ParticipantsExternal(null, on_ok);
         }
@@ -208,26 +245,22 @@ function initParticipantsGrid() {
 		tmp_participant = new Participants("participantsNewTask",
 							function(cb){
 								$("partCounterTasksNew").firstChild.data = 
-								tmp_participant.getParticipants().length;
+								    tmp_participant.getParticipants().length;
+								ce();
 							}, true, true, false, true, "Select Participants", /*i18n*/
 							false); /*i18n*/
 	} else {
 		tmp_participant = new Participants("participantsNewTask", function(cb){
 								$("partCounterTasksNew").firstChild.data = 
-								tmp_participant.getParticipants().length;
+								    tmp_participant.getParticipants().length;
+								ce();
 							}, true, true, false, true, "Select Participants", /*i18n*/
 							false); 
 	}
 }
 
-var messageCloseWindow = _("Do you really want to discard your changes and close the window?");
-
-function unloadMessage(){
-    return messageCloseWindow;
-}
-
-function setBeforeUnload(on){
-	window.onbeforeunload = (on) ? unloadMessage : null;
+function setBeforeUnload(on) {
+    messageOnCancel = on;
 }
 
 function newTaskOnload() {
@@ -249,7 +282,8 @@ function newTaskOnload() {
 	var btnClose = $("hider");
 	register("OX_SAVE_OBJECT", saveTask);
 	register("OX_Task_Add_Sequence", openSequenceWindow);
-	register("OX_Cancel_Object", canselProcessTaskWindow);
+	register("OX_Cancel_Object", cancelProcessTaskWindow);
+    register("OX_Object_Participant_Delete", ce);
 	register("doneModifyEvent", function(param) {
 		doneModifyDown(param);
 	});
@@ -288,13 +322,12 @@ function newTaskOnload() {
 		var changes=globalseries.sequenceStart.selectedTime-tmpstart.getTime();
 		tmpend.setTime(tmpend.getTime()+changes);
 		$("newtask_begins_date").value=formatDate(globalseries.getStartDate(),"date");
-		$("newtask_ends_date").value=formatDate(tmpend,"date");	
+		$("newtask_ends_date").value=formatDate(tmpend,"date");
+		ce();
 	});
 	
 	initTaskCategories();
-	initParticipantContent();
-	triggerEvent("OX_menu_Change_Height",true);
-	
+	initParticipantContent();	
 	initTaskTree();
 }
 
@@ -319,6 +352,7 @@ function initTaskCategories() {
 				ox.categories.ui.drawCategoriesList(
 						ox.categories.getByString(task_categories), 
 						$("newtask_categories_list"));
+				ce();
 			}
 		);		
 	});		
@@ -329,6 +363,7 @@ function openTaskCategoriesDialog() {
 		task_categories = str;
 		ox.categories.ui.drawCategoriesList(ox.categories.getByString(task_categories), 
 				$("newtask_categories_list"));
+		ce();
 	});
 }
 
@@ -345,48 +380,61 @@ function setModulPopup() {
 		fillTaskFields(url);
 		// disable loading screen
         $("loading_data_bg").style.display="none";
+        triggerReady();
 	}
 }
 
 function initNewTask() {
+    
+    // add default theme (should be in browser cache)
+    var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
+    ox.gui.themePath = getFullImgSrc("");
+    removeCSSFilesForNewWindow(themeStyle.path);
+    
 	activemodule = "task_new";
 	initContents(activemodule);
 	initAll();
+	
 	window.setTimeout(function() {
 		initNewTaskLoaded();
 	}, 0);
-	document.title = (url.module == "new") ? _("New Task") : _("Change Task");
 }
 
-function nt_ends_date_changed() {
+function nt_ends_date_changed(hideError) {
 	var value=$("newtask_ends_date").value;
 	if(value != "") {
 		var date=parseDateString(value,"date");
 		if(!date) {
-			triggerEvent("OX_New_Error",4,_("Illegal date in due date"));
+		    if (!hideError) {
+		        triggerEvent("OX_New_Error",4,_("Illegal date in due date"));
+		    }
 			return;
 		}
 		endCalendar.setSelectedByDate(date.getUTCFullYear(),date.getUTCMonth(),date.getUTCDate());
 	}
 	
 }
-function nt_begins_date_changed() {
+function nt_begins_date_changed(hideError) {
 	var value=$("newtask_begins_date").value;
 	if (value) {
 		var date=parseDateString(value,"date");
 		if(!date) {
-			triggerEvent("OX_New_Error",4,_("Illegal Date in start date"));
+		    if (!hideError) {
+		        triggerEvent("OX_New_Error",4,_("Illegal Date in start date"));
+		    }
 			return;
 		}
 		beginCalendar.setSelectedByDate(date.getUTCFullYear(),date.getUTCMonth(),date.getUTCDate());
 	}
 }
-function nt_remind_date_changed() {
+function nt_remind_date_changed(hideError) {
 	var value=$("newtask_reminder_date").value;
 	if (value) {
 		var date=parseDateString(value,"date");
 		if(!date) {
-			triggerEvent("OX_New_Error",4,_("Illegal Date in remind date"));
+		    if (!hideError) {
+		        triggerEvent("OX_New_Error",4,_("Illegal Date in remind date"));
+		    }
 			return;
 		}
 		remindCalendar.setSelectedByDate(date.getUTCFullYear(),date.getUTCMonth(),date.getUTCDate());
@@ -420,7 +468,7 @@ function fillTaskFieldsById(id) {
 					} else if (url.module == "duplicate") {
 						taskobject.number_of_attachments = 0;
 						taskobject.participants = [];
-					}
+					}					
 					fillTaskFields(taskobject);
 				}
 			} else {
@@ -428,14 +476,39 @@ function fillTaskFieldsById(id) {
 			}
 			// disable loading screen
             $("loading_data_bg").style.display="none";
+            // ready
+            triggerReady();
 		}
 	);
 }
 
+function setWindowTitle (title) {
+    title = title || $("title").value || "";
+    if (document) {
+    	document.title = (url.module === "new" ? _("New Task") : _("Edit Task") + ": " + title);
+    }
+}
+
 function fillTaskFields(taskobject) {
-	if (taskobject.title) $("title").value = taskobject.title;
+    
+    // set title
+    var title = taskobject.title || "";
+    $("title").value = title;
+    setWindowTitle(title);
+    
 	if (taskobject.color_label) $("color_label").value = taskobject.color_label;
-	if (taskobject.status) comboStatusTask.setKey(parseInt(taskobject.status) - 1);
+	
+	if (taskobject.status === null || isNaN(taskobject.status)) {
+        // set default status if it's not a number
+	    taskobject.status = 1;
+        // if percent complete greater then 0 its in progress
+        if ((taskobject.percent_completed || 0) > 0) {
+            taskobject.status = 2;
+        }
+    }
+	
+    comboStatusTask.setKey(parseInt(taskobject.status) - 1, true);
+    
 	if (taskobject.start_date) {
 		var mydatestart=new Date(taskobject.start_date);
 		$("newtask_begins_date").value=formatDate(taskobject.start_date,"date");
@@ -451,7 +524,7 @@ function fillTaskFields(taskobject) {
 		$("newtask_personal").checked = "checked";					
 	}
 	if (taskobject.participants && taskobject.participants.length) $("partCounterTasksNew").firstChild.data = taskobject.participants.length;
-	if (taskobject.priority) comboPriorityTask.setKey(parseInt(taskobject.priority) - 1);
+	if (taskobject.priority) comboPriorityTask.setKey(parseInt(taskobject.priority) - 1, true);
 	if (taskobject.percent_completed) $("percent_completed").value = taskobject.percent_completed;
 	if (taskobject.alarm) {
 		$("newtask_reminder_date").value = formatDate(new Date(taskobject.alarm),"date");
@@ -469,28 +542,29 @@ function fillTaskFields(taskobject) {
 	if (taskobject.actual_duration) $("actual_duration").value = taskobject.actual_duration;
 	if (taskobject.target_duration) $("target_duration").value = taskobject.target_duration;
 
-	if (taskobject.currency) comboCostsTask.setKey(taskobject.currency);					
+	if (taskobject.currency) comboCostsTask.setKey(taskobject.currency, true);					
 	if (taskobject.target_costs) $("target_costs").value = round(taskobject.target_costs);
 	if (taskobject.actual_costs) $("actual_costs").value = round(taskobject.actual_costs);
 	if (taskobject.billing_information) $("billing_information").value = taskobject.billing_information;
 	if (taskobject.companies) $("companies").value = taskobject.companies;
 	if (taskobject.number_of_attachments){
-		setNumberOfAttNewTask(taskobject.number_of_attachments);
+		setNumberOfAttNewTask(taskobject.number_of_attachments, true);
 	}								
 	globalseries.setParameters(taskobject);
 	$("taskSequence").value = globalseries.getSeriesString();
 	if (taskobject.trip_meter) $("trip_meter").value = taskobject.trip_meter;
 }
 
-function canselProcessTaskWindow() {
+function cancelProcessTaskWindow() {
 	function cbyes() {
-		window.onbeforeunload=null;
-		ox.api.window.close(url.guid);
+	    ctrl.close(true);
 	}
-	if(taskCloseBit)
-		newConfirm(_("Close Window"),_(messageCloseWindow),AlertPopup.YESNO,null,null,cbyes,null);		
-	else
+	if (taskCloseBit) {
+		newConfirm(_("Close Window"), messageCloseWindow, AlertPopup.YESNO,
+		    null, null, cbyes, null);		
+	} else {
 		cbyes();
+	}
 }
 
 function closeTaskWindow() {	
@@ -498,7 +572,7 @@ function closeTaskWindow() {
 	setBeforeUnload(taskCloseBit);
 	window.setTimeout(
 		function() {
-		    ox.api.window.close(url.guid);
+		    ctrl.close(true);
 		},50
 	);
 }
@@ -535,7 +609,7 @@ function readTaskFields() {
 		allOk = 2;
 	}
 	try {
-		if (($("newtask_ends_date").value != "" && $("newtask_begins_date").value != "") && (parseDateString($("newtask_ends_date").value,"date").getTime()
+		if (allOk == 0 && ($("newtask_ends_date").value != "" && $("newtask_begins_date").value != "") && (parseDateString($("newtask_ends_date").value,"date").getTime()
 				< parseDateString($("newtask_begins_date").value,"date").getTime())) {
 			allOk = 3;
 		}
@@ -561,15 +635,15 @@ function readTaskFields() {
 	}
         
     switch (allOk) {
-		case 1: error_msg = _("Mandatory Field(s) missing!");
-		case 2: error_msg = _("Incorrect input.");
-		case 3: error_msg = _("End date is before start date.");
-		case 4:  
-			setTimeout(function() { 
-				triggerEvent("OX_New_Error", 4, error_msg); 
-			}, 0);
-			break;
+		case 1: error_msg = _("Mandatory Field(s) missing!"); break;
+		case 2: error_msg = _("Incorrect input."); break;
+		case 3: error_msg = _("End date is before start date."); break;
     }  
+    if (allOk != 0 && error_msg) {
+        setTimeout(function() { 
+            triggerEvent("OX_New_Error", 4, error_msg); 
+        }, 0);
+    }
 	
 	if($("newtask_personal").checked && ($("newtask_personal_tr").style.visibility == "visible" || $("newtask_personal_tr").style.visibility == "")) {
 		ta_object.private_flag = true;
@@ -705,38 +779,67 @@ function updateTask() {
     }
 	
 	if (allOk == 0 && checkTaskNumberFormat == 0) {
+	    setModalBusy(true);
 		json.put(AjaxRoot + "/tasks?action=update&folder=" + activefolder + "&session=" +
 			session + "&id=" + taskDetailId + "&timestamp=" + lastTimestamp,
 			ta_object,
 			null,
+			// success handler
 			function(reply) {
-				function finalFunction()
-				{
+				function finalFunction () {
 					function fn_cb(){
-						if (!reply.error) {					
+						if (!reply.error) {
 							closeTaskWindow();
 						}
 					}
-					corewindow.OXTaskMapping.editObjects([oldObject],
-					    corewindow.clone(newObject));
+					// TODO: review bug fix 17278
+                    corewindow.OXCache.newRequest(null, "tasks", {
+                        columns: null,
+                        objects: [corewindow.OXTaskMapping.createKeyFromObject({
+                            module: "tasks", folder_id: activefolder, // ta_object does not contain folder_id
+                            id: taskDetailId
+                        })] }, null, emptyFunction, true);
+                    if (activefolder != ta_object.folder_id) {
+                        corewindow.OXTaskMapping.deleteObjectsInternal(
+                            [corewindow.OXTaskMapping.createKeyFromObject({
+                                module: "tasks", folder_id: activefolder,
+                                id: taskDetailId
+                            })]);
+                    }
 					if (tmp_attachmentDialog.attach_changed()) {
 						corewindow.triggerEvent("OX_Quota_Update");
 					}
+                    ox.api.window.core.triggerEvent("OX_NEW_TASK_SAVE_SUCCESS", 
+                    		{ data: { id: taskDetailId } }, url.guid);
+
                     fn_cb();
 				}
-				if (tmp_attachmentDialog.attach_changed()) 
-				{
+				if (tmp_attachmentDialog.attach_changed()) {
                     newObject.number_of_attachments = 
                         tmp_attachmentDialog.file_storage.ids.length;
 					var obj = new Object();
 					obj['attached'] = taskDetailId;
 					obj['module'] = 4; 				
 					obj['folder'] = activefolder;
-					tmp_attachmentDialog.do_post(obj,finalFunction);
+					// update attachments
+					tmp_attachmentDialog.do_post(
+					    // data
+					    obj,
+					    // success
+					    finalFunction, null, null, 
+					    // error
+					    function (response) {
+					        newServerError(response);
+					        setModalBusy(false);
+					    }
+					);
 				}
-				else
+				else {
 					finalFunction();
-			}
+				}
+			},
+			// error handler
+			setModalBusy
 		); 
 	} else {
 		savePending = false;
@@ -761,9 +864,11 @@ function writeNewTask() {
     }
 	
 	if (allOk == 0 && checkTaskNumberFormat == 0) {
+	    setModalBusy(true);
 		json.put(AjaxRoot + "/tasks?action=new&folder=" + activefolder + "&session=" + session,
 			ta_object,
 			null,
+			// success
 			function(reply) {
 				function finalFunction() {
 					function fn_cb(){
@@ -771,23 +876,26 @@ function writeNewTask() {
 							closeTaskWindow();
 						}
 					}
+                    ox.api.window.core.triggerEvent("OX_NEW_TASK_SAVE_SUCCESS", reply, url.guid);
 					corewindow.OXTaskMapping.createObject(newObject);
 					if (tmp_attachmentDialog.attach_changed()) {
 						corewindow.triggerEvent("OX_Quota_Update");
 					}
                     fn_cb();
 				}
-				if (tmp_attachmentDialog.attach_changed()) 
-				{
-					var obj = new Object();
+				if (tmp_attachmentDialog.attach_changed()) {
+                    var obj = new Object();
 					obj['attached'] = reply.data.id;
 					obj['module'] = 4; 				
 					obj['folder'] = activefolder;
 					tmp_attachmentDialog.do_post(obj,finalFunction);
 				}
-				else
-					finalFunction();						
-			}
+				else {
+					finalFunction();
+				}
+			},
+			// error
+			setModalBusy
 		);
 	} else {
 		checkTaskNumberFormat = 0;
@@ -836,7 +944,8 @@ function doneModifyDown(field) {
 		if (oldvalue != newvalue) $("percent_completed").value = newvalue;
 	} else if (oldvalue == 100) {
 		$("percent_completed").value = 75;
-	} 
+	}
+	ce();
 }
 
 function changeSequenceView(what) {
@@ -880,6 +989,7 @@ function fillSelectBoxes() {
 	comboPriorityTask.addElement(_("Normal"),"1");
 	comboPriorityTask.addElement(_("High"),"2");
 	comboPriorityTask.getDomNode();
+	comboPriorityTask.onChange = ce;
 
 /*	// The duration type box	
 	comboDurationTask=new ComboBox3(window,"durationSelectBox","7em",1,true,null,null);
@@ -922,31 +1032,35 @@ function fillSelectBoxes() {
 	var index=0;
 	for (var i in corewindow.currencies) {
 		var cur = corewindow.currencies[i];
-		comboCostsTask.addElement(cur.iso, cur.iso);
+		comboCostsTask.addElement(_(cur.iso), cur.iso);
 		if (currencyLanguageMatch(cur)) comboCostsTask.selected = index;
 		index++;	
 	}
 	comboCostsTask.getDomNode();
+	comboCostsTask.onChange = ce;
 }
 
 function changeRemindTimeFunction() {
 	$("newtask_reminder_hour").value = formatDate(comboRemindTask.getKey(), "time");
+	ce();
 }
 
 function showMiniStart(){
 	var tmp = $("mini_start");
 	$("mini_end").style.display = "none";
 	tmp.style.display = "block";
-	tmp.left = 0;
-	tmp.top = "1.6em";	
+	tmp.style.left = 210 + "px";
+	tmp.style.top = 120 + "px";
+	tmp.style.height = 210 + "px";
 }
 
 function showMiniEnd(){
 	var tmp = $("mini_end");
 	$("mini_start").style.display = "none";	
 	tmp.style.display = "block";
-	tmp.left = 0;
-	tmp.top = "1.6em";
+	tmp.style.left = 210 + "px";
+	tmp.style.top = 120 + "px";
+	tmp.style.height = 210 + "px";
 }
 
 function toggleMiniStart(){
@@ -954,8 +1068,9 @@ function toggleMiniStart(){
 	if(!miniStartVisible){
 		$("mini_end").style.display = "none";
 		tmp.style.display = "block";
-		tmp.left = 0;
-		tmp.top = "1.6em";
+		tmp.style.left = 210 + "px";
+		tmp.style.top = 120 + "px";
+		tmp.style.height = 210 + "px";
 		miniStartVisible = true;
 		miniEndVisible = false;
 	} else {
@@ -969,8 +1084,9 @@ function toggleMiniEnd(){
 	if(!miniEndVisible){
 		$("mini_start").style.display = "none";
 		tmp.style.display = "block";
-		tmp.left = 0;
-		tmp.top = "1.6em";
+		tmp.style.left = 210 + "px";
+		tmp.style.top = 120 + "px";
+		tmp.style.height = 210 + "px";
 		miniEndVisible = true;
 		miniStartVisible = false;
 	} else {
@@ -1038,6 +1154,7 @@ function setStartDate() {
 	var mydate=Date.UTC(beginCalendar.selectedYear,beginCalendar.selectedMonth,beginCalendar.selectedDate,0,0,0);
 	$("newtask_begins_date").value = formatDate(mydate,"date");
 	$("mini_start").style.display = "none";
+	ce();
 }
 
 function setEndDate(){
@@ -1045,6 +1162,7 @@ function setEndDate(){
 	var mydate=Date.UTC(endCalendar.selectedYear,endCalendar.selectedMonth,endCalendar.selectedDate,0,0,0);
 	$("newtask_ends_date").value = formatDate(mydate,"date");
 	$("mini_end").style.display = "none";
+    ce();
 }
 
 function setReminderDate(){
@@ -1053,6 +1171,7 @@ function setReminderDate(){
 	$("newtask_reminder_date").value = formatDate(mydate,"date");
 	$("newtask_reminder_hour").value = comboRemindTask.getValue();
 	$("mini_reminder").style.display = "none";
+    ce();
 }
 
 function setSequenceStartDate() {
@@ -1198,10 +1317,13 @@ function toggleTreeTasks(){
 	if(newTaskFolderTree == undefined)		
 		initTaskTree();
 	if(!treeVisible) {
+		centerPopupWindow($("TreeDialogTask"));
 		$("TreeDialogTask").style.display = "block";
+		$("TreeDialogTask").style.top = "120px";
+		$("TreeDialogTask").style.left = "170px";
 		treeVisible = true;
 		if(!taskTreeLoaded) {
-			newTaskFolderTree.load();
+//			newTaskFolderTree.load();
 			taskTreeLoaded = true;
 			}
 	}
@@ -1211,47 +1333,70 @@ function toggleTreeTasks(){
 	}
 }
 
+corewindow.register("OX_Configuration_Changed", function () {
+    if (ox && ox.api && url.folder) {
+        ox.api.folder.getPathString({
+            folder: url.folder,
+            cache: false,
+            success: cb_getpath
+        });
+    }
+});
+
+function cb_getpath(sPath) {
+    document.getElementsByName('newtask_folder')[0].value = sPath;
+}
+
 function initTaskTree() {		
-	corewindow.oMainFolderTree.get_folder_path(url.folder,
-				function (sPath) {document.getElementsByName('newtask_folder')[0].value = sPath;} );
+
+	ox.api.folder.getPathString({
+	    folder: url.folder,
+		success: cb_getpath
+	});
+		
 	var folderViewSettingsNewTask = new Object();
 	//Disable Email... 
 	folderViewSettingsNewTask["mail"] = 4;
 	folderViewSettingsNewTask["tasks"] = 8;
 	if(!treeLoaded){
-		newTaskFolderTree = new cFolderTree($('folder_tree_tasks'),
-										folderTasksAction,
-										false,
-										corewindow.oMainFolderTree.cache,
-										corewindow.optFolderState.getState('folder_tree_tasks'));
-		newTaskFolderTree.enabled_modules = {tasks:true};					
-
+		ox.api.ui.selectFolder({
+	    	type: "tasks",
+	    	id: "select-folder-popup-tasks",
+	    	callback: folderTasksAction,
+	    	node: $('folder_tree_info'),
+	    	minPerms: 2, // create objects
+	    	destroy: false
+	    });				
 		treeLoaded = true;
 	}							
-	newTaskFolderTree.setSaveConfiguration(corewindow.optFolderState);			
 }
 
-function folderTasksAction(ofolder) {
-	var OXFolder = ofolder.oxfolder;
+function folderTasksAction(data) {
 
-	//$("cancelNewTaskTreeButton").click();
 	toggleTree();
-	newFolderName = OXFolder.data.id;
+	newFolderName = data.id;
 
-	function cb_getpath(sPath) {
-		document.getElementsByName('newtask_folder')[0].value = sPath;
-		if(OXFolder.data.type != 1){
-			$("newtask_personal_tr").style.visibility = "hidden";
-		} else {
-			$("newtask_personal_tr").style.visibility = "visible";
-		}		
-	}	
-	newTaskFolderTree.get_folder_path(newFolderName,cb_getpath);
+	if (data.type != 1){
+        $("newtask_personal_tr").style.visibility = "hidden";
+    } else {
+        $("newtask_personal_tr").style.visibility = "visible";
+    }
+	
+	ox.api.folder.getPathString({
+	    folder: newFolderName,
+	    success: function(s) {
+	        cb_getpath(s);
+	        ce();
+	    }
+	});
 }
 
 function toggleTree(){
 	if(!treeVisible){
+		centerPopupWindow($("TreeDialogTask"));
 		$("TreeDialogTask").style.display = "block";
+		$("TreeDialogTask").style.top = "120px";
+		$("TreeDialogTask").style.left = "170px";
 		treeVisible = true;
 
 	}
@@ -1273,4 +1418,16 @@ function checkCorrectInput(param, id) {
 function ce() {
 	taskCloseBit = true;
 	setBeforeUnload(taskCloseBit);
-}
\ No newline at end of file
+}
+
+//init window controller
+
+var ctrl = windowController = new WindowController();
+
+ctrl.set("beforeunload", function () {
+    if (messageOnCancel) {
+        return messageCloseWindow + "";
+    }
+});
+
+ctrl.set("confirm", cancelProcessTaskWindow);
