@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2010 Open-Xchange, Inc.
+ * Copyright (C) Open-Xchange Inc., 2006-2012
  * Mail: info@open-xchange.com 
  * 
  * @author Dirk Hartmann <dirk.hartmann@open-xchange.com>
@@ -21,12 +21,12 @@
  *    this also would give us the advantage to be informed when the selected object changed
  */
 
-registerModule("tasks", "Tasks",50); /*i18n*/
-registerModuleView("tasks", "Tasks",5,{x:1,y:1,ww:1,hw:1});
+registerModule("tasks", _("Tasks"), 50);
+registerModuleView("tasks", "Tasks",5,{x:1,y:1});
 registerPrintView("tasks/list");
 registerPrintView("tasks/split");
 registerPrintView("tasks/split/overview");
-var json = new JSON(); // argh, very bad making such vars public!
+var json = new JSONX(); // argh, very bad making such vars public!
 var completedetailtask;
 var activeTaskId = new Array();
 var tasksTabsList;
@@ -44,6 +44,7 @@ var tasksFolderPath;
 var tasksSelection = new Selection();
 var tasksSelection2= new Selection2();
 var tmpDetailRequest;
+var oAttachmentGridTask;
 (
 function() {
     function fn_add_Tag_tasks(tag){
@@ -84,7 +85,7 @@ function() {
                 }
             },
             function () { 
-                menuclearSearch();
+                triggerEvent('OX_Delete_Search');
                 triggerEvent("Selected",[]);
             }
     );
@@ -126,9 +127,9 @@ function() {
             register("OX_Add_Flag", fn_add_Tag_tasks);
             register("OX_Delete_Search", taskSearchDelete);
             register("OX_Task_MarkAsDone", tasks_markAsDone);
+            if (corewindow.hasFocus) setFocus($("listeTasks"));
          }, 
-         function() {
-            tasksFolderPath.clear();
+         function() {            
             if (gridlist) gridlist.disable();
             unregister("OX_Add_Flag", fn_add_Tag_tasks);    
             unregister("OX_New_Search", taskSearch);
@@ -136,6 +137,7 @@ function() {
             unregister("OX_Delete_Search", taskSearchDelete);
             unregister("OX_Task_MarkAsDone", tasks_markAsDone);
             latestRenderedTask=null;
+            tasksFolderPath.clear();
          },
          function() { 
             hideNode("taskslist");  
@@ -153,7 +155,11 @@ function() {
     
     registerView("tasks/split",
             function() {
-                showNode("taskssplit");  
+                 // hide tab if property is set
+                if ((ox.upsell.isVisible("infostore") && ox.upsell.isVisible("tasks-attachments")) === false) {
+                    $("taskpanel4").style.display = "none";
+                }
+                showNode("taskssplit");
                 $("taskssplit").style.display="";
             }, 
             function() {
@@ -182,9 +188,9 @@ function() {
                 register("OX_Task_MarkAsDone", tasks_markAsDone);
                 // update confirm button
                 triggerEvent("Confirmation_Changed", 0);
+                if (corewindow.hasFocus) setFocus($("taskssplitgrid"));
              }, 
              function() {
-                tasksFolderPath.clear();          
                 if (gridsplit) gridsplit.disable();
                 gridsplitTask = false;
                 if (tmpDetailRequest) {
@@ -198,6 +204,7 @@ function() {
                 unregister("OX_Add_Flag", fn_add_Tag_tasks);
                 unregister("OX_Delete_Search", taskSearchDelete);
                 unregister("OX_Task_MarkAsDone", tasks_markAsDone);
+                tasksFolderPath.clear();
              },
              function() {
                 latestRenderedTask = null;
@@ -255,8 +262,13 @@ function() {
                 if(!bAttachmentGridCreatedTask) {
                     createAttachmentGridTask();
                     bAttachmentGridCreatedTask = true;
+                    ox.ToolBarController.processSelection("attachments", false,
+                        [], true);
                 } else {        
                     oAttachmentGridTask.enableGrid();
+                    ox.ToolBarController.processSelection("attachments", false,
+                        oAttachmentGridTask.liveGrid.selection.getSelected(),
+                        true);
                 }
                 oAttachmentGridTask.getAttachments(activeTaskId[0].id,activeTaskId[0].folder_id);                   
             },
@@ -319,10 +331,10 @@ function() {
           gridsplit.enable(criteria,search,false);
                 
         } else if(currentpath2[1] == "list") {
-          gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");              
+          gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
           gridlist.enable(criteria,search,false);
         }
-        tasksFolderPath.drawSearch(module, pattern);     
+        tasksFolderPath.drawSearch(module, pattern);
     }
     
     function taskSearchDelete() {
@@ -345,13 +357,13 @@ function() {
     var portalCall = false;
     
     var bAttachmentGridCreatedTask;
-    var oAttachmentGridTask;
     
     function createAttachmentGridTask() {
         //set id and fid for attachments here
         var nId = activeTaskId[0].id;
         var nFolder = activeTaskId[0].folder || activeTaskId[0].folder_id;
-        oAttachmentGridTask = new attachmentGrid("taskAttachments",nId,nFolder,4);  
+        oAttachmentGridTask = new attachmentGrid("taskAttachments",nId,nFolder,4);
+        triggerEvent("OX_Tasks_AttachmentGrid_Ready", oAttachmentGridTask);
     }
     
     register("OX_Task_Delete", deleteTask);
@@ -362,20 +374,6 @@ function() {
     register("Loaded", function() {
         gridlist = makeGrid("listeTasks",true);
         gridsplit = makeGrid("taskssplitgrid",true);
-        
-        function addmenu(node) {
-            var menu = new PulldownMenu(node);
-            var item = new MenuItem("Options", /*i18n*/
-                function() {
-                    if (currentpath2[0] == "tasks")
-                        triggerEvent("OX_Switch_View",
-                                     "configuration/tasks/preferences");
-                });
-            item.setIcon("img/folder/settings.gif");
-            menu.addItem(item);
-        }
-        addmenu($("arrowForTaskOptions"));
-        addmenu($("arrowForTaskSplitOptions"));
     });
         
     function tasks_markAsDone() {
@@ -407,13 +405,13 @@ function() {
         collection.columns=columns;
         OXCache.newRequest(null,"tasks",collection,null,
             function(daten) {
-                if (!daten.objects) return;             
+                if (!daten.objects) return;
                 var fPutData = new Array(); 
-                var fOCData = null;             
+                var fOCData = null;
                 for (var i in daten.objects) {
                     var object = daten.objects[i];
                     var timestamp = object["timestamp"] || 0;
-                    changes = cb_changes(object);                    
+                    changes = cb_changes(object);
                     if (!changes) continue;
                     fOCData = changes;
                     fPutData.push({
@@ -426,7 +424,7 @@ function() {
                     });
                 }
                 if (!fPutData.length || fOCData == null) return;
-                new JSON().put(AjaxRoot + "/multiple?session=" + session, 
+                new JSONX().put(AjaxRoot + "/multiple?session=" + session, 
                        fPutData, null,
                        function(cb) { 
                             if (!cb.length) return;
@@ -448,11 +446,11 @@ function() {
         return { "percent_completed": new_pc, "status": new_status };
     }
     
-    function addCheckBox() {
-        var checkbox = newnode("input", 0, { type: "checkbox", className: "noborder" });
-        addDOMEvent(checkbox, "click", function() {
-                if (!tasksSelection2.getSelected().length) return false;
-                tasks_udpateTasks([tasksSelection2.getSelected()[0]], ["percent_completed"], cb_changes);
+    function addCheckBox(data) {
+        var checkbox = newnode("input", { padding: 0, margin: 0, verticalAlign: "middle" }, { type: "checkbox", className: "noborder" });
+        jQuery(checkbox).bind("click", { data: data }, function(evt) {
+            evt.data.data.module = "tasks";
+            tasks_udpateTasks([ evt.data.data ], ["percent_completed"], cb_changes);
         });
         return checkbox;
     }
@@ -480,7 +478,7 @@ function() {
                         div.firstChild.style.height = "16px";
                     } else {
                         div.firstChild.src = getFullImgSrc("img/tasks/sequence.gif");
-                        div.firstChild.alt = _("Series");   /*i18n*/
+                        div.firstChild.alt = _("Recurrence");   /*i18n*/
                         div.firstChild.style.verticalAlign = "middle";
                         div.firstChild.style.width = "16px";
                         div.firstChild.style.height = "16px";
@@ -495,19 +493,68 @@ function() {
                     div.firstChild.style.width = "16px";
                     div.firstChild.style.height = "16px";
                 }
-            },{
+            }, {
+                sortable: false,
+                name : ["participants"],
+                text: "&#xa0;",
+                width: "20px",
+                style: { padding: 0, textAlign: "center", verticalAlign: "middle" },
+                set: function(div, participants) {
+                    if (!div.firstChild) {
+                        jQuery(div).append(
+                            jQuery("<img>")
+                            .css({ verticalAlign: "middle"})
+                            .attr({ width: 16, height: 16, alt: "", title: "" })
+                        );
+                    }
+                    if (isGroupAppointment(participants)) {
+                        jQuery("img:first", div)
+                        .attr({
+                            src: getFullImgSrc("img/calendar/group.gif"),
+                            alt: _("Group task"),
+                            title: _("Group task")
+                        });
+                    } else {
+                        jQuery("img:first", div)
+                        .attr({
+                            src: getFullImgSrc("img/dummy.gif"),
+                            alt: "",
+                            title: ""
+                        });
+                    }
+                },
+                clear: function(div) {
+                    if (!div.firstChild) {
+                        jQuery(div).append(
+                            jQuery("<img>")
+                            .css({ verticalAlign: "middle"})
+                            .attr({
+                                src: getFullImgSrc("img/dummy.gif"),
+                                width: 16,
+                                height: 16,
+                                alt: "",
+                                title: ""
+                            })
+                        );
+                    } else {
+                        jQuery("img:first", div)
+                        .attr({
+                            src: getFullImgSrc("img/dummy.gif")
+                        });
+                    }
+                }
+            }, {
                 name: ["folder_id", "id", "percent_completed"],
                 text: "&#xa0;",
                 style: { padding: 0, textAlign: "center", verticalAlign: "middle" },
                 width: "20px",
                 set: function(div, data) {
-                    if (!div.firstChild) div.appendChild(addCheckBox());
+                    if (!div.firstChild) div.appendChild(addCheckBox({ folder_id: data.folder_id, id: data.id }));
                     div.firstChild.style.display = "";
                     div.firstChild.checked = (data["percent_completed"] && data["percent_completed"] >= 100);
                 },
-                clear: function(div) {
-                    if (!div.firstChild) div.appendChild(addCheckBox());
-                    div.firstChild.style.display = "none";
+                clear: function(div, data) {
+                    if (div.firstChild) removeChildNodes(div);
                 }
             },{ 
                 text: "&#160;",
@@ -544,8 +591,8 @@ function() {
                     if (object.title) {
                         div.firstChild.data = object.title;
                         if(object["percent_completed"] && object["percent_completed"] >= 100) {
-                            div.className="cell font-color-disabled";                           
-                            div.style.textDecoration = "line-through";                            
+                            div.className="cell font-color-disabled";                          
+                            div.style.textDecoration = "line-through";
                         } else {
                             div.className="cell";
                             div.style.textDecoration = "none";
@@ -637,6 +684,7 @@ function() {
                 sortable: true,
                 sort: "percent_completed",
                 name : ["percent_completed"],
+                style: {textAlign: "right"},
                 width: "12%",
                 set: function(div, percent_completed) {
                     if (!div.firstChild) {
@@ -659,9 +707,8 @@ function() {
                 },
                 clear: clear
             }, {
-                text: "Flag",   /*i18n*/
+                text: "&#160;",
                 name : ["color_label"],
-                i18n: true,
                 width: "4em",
                 sort: "color_label",
                 sortable: true,
@@ -682,35 +729,38 @@ function() {
         
         var contextData = [];
         var count = Value(), writable = Value(), deletable = Value();
-        var confirmable = Value();
+        var confirmable = Value(), markable = Value();
         var menu = grid.contextmenu = globalContextMenus.tasks = new ContextMenu();
         
-        var edit = new MenuItem("Edit", /*i18n*/
+        var edit = new MenuItem(_("Edit"),
             function() { triggerEvent('OX_Task_Edit'); });
         edit.setIcon("img/menu/edit.gif", "img/menu/edit_d.gif");
         edit.setEnabledF(function() { return count() == 1 && writable(); });
         menu.addItem(edit);
         
-        var del = new MenuItem("Delete", /*i18n*/
+        var del = new MenuItem(_("Delete"),
             function() { triggerEvent('OX_Task_Delete'); });
         del.setIcon("img/menu/delete.gif", "img/menu/delete_d.gif");
         del.setEnabledF(function() { return count() > 0 && deletable(); });
         menu.addItem(del);
         
-        var copy = new MenuItem("Use as template", /*i18n*/
+        var copy = new MenuItem(_("Use as template"),
             function() { triggerEvent('OX_Task_Duplicate'); });
         copy.setIcon("img/menu/task_copy.gif", "img/menu/task_copy_d.gif");
         copy.setEnabledF(function() { return count() == 1 && writable(); });
         menu.addItem(copy);
     
-        var done = new MenuItem("Mark as Done", /*i18n*/
+        var done = new MenuItem(_("Mark as Done"),
             function() { triggerEvent('OX_Task_MarkAsDone'); });
-        done.setEnabledF(function() { return count() > 0 && writable(); });
+        done.setIcon("icons/16/task_mark_as_done.png", "icons/16/task_mark_as_done_dis.png");
+        done.setEnabledF(function() {
+            return count() > 0 && writable() && markable();
+        });
         menu.addItem(done);
         
         menu.addItem(new MenuSeparator());
     
-        var confirm = new MenuItem("Change confirmation"/*i18n*/, function() {
+        var confirm = new MenuItem(_("Change confirmation"), function() {
             var objects = new Array(contextData.length);
             for (var i = 0; i < objects.length; i++) {
                 objects[i] = new AcceptDenyObject("tasks", contextData[i]);
@@ -730,14 +780,23 @@ function() {
             writable.clear();
             deletable.clear();
             confirmable.clear();
+            markable.clear();
             if (!sel.length) return;
 
             OXCache.newRequest(null, "tasks",
-                { columns: ["created_by"], objects: sel }, null, ownerData);
-            function ownerData(data) {
+                { columns: ["created_by", "status"], objects: sel },
+                null, simpleData);
+            function simpleData(data) {
                 contextData = data.objects;
                 writable.set(menuhasRight(contextData, "WRITE"));
                 deletable.set(menuhasRight(contextData, "DELETE"));
+                for (var i in contextData) {
+                    if (contextData[i].status != 3) {
+                        markable.set(true);
+                        return;
+                    }
+                }
+                markable.set(false);
             }
 
             OXCache.newRequest(null, "tasks",
@@ -795,11 +854,11 @@ function() {
         $(gridName + "Header").appendChild(grid.getHeader());
         grid.getTable($(gridName));
         grid.events.register("Changed",tasks_HeaderUpdate);
-        var hv = grid.addHover(OXTaskHover.getContent().node, function(id) {
-            OXTaskHover.actualHover=hv;
-            OXTaskHover.refillContent(id.id,id.folder_id);                  
-            
-        });
+        var hv = grid.addHover(OXTaskHover.getContent().node,
+            function(id, manual) {
+                OXTaskHover.actualHover=hv;
+                OXTaskHover.refillContent(id.id,id.folder_id);
+            });
         hv.setSize(OXTaskHover.contentobject.node);
         grid.setSort("end_date","asc");
         return grid;
@@ -820,13 +879,6 @@ function() {
                 },
                 id: activeTaskId[0]
             });
-//            editTask = newWindow("newTask.html#modul=edit&id=" 
-//                + activeTaskId[0].id 
-//                + "&session=" 
-//                + session 
-//                + "&folder=" 
-//                + activeTaskId[0].folder_id, getWindowOptions(), activeTaskId[0]);
-//            if (editTask) editTask.focus();
         }
     }
     
@@ -843,13 +895,6 @@ function() {
                     folder: activeTaskId[0].folder_id
                 }
             });
-//            duplicatetask = newWindow("newTask.html#modul=duplicate&id=" 
-//                + activeTaskId[0].id 
-//                + "&session=" 
-//                + session 
-//                + "&folder=" 
-//                + activeTaskId[0].folder_id, getWindowOptions());
-//            if (duplicatetask) duplicatetask.focus();
         }
     }
     register("OX_Create_Object",createNewTask);
@@ -865,8 +910,6 @@ function() {
                     folder: folder
                 }
             });
-//            newTaskWindow = newWindow("newTask.html#folder="+folder, "width=780px,height=640px,left=5,top=5,resizable=yes");
-//            newTaskWindow.focus();
         }
     }
     
@@ -900,6 +943,7 @@ function() {
     }
     
     function printTasks() {
+        
         if (!tasksSelection2 || activemodule != "tasks") {
             return;
         } else if (tasksSelection2.count != 1) {
@@ -909,52 +953,60 @@ function() {
                 globalprint.printLiveGrid(gridlist);
             }
             return;
-        }       
+        }
         
-        var aPrintDetailTask = new Array();
-        aPrintDetailTask = [];
-                
-        var taskData = completedetailtask;
-        var detailTaskPrint = new Print(taskData.title);
+        var aPrintDetailTask = [],
+            taskData = completedetailtask,
+            detailTaskPrint = new Print(taskData.title);
         
         /* Tab Details */
         aPrintDetailTask.push(Print.createTitle(taskData.title));
         aPrintDetailTask.push(Print.createLine("5px"));
         aPrintDetailTask.push(Print.createEmpty(true));
         
-        if (taskData.priority)
+        if (taskData.priority) {
             aPrintDetailTask.push(Print.createPriority(taskData.priority));
+        }
             
-        aPrintDetailTask.push(Print.createContent(_("% done:"),taskData.percent_completed || "0"));
-
-        if (taskData.start_date)
-            aPrintDetailTask.push(Print.createContent(_("Start date:"),formatDate(taskData.start_date, "dateday")));
-
-        if (taskData.end_date)
-            aPrintDetailTask.push(Print.createContent(_("End date:"),formatDate(taskData.end_date, "dateday")));
-
-        if (taskData.note)
-            aPrintDetailTask.push(Print.createContent(_("Description:"),taskData.note));
+        aPrintDetailTask.push(Print.createContent(_("% done:"), taskData.percent_completed || "0"));
+        
+        if (taskData.start_date) {
+            aPrintDetailTask.push(Print.createContent(_("Start date:"), formatDate(taskData.start_date, "dateday")));
+        }
+        
+        if (taskData.end_date) {
+            aPrintDetailTask.push(Print.createContent(_("End date:"), formatDate(taskData.end_date, "dateday")));
+        }
+        
+        if (taskData.categories) {
+            aPrintDetailTask.push(Print.createContent(_("Categories:"), taskData.categories));
+        }
+        
+        if (taskData.note) {
+            aPrintDetailTask.push(Print.createContent(_("Description:"), taskData.note));
+        }
         
         /* Tab Details */
         aPrintDetailTask.push(Print.createEmpty());
         aPrintDetailTask.push(Print.createHeader(_("Details:")));
         
-        if (taskData.trip_meter)
-            aPrintDetailTask.push(Print.createContent(_("Distance:"),taskData.trip_meter));
-            
-        if (taskData.target_duration)
-            aPrintDetailTask.push(Print.createContent(_("Estimated Duration:"),taskData.target_duration + " " + _("minutes")));
-            
-        if (taskData.actual_duration)
-            aPrintDetailTask.push(Print.createContent(_("Current Duration:"),taskData.actual_duration + " " + _("minutes")));
-
-        if (taskData.target_costs)
+        if (taskData.trip_meter) {
+            aPrintDetailTask.push(Print.createContent(_("Distance:"), taskData.trip_meter));
+        }
+        if (taskData.target_duration) {
+            aPrintDetailTask.push(Print.createContent(_("Estimated Duration:"), taskData.target_duration + " " + _("minutes")));
+        }
+        if (taskData.actual_duration) {
+            aPrintDetailTask.push(Print.createContent(_("Current Duration:"), taskData.actual_duration + " " + _("minutes")));
+        }
+        if (taskData.target_costs) {
             aPrintDetailTask.push(Print.createContent(_("Estimated Costs:"), (taskData.target_costs ? round(taskData.target_costs) : "") + " " + taskData.currency));
-
-        if (taskData.actual_costs)
+        }
+        if (taskData.actual_costs) {
             aPrintDetailTask.push(Print.createContent(_("Current Costs:"), (taskData.actual_costs ? round(taskData.actual_costs) : "") + " " + taskData.currency));
-
+        }
+        
+        // print
         detailTaskPrint.printDetail(aPrintDetailTask);
     }
 
@@ -988,14 +1040,14 @@ function fn_tasks_getDetails(objects, forceUpdate) {
         OXCache.unregister(tmpDetailRequest.uniqueName);
         delete(tmpDetailRequest);
     }
-    tmpDetailRequest=OXCache.newRequest(null, "tasks", collection, function(daten) {      
-        if (!daten || !daten.objects) {
+    tmpDetailRequest=OXCache.newRequest(null, "tasks", collection, function(daten) {
+        if (!daten || !daten.objects || !daten.objects.length) {
             enableTaskLoadingScreen(false);
             return;
         }
         updateTaskSplit(daten.objects[0]);
     }, function(daten) {
-        if (!daten || !daten.objects) {
+        if (!daten || !daten.objects || !daten.objects.length) {
             enableTaskLoadingScreen(false);
             return;
         }
@@ -1057,7 +1109,7 @@ function updateTaskSplit(object) {
     completedetailtask=object;
     
     for (idfield in object) {
-        var idvalue = object[idfield];          
+        var idvalue = object[idfield];
         switch (idfield) {
             case "priority":
                   var img = idvalue && idvalue <= 3 ? idvalue : 2; 
@@ -1074,8 +1126,16 @@ function updateTaskSplit(object) {
                   }
                   continue;
                   break;
-            case "status":
-                  idvalue = isNaN(idvalue) ? "" : _(aStatusTask[idvalue - 1]);
+            case "status": 
+                  if (idvalue === null || isNaN(idvalue)) {
+                      // set default status if it's not a number
+                      idvalue = 1;
+                      // if percent complete greater then 0 its in progress
+                      if ((object.percent_completed || 0) > 0) {
+                          idvalue = 2;
+                      }
+                  }
+                  idvalue = _(aStatusTask[idvalue - 1]);
                   break; 
             case "created_by":
                   $("tasks.split." + idfield).firstChild.data = _("Unknown"); /*i18n*/
@@ -1159,8 +1219,8 @@ function updateTaskSplit(object) {
                   objTaskDetailParticipants.popArray();
                   objTaskDetailParticipants.oParticipantResources = clone(idvalue);  
                   objTaskDetailParticipants.writeCountParticipants();
-                  objTaskDetailParticipants.pushArray();                      
-                  $("tasks.split.participants_count").firstChild.data = objTaskDetailParticipants.arrayLength();
+                  objTaskDetailParticipants.pushArray();
+                  jQuery("#tasks\\.split\\.participants_count").text("(" + objTaskDetailParticipants.arrayLength() + ")");
                   internalCache.getUsers(objTaskDetailParticipants.idUserArr,fnSetTaskUserColumn);
                   break;
             case "users":
@@ -1199,7 +1259,7 @@ function updateTaskSplit(object) {
                   break;
             case "categories":
             	var cat = (idvalue || "");
-                $("tasks.split."+idfield).style.display = cat.length ? "" : "none";                  
+                $("tasks.split."+idfield).style.display = cat.length ? "" : "none";
                 if (cat.length) {
 	                  ox.categories.ui.drawCategoriesList(ox.categories.getByString(cat), 
 	                		  $("tasks.split."+idfield));
@@ -1208,6 +1268,17 @@ function updateTaskSplit(object) {
                 }
                 continue;
                 break;
+            case "number_of_attachments":
+                jQuery("#tasks\\.split\\.number_of_attachments").text("(" + idvalue + ")");
+                continue;
+                break;
+            case "alarm":
+                if (idvalue) {
+                    idvalue = formatDate(idvalue, "datetime");
+                } else {
+                    idvalue = _("Not set");
+                }
+                break;
         }
         
         if ($("tasks.split." + idfield)) {
@@ -1252,7 +1323,7 @@ function TaskDetailParticipants() {
 TaskDetailParticipants.prototype = {
     writeCountParticipants : function () {
         this.sText = this.oParticipantResources.length;
-        $("tasks.split.participants_count").firstChild.data = this.sText;
+        jQuery("#tasks\\.split\\.participants_count").text("(" + this.sText + ")");
     },
     pushArray : function () {
         for(i=0; i < this.oParticipantResources.length; i++)
@@ -1473,7 +1544,7 @@ TaskDetailParticipantTab.prototype = {
                 if (div) {
                     removeChildNodes(div);
                     switch(text) {
-                        case 0  :   div.appendChild(document.createTextNode(_("waiting")));
+                        case 0  :   div.appendChild(addTranslated(_("waiting")));
                                         break;
                                         
                         case 1  :   div.appendChild(newnode("span", 0, {className : "appointmentACCEPTED"}, [document.createTextNode(_("accepted"))]));
@@ -1551,8 +1622,9 @@ TaskDetailParticipantTab.prototype = {
 };
 
 function tasks_HeaderUpdate(data) {
-    contactsFolderPath.additionalNode=document.createTextNode(" ("+ data.objects.length + ")");
-    contactsFolderPath.drawDOMNode(currentpath2[1] == "split" ? "taskofsplitview" : "taskoflistview", activefolder);
+    if (data.search) return; // do not update when search is active
+    tasksFolderPath.additionalNode=document.createTextNode(" ("+ data.objects.length + ")");
+    tasksFolderPath.drawDOMNode(currentpath2[1] == "split" ? "taskofsplitview" : "taskoflistview", activefolder);
 }
 
 function fnSetTaskUserColumn(arg) {
